@@ -1,5 +1,5 @@
 /*
- *  Copyright (c) 2009 Cyrille Berger <cberger@cberger.net>
+ *  SPDX-FileCopyrightText: 2009 Cyrille Berger <cberger@cberger.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -26,7 +26,8 @@ struct LayoutFactory::Private {
     QString name;
 };
 
-LayoutFactory::LayoutFactory(const QString& _id, const QString& _name) : d(new Private)
+LayoutFactory::LayoutFactory(const QString &_id, const QString &_name)
+    : d(new Private)
 {
     d->id = _id;
     d->name = _name;
@@ -37,12 +38,12 @@ LayoutFactory::~LayoutFactory()
     delete d;
 }
 
-const QString& LayoutFactory::id() const
+const QString &LayoutFactory::id() const
 {
     return d->id;
 }
 
-const QString& LayoutFactory::name() const
+const QString &LayoutFactory::name() const
 {
     return d->name;
 }
