@@ -1,5 +1,5 @@
 /*
- *  Copyright (c) 2009 Cyrille Berger <cberger@cberger.net>
+ *  SPDX-FileCopyrightText: 2009 Cyrille Berger <cberger@cberger.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,8 +25,8 @@
 class RootSection;
 class Section;
 
-#include <QDockWidget>
 #include <KoDockFactoryBase.h>
+#include <QDockWidget>
 
 class SectionPropertiesDock : public QDockWidget
 {
@@ -34,36 +34,39 @@ class SectionPropertiesDock : public QDockWidget
 public:
     SectionPropertiesDock();
     virtual ~SectionPropertiesDock();
-    void setRootSection(RootSection* _rootSection);
-    void setSection(Section* _section);
+    void setRootSection(RootSection *_rootSection);
+    void setSection(Section *_section);
 private Q_SLOTS:
     void reload();
     void layoutChanged(int index);
+
 private:
     Ui::WdgSectionProperties m_wdgSectionProperties;
-    Section* m_currentSection;
-    RootSection* m_rootSection;
+    Section *m_currentSection;
+    RootSection *m_rootSection;
 };
 
 class SectionPropertiesDockFactory : public KoDockFactoryBase
 {
-
 public:
-    SectionPropertiesDockFactory() { }
+    SectionPropertiesDockFactory() = default;
 
-    virtual QString id() const {
+    QString id() const override
+    {
         return QString("SectionProperties");
     }
 
-    virtual QDockWidget* createDockWidget() {
-        SectionPropertiesDock * dockWidget = new SectionPropertiesDock();
+    QDockWidget *createDockWidget() override
+    {
+        SectionPropertiesDock *dockWidget = new SectionPropertiesDock();
 
         dockWidget->setObjectName(id());
 
         return dockWidget;
     }
 
-    DockPosition defaultDockPosition() const {
+    DockPosition defaultDockPosition() const override
+    {
         return DockRight;
     }
 };
