@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2006 Frans Englich <frans.englich@telia.com>
+    SPDX-FileCopyrightText: 2006 Frans Englich <frans.englich@telia.com>
 
     This file is part of the KDE project
 
@@ -19,39 +19,38 @@
     Boston, MA 02110-1301, USA.
 */
 
-
 #ifndef KXQTS_TreeSortFilter_H
 #define KXQTS_TreeSortFilter_H
 
 #include <QSortFilterProxyModel>
 
 /**
-  * @short A sort & filter model for hierarchical item models.
-  *
-  * The current feature is that, when sorting, numbers are treated as
-  * a whole instead of on a character-per-character basis. For example, "myFile-10" is sorted
-  * after "myFile-9".
-  *
-  * @ingroup KXQTS
-  * @author Frans Englich <frans.englich@telia.com>
-  */
+ * @short A sort & filter model for hierarchical item models.
+ *
+ * The current feature is that, when sorting, numbers are treated as
+ * a whole instead of on a character-per-character basis. For example, "myFile-10" is sorted
+ * after "myFile-9".
+ *
+ * @ingroup KXQTS
+ * @author Frans Englich <frans.englich@telia.com>
+ */
 class TreeSortFilter : public QSortFilterProxyModel
 {
 public:
     /**
-      * Creates a TreeSortFilter.
-      *
-      * @param parent the parent. Must not be @c null.
-      */
+     * Creates a TreeSortFilter.
+     *
+     * @param parent the parent. Must not be @c null.
+     */
     explicit TreeSortFilter(QObject *parent);
+
 protected:
-
     /**
-      * Compares @p left and @p right. They are treated as QStrings.
-      */
-    virtual bool lessThan(const QModelIndex &left, const QModelIndex &right) const;
+     * Compares @p left and @p right. They are treated as QStrings.
+     */
+    bool lessThan(const QModelIndex &left, const QModelIndex &right) const override;
 
-    virtual bool filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent) const;
+    bool filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent) const override;
 
 private:
     inline bool numericLessThan(const QString &l, const QString &r) const;
