@@ -1,53 +1,39 @@
 /*
  * This file is part of Calligra
  *
- * Copyright (C) 2011 Nokia Corporation and/or its subsidiary(-ies).
+ * SPDX-FileCopyrightText: 2011 Nokia Corporation and /or its subsidiary(-ies).
  *
  * Contact: Thorsten Zachmann thorsten.zachmann@nokia.com
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public License
- * version 2.1 as published by the Free Software Foundation.
- *
- * This library is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301 USA
+ * SPDX-License-Identifier: LGPL-2.1-only
  *
  */
 
 #include "CSThumbProviderTables.h"
 
-#include <sheets/part/Doc.h>
-#include <sheets/Sheet.h>
-#include <sheets/Map.h>
-#include <sheets/PrintSettings.h>
-#include <sheets/ui/SheetView.h>
-#include <sheets/SheetPrint.h>
-#include <KoZoomHandler.h>
-#include <KoShapePainter.h>
 #include <KoPAUtil.h>
+#include <KoShapePainter.h>
+#include <KoZoomHandler.h>
 #include <QPainter>
+#include <sheets/core/Map.h>
+#include <sheets/core/PrintSettings.h>
+#include <sheets/core/Sheet.h>
+#include <sheets/core/SheetPrint.h>
+#include <sheets/part/Doc.h>
+#include <sheets/ui/SheetView.h>
 
 CSThumbProviderTables::CSThumbProviderTables(Calligra::Sheets::Doc *doc)
-: m_doc(doc)
+    : m_doc(doc)
 {
 }
 
-CSThumbProviderTables::~CSThumbProviderTables()
-{
-}
+CSThumbProviderTables::~CSThumbProviderTables() = default;
 
 QVector<QImage> CSThumbProviderTables::createThumbnails(const QSize &thumbSize)
 {
     QVector<QImage> thumbnails;
-    if (0 != m_doc->map()) {
-        foreach(Calligra::Sheets::Sheet* sheet, m_doc->map()->sheetList()) {
+    if (nullptr != m_doc->map()) {
+        for (Calligra::Sheets::SheetBase *bsheet : m_doc->map()->sheetList()) {
             QImage thumbnail(thumbSize, QImage::Format_RGB32);
             thumbnail.fill(QColor(Qt::white).rgb());
             QPainter p(&thumbnail);
@@ -58,6 +44,7 @@ QVector<QImage> CSThumbProviderTables::createThumbnails(const QSize &thumbSize)
             pageLayout.rightMargin = 0;
             pageLayout.topMargin = 0;
             pageLayout.bottomMargin = 0;
+            Calligra::Sheets::Sheet *sheet = dynamic_cast<Calligra::Sheets::Sheet *>(bsheet);
             sheet->printSettings()->setPageLayout(pageLayout);
             sheet->print()->setSettings(*sheet->printSettings(), true);
 
@@ -81,7 +68,9 @@ QVector<QImage> CSThumbProviderTables::createThumbnails(const QSize &thumbSize)
 
             const Qt::LayoutDirection direction = sheet->layoutDirection();
 
-            KoShapePainter shapePainter(direction == Qt::LeftToRight ? (KoShapeManagerPaintingStrategy *)0 : (KoShapeManagerPaintingStrategy *)0 /*RightToLeftPaintingStrategy(shapeManager, d->canvas)*/);
+            KoShapePainter shapePainter(direction == Qt::LeftToRight
+                                            ? (KoShapeManagerPaintingStrategy *)nullptr
+                                            : (KoShapeManagerPaintingStrategy *)nullptr /*RightToLeftPaintingStrategy(shapeManager, d->canvas)*/);
             shapePainter.setShapes(sheet->shapes());
             shapePainter.paint(p, zoomHandler);
 
