@@ -31,8 +31,6 @@
 
 #include <KPluginFactory>
 
-#include <poppler-version.h>
-
 // Don't show this warning: it's an issue in poppler
 #ifdef __GNUC__
 #pragma GCC diagnostic ignored "-Wunused-parameter"
@@ -42,8 +40,6 @@
 #include <GlobalParams.h>
 #include <PDFDoc.h>
 
-#define POPPLER_VERSION_MACRO ((POPPLER_VERSION_MAJOR << 16) | (POPPLER_VERSION_MINOR << 8) | (POPPLER_VERSION_MICRO))
-
 K_PLUGIN_FACTORY_WITH_JSON(Pdf2OdgImportFactory, "calligra_filter_pdf2odg.json", registerPlugin<Pdf2OdgImport>();)
 
 Pdf2OdgImport::Pdf2OdgImport(QObject *parent, const QVariantList &)
@@ -70,17 +66,13 @@ KoFilter::ConversionStatus Pdf2OdgImport::convert(const QByteArray &from, const
     Q_ASSERT(m_document->pages().isEmpty());
 
     // read config file
-    globalParams = std::unique_ptr<GlobalParams>(new GlobalParams);
-    if (!globalParams)
+    globalParams = std::make_unique<GlobalParams>();
+    if (!globalParams) {
         return KoFilter::NotImplemented;
+    }
 
-#if POPPLER_VERSION_MACRO < QT_VERSION_CHECK(22, 03, 0)
-    GooString *fname = new GooString(QFile::encodeName(m_chain->inputFile()).data());
-    PDFDoc *pdfDoc = new PDFDoc(fname, 0, 0, 0);
-#else
     std::unique_ptr<GooString> fname = std::make_unique<GooString>(QFile::encodeName(m_chain->inputFile()).data());
-    PDFDoc *pdfDoc = new PDFDoc(std::move(fname));
-#endif
+    auto pdfDoc = new PDFDoc(std::move(fname));
     if (!pdfDoc) {
         globalParams.reset();
         return KoFilter::StupidError;
@@ -109,7 +101,7 @@ KoFilter::ConversionStatus Pdf2OdgImport::convert(const QByteArray &from, const
         }
         tmpFile.close();
         debugPdf << "tmpFile:" << tmpFile.fileName();
-        SvgOutputDev *dev = new SvgOutputDev(tmpFile.fileName());
+        auto dev = new SvgOutputDev(tmpFile.fileName());
         if (dev->isOk()) {
             int rotate = 0;
             bool useMediaBox = true;
