@@ -1,20 +1,7 @@
 /* This file is part of the KDE project
-   Copyright (C) 2010 by Nokia
+   SPDX-FileCopyrightText: 2010 Nokia
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef MSO_WRITER_H
@@ -59,11 +46,11 @@ public:
     /**
      * Xml writer that writes into content.xml.
      */
-    KoXmlWriter& xml;
+    KoXmlWriter &xml;
     /**
      * Styles for the document that is being created.
      **/
-    KoGenStyles& styles;
+    KoGenStyles &styles;
     /**
      * Tells if the current output is for styles.xml or content.xml
      **/
@@ -76,8 +63,7 @@ public:
      * @param kostyles The styles for the writer.
      * @param stylexml Defines whether the style is an XML style.
      */
-    Writer(KoXmlWriter& xmlWriter, KoGenStyles& kostyles,
-           bool stylexml = false);
+    Writer(KoXmlWriter &xmlWriter, KoGenStyles &kostyles, bool stylexml = false);
     /**
      * Create a new writer with a new coordinate system.
      *
@@ -85,7 +71,7 @@ public:
      * systems are used.  These are defined by specifying a rectangle in the
      * old coordinate system and the equivalent in the new coordinate system.
      */
-    Writer transform(const QRectF& oldCoords, const QRectF &newCoords) const;
+    Writer transform(const QRectF &oldCoords, const QRectF &newCoords) const;
     /**
      * Convert local length to global length.
      *
@@ -110,4 +96,4 @@ public:
     qreal hOffset(qreal offset) const;
 };
 
-#endif //MSO_WRITER_H
+#endif // MSO_WRITER_H
