@@ -1,23 +1,11 @@
 /*
  * This file is part of Office 2007 Filters for Calligra
  *
- * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
+ * SPDX-FileCopyrightText: 2009-2010 Nokia Corporation and /or its subsidiary(-ies).
  *
  * Contact: Suresh Chande suresh.chande@nokia.com
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public License
- * version 2.1 as published by the Free Software Foundation.
- *
- * This library is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301 USA
+ * SPDX-License-Identifier: LGPL-2.1-only
  *
  */
 
@@ -34,7 +22,7 @@ void MSOOXML_CURRENT_CLASS::initInternal()
     m_hasPosOffsetV = false;
     m_posOffsetH = 0;
     m_posOffsetV = 0;
-    m_currentTextStyleProperties = 0;
+    m_currentTextStyleProperties = nullptr;
     m_read_t_args = false;
 }
 
@@ -77,7 +65,7 @@ KoFilter::ConversionStatus MSOOXML_CURRENT_CLASS::read_t()
 
     while (!atEnd()) {
         readNext();
-        //debugMsooXml << *this;
+        // debugMsooXml << *this;
         if (isCharacters()) {
             body->addTextSpan(text().toString());
 #ifdef PPTXXMLSLIDEREADER_CPP
@@ -90,7 +78,7 @@ KoFilter::ConversionStatus MSOOXML_CURRENT_CLASS::read_t()
             BREAK_IF_END_OF(CURRENT_EL)
         }
     }
-//debugMsooXml << "{1}";
+    // debugMsooXml << "{1}";
 
     if (m_read_t_args) {
         m_read_t_args = false;
@@ -100,8 +88,6 @@ KoFilter::ConversionStatus MSOOXML_CURRENT_CLASS::read_t()
     }
 }
 
-
-
 // ================================================================
 //                     Namespace: mc
 // ================================================================
@@ -115,7 +101,6 @@ KoFilter::ConversionStatus MSOOXML_CURRENT_CLASS::read_t()
 // there are always namespaces, so it doesn't apply.
 // Same is true for READ_EPILOGUE.
 
-
 #undef MSOOXML_CURRENT_NS
 #define MSOOXML_CURRENT_NS "mc"
 
@@ -128,18 +113,16 @@ KoFilter::ConversionStatus MSOOXML_CURRENT_CLASS::read_AlternateContent()
 
     while (!atEnd()) {
         readNext();
-        if (isEndElement() && name() == "AlternateContent") {
+        if (isEndElement() && name() == QLatin1StringView("AlternateContent")) {
             break;
         }
 
         if (isStartElement()) {
-            if (name() == "Choice") {
+            if (name() == QLatin1StringView("Choice")) {
                 TRY_READ(Choice)
-            }
-            else if (!m_choiceAccepted && qualifiedName() == "mc:Fallback") {
+            } else if (!m_choiceAccepted && qualifiedName() == QLatin1StringView("mc:Fallback")) {
                 TRY_READ(Fallback)
-            }
-            else {
+            } else {
                 skipCurrentElement();
             }
         }
@@ -153,7 +136,6 @@ KoFilter::ConversionStatus MSOOXML_CURRENT_CLASS::read_AlternateContent()
 //! Choice handler
 KoFilter::ConversionStatus MSOOXML_CURRENT_CLASS::read_Choice()
 {
-
     const QXmlStreamAttributes attrs(attributes());
 
     TRY_READ_ATTR_WITHOUT_NS(Requires)
@@ -171,7 +153,7 @@ KoFilter::ConversionStatus MSOOXML_CURRENT_CLASS::read_Choice()
     m_choiceAccepted = true;
     while (!atEnd()) {
         readNext();
-        if (isEndElement() && name() == "Choice") {
+        if (isEndElement() && name() == QLatin1StringView("Choice")) {
             break;
         }
         if (isStartElement()) {
@@ -188,10 +170,9 @@ KoFilter::ConversionStatus MSOOXML_CURRENT_CLASS::read_Choice()
 //! Fallback handler
 KoFilter::ConversionStatus MSOOXML_CURRENT_CLASS::read_Fallback()
 {
-
     while (!atEnd()) {
         readNext();
-        if (isEndElement() && name() == "Fallback") {
+        if (isEndElement() && name() == QLatin1StringView("Fallback")) {
             break;
         }
 
@@ -204,7 +185,7 @@ KoFilter::ConversionStatus MSOOXML_CURRENT_CLASS::read_Fallback()
 #endif
 #ifdef XLSXXMLWORKSHEETREADER_CPP
             // FIXME: This Choice/Content/Fallback structure needs a more general treatment.
-            if (name() == "oleObject") {
+            if (name() == QLatin1StringView("oleObject")) {
                 TRY_READ(oleObject)
             }
 #endif
