@@ -1,20 +1,7 @@
 /* Swinder - Portable library for spreadsheet
-   Copyright (C) 2010 Sebastian Sauer <sebsauer@kdab.com>
+   SPDX-FileCopyrightText: 2010 Sebastian Sauer <sebsauer@kdab.com>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA
+   SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include <QCoreApplication>
@@ -44,9 +31,18 @@ struct Field {
     QString defaultValue;
     QString lengthFor;
 
-    Field(const QString &name = QString(), const QString &type = QString()) : name(name), type(type), isArray(false), isArrayLength(false), isStringLength(false), isEnum(false) {}
+    Field(const QString &name = QString(), const QString &type = QString())
+        : name(name)
+        , type(type)
+        , isArray(false)
+        , isArrayLength(false)
+        , isStringLength(false)
+        , isEnum(false)
+    {
+    }
 
-    QString getterName() const {
+    QString getterName() const
+    {
         if (type == "bool" && !(name.startsWith("has") || name.startsWith("is"))) {
             return "is" + ucFirst(name);
         } else {
@@ -54,35 +50,46 @@ struct Field {
         }
     }
 
-    QString setterName() const {
+    QString setterName() const
+    {
         return "set" + ucFirst(name);
     }
 };
 
-static QString getFieldType(const QString &xmlType, unsigned bits, const QString &otherType, const QMap<QString, QString>& extraTypes)
+static QString getFieldType(const QString &xmlType, unsigned bits, const QString &otherType, const QMap<QString, QString> &extraTypes)
 {
     Q_UNUSED(bits);
     Q_UNUSED(otherType);
-    if (xmlType == "unsigned") return "unsigned";
-    else if (xmlType == "signed") return "int";
-    else if (xmlType == "float" || xmlType == "fixed") return "double";
-    else if (xmlType == "bool") return "bool";
-    else if (xmlType == "bytestring" || xmlType == "unicodestring" || xmlType == "unicodechars") return "QString";
-    else if (xmlType == "blob") return "QByteArray";
-    else if (xmlType == "uuid") return "QUuid";
-    else if (extraTypes.contains(xmlType)) return getFieldType(extraTypes[xmlType], bits, otherType, extraTypes);
+    if (xmlType == "unsigned")
+        return "unsigned";
+    else if (xmlType == "signed")
+        return "int";
+    else if (xmlType == "float" || xmlType == "fixed")
+        return "double";
+    else if (xmlType == "bool")
+        return "bool";
+    else if (xmlType == "bytestring" || xmlType == "unicodestring" || xmlType == "unicodechars")
+        return "QString";
+    else if (xmlType == "blob")
+        return "QByteArray";
+    else if (xmlType == "uuid")
+        return "QUuid";
+    else if (extraTypes.contains(xmlType))
+        return getFieldType(extraTypes[xmlType], bits, otherType, extraTypes);
     return "ERROR";
 }
 
-bool hasParentNode(const QDomNode& n, const QString& name)
+bool hasParentNode(const QDomNode &n, const QString &name)
 {
     QDomNode p = n.parentNode();
-    if (p.isNull()) return false;
-    if (p.nodeName() == name) return true;
+    if (p.isNull())
+        return false;
+    if (p.nodeName() == name)
+        return true;
     return hasParentNode(p, name);
 }
 
-static QMap<QString, Field> getFields(QDomElement record, bool* foundStrings = 0)
+static QMap<QString, Field> getFields(QDomElement record, bool *foundStrings = nullptr)
 {
     QDomNodeList types = record.elementsByTagName("type");
     QMap<QString, QString> extraTypes;
@@ -101,7 +108,8 @@ static QMap<QString, Field> getFields(QDomElement record, bool* foundStrings = 0
         QString name = e.attribute("name");
         if (!name.startsWith("reserved")) {
             map[name] = Field(name, getFieldType(e.attribute("type"), e.attribute("size").toUInt(), map[name].type, extraTypes));
-            if (foundStrings && map[name].type == "QString") *foundStrings = true;
+            if (foundStrings && map[name].type == "QString")
+                *foundStrings = true;
             if (hasParentNode(e, "array")) {
                 map[name].isArray = true;
             }
@@ -134,7 +142,7 @@ static QMap<QString, Field> getFields(QDomElement record, bool* foundStrings = 0
         QDomElement e = arrays.at(i).toElement();
         QString name = e.attribute("length");
         if (map.contains(name)) {
-            Field& field = map[name];
+            Field &field = map[name];
             field.isArrayLength = true;
             QDomNodeList afields = e.elementsByTagName("field");
             for (int j = 0; j < afields.size(); j++) {
@@ -148,7 +156,7 @@ static QMap<QString, Field> getFields(QDomElement record, bool* foundStrings = 0
     return map;
 }
 
-void processEnumsForHeader(QDomNodeList fieldList, QTextStream& out)
+void processEnumsForHeader(QDomNodeList fieldList, QTextStream &out)
 {
     for (int i = 0; i < fieldList.size(); i++) {
         QDomElement f = fieldList.at(i).toElement();
@@ -161,16 +169,17 @@ void processEnumsForHeader(QDomNodeList fieldList, QTextStream& out)
                 out << "        " << en.attribute("name");
                 if (en.hasAttribute("value"))
                     out << " = " << en.attribute("value");
-                if (j != enumNodes.size() - 1) out << ",";
+                if (j != enumNodes.size() - 1)
+                    out << ",";
                 out << "\n";
             }
             out << "    };\n\n"
-            << "    static QString " << lcFirst(f.attribute("name")) << "ToString(" << name << " " << f.attribute("name") << ");\n\n";
+                << "    static QString " << lcFirst(f.attribute("name")) << "ToString(" << name << " " << f.attribute("name") << ");\n\n";
         }
     }
 }
 
-void processRecordForHeader(QDomElement e, QTextStream& out)
+void processRecordForHeader(QDomElement e, QTextStream &out)
 {
     QString className = e.attribute("name") + "Record";
     QList<Field> fields = getFields(e).values();
@@ -179,14 +188,14 @@ void processRecordForHeader(QDomElement e, QTextStream& out)
 
     // add id field and rtti method
     out << "    static const unsigned id;\n\n"
-    << "    virtual unsigned rtti() const { return this->id; }\n\n";
+        << "    virtual unsigned rtti() const override { return this->id; }\n\n";
 
     // constructor and destructor
-    out << "    " << className << "(Swinder::Workbook *book);\n    virtual ~" << className << "();\n\n";
+    out << "    " << className << "(Swinder::Workbook *book);\n    virtual ~" << className << "() override;\n\n";
 
     // copy and assignment
     out << "    " << className << "( const " << className << "& record );\n"
-    << "    " << className << "& operator=( const " << className << "& record );\n\n";
+        << "    " << className << "& operator=( const " << className << "& record );\n\n";
 
     // enums
     QDomNodeList fieldNodes = e.elementsByTagName("field");
@@ -197,12 +206,14 @@ void processRecordForHeader(QDomElement e, QTextStream& out)
     processEnumsForHeader(typeNodes, out);
 
     // getters and setters
-    foreach(const Field& f, fields) {
+    foreach (const Field &f, fields) {
         out << "    " << f.type << " " << f.getterName() << "(";
-        if (f.isArray) out << " unsigned index ";
+        if (f.isArray)
+            out << " unsigned index ";
         out << ") const;\n"
-        << "    void " << f.setterName() << "(";
-        if (f.isArray) out << " unsigned index,";
+            << "    void " << f.setterName() << "(";
+        if (f.isArray)
+            out << " unsigned index,";
         out << " " << f.type << " " << f.name << " );\n\n";
     }
 
@@ -210,7 +221,8 @@ void processRecordForHeader(QDomElement e, QTextStream& out)
     for (int i = 0; i < cfieldNodes.size(); i++) {
         QDomElement f = cfieldNodes.at(i).toElement();
         QString type = f.attribute("ctype");
-        if (type.isEmpty()) type = ucFirst(f.attribute("name"));
+        if (type.isEmpty())
+            type = ucFirst(f.attribute("name"));
         out << "    " << type << " " << f.attribute("name") << "() const;\n\n";
     }
 
@@ -234,22 +246,22 @@ void processRecordForHeader(QDomElement e, QTextStream& out)
     }
 
     // setData method
-    out << "    virtual void setData( unsigned size, const unsigned char* data, const unsigned* continuePositions );\n\n";
+    out << "    virtual void setData( unsigned size, const unsigned char* data, const unsigned* continuePositions ) override;\n\n";
 
     // writeData method
-    out << "    virtual void writeData( XlsRecordOutputStream& out ) const;\n\n";
+    out << "    virtual void writeData( XlsRecordOutputStream& out ) const override;\n\n";
 
     // name method
-    out << "    virtual const char* name() const { return \"" << e.attribute("name") << "\"; }\n\n";
+    out << "    virtual const char* name() const override { return \"" << e.attribute("name") << "\"; }\n\n";
 
     // dump method
-    out << "    virtual void dump( std::ostream& out ) const;\n\n";
+    out << "    virtual void dump( std::ostream& out ) const override;\n\n";
 
     // private stuff
     out << "private:\n    class Private;\n    Private * const d;\n};\n\n";
 }
 
-static void invalidFound(const QString &indent, QTextStream& out, const QString &currentOptional)
+static void invalidFound(const QString &indent, QTextStream &out, const QString &currentOptional)
 {
     if (currentOptional.isEmpty()) {
         out << indent << "setIsValid(false);\n";
@@ -260,18 +272,20 @@ static void invalidFound(const QString &indent, QTextStream& out, const QString
     }
 }
 
-static void sizeCheck(const QString &indent, QTextStream& out, QDomElement firstField, unsigned offset, bool dynamicOffset, const QString &currentOptional)
+static void sizeCheck(const QString &indent, QTextStream &out, QDomElement firstField, unsigned offset, bool dynamicOffset, const QString &currentOptional)
 {
     // find size of all fields until first unsized field or first if/array
     unsigned size = 0;
     for (QDomElement e = firstField; !e.isNull(); e = e.nextSiblingElement()) {
-        if (e.tagName() != "field") break;
+        if (e.tagName() != "field")
+            break;
         unsigned bits = e.attribute("size", "0").toUInt();
         if (bits == 0 && e.attribute("type") == "uuid") {
             bits = 128;
             e.setAttribute("size", "128");
         }
-        if (bits == 0) break;
+        if (bits == 0)
+            break;
         size += bits;
     }
     if (size % 8 != 0)
@@ -280,15 +294,24 @@ static void sizeCheck(const QString &indent, QTextStream& out, QDomElement first
         qFatal("Invalid non-byte-aligned chunk of fields found");
     if (size != 0) {
         out << indent << "if (size < ";
-        if (dynamicOffset) out << "curOffset + ";
-        if (offset) out << (offset / 8) << " + ";
+        if (dynamicOffset)
+            out << "curOffset + ";
+        if (offset)
+            out << (offset / 8) << " + ";
         out << (size / 8) << ") {\n";
         invalidFound(indent + "    ", out, currentOptional);
         out << indent << "}\n";
     }
 }
 
-static void processFieldElement(const QString &indent, QTextStream& out, QDomElement field, unsigned& offset, bool& dynamicOffset, QMap<QString, Field>& fieldsMap, const QString &setterArgs = QString(), const QString &currentOptional = QString())
+static void processFieldElement(const QString &indent,
+                                QTextStream &out,
+                                QDomElement field,
+                                unsigned &offset,
+                                bool &dynamicOffset,
+                                QMap<QString, Field> &fieldsMap,
+                                const QString &setterArgs = QString(),
+                                const QString &currentOptional = QString())
 {
     if (field.tagName() == "fail") {
         invalidFound(indent, out, currentOptional);
@@ -296,21 +319,23 @@ static void processFieldElement(const QString &indent, QTextStream& out, QDomEle
         unsigned bits = field.attribute("size").toUInt();
         QString name = field.attribute("name");
         if (!name.startsWith("reserved")) {
-            //if (bits >= 8 && offset % 8 != 0)
-            //    qFatal("Unaligned byte-or-larger field");
+            // if (bits >= 8 && offset % 8 != 0)
+            //     qFatal("Unaligned byte-or-larger field");
             if (bits >= 16 && bits % 8 != 0)
                 qFatal("Fields of 16 bits and larger must always be an exact number of bytes");
 
-            Field& f = fieldsMap[name];
+            Field &f = fieldsMap[name];
             if (f.type == "QString") {
                 if (offset % 8 != 0)
                     qFatal("Unaligned string");
 
                 if (!dynamicOffset)
                     out << indent << "curOffset = " << (offset / 8) << ";\n";
-                else if (offset) out << indent << "curOffset += " << (offset / 8) << ";\n";
+                else if (offset)
+                    out << indent << "curOffset += " << (offset / 8) << ";\n";
                 out << indent << f.setterName() << "(" << setterArgs;
-                dynamicOffset = true; offset = 0;
+                dynamicOffset = true;
+                offset = 0;
 
                 if (field.attribute("type") == "unicodestring")
                     out << "readUnicodeString(";
@@ -325,7 +350,7 @@ static void processFieldElement(const QString &indent, QTextStream& out, QDomEle
                 else
                     out << "-1";
                 out << ", size - curOffset"
-                << ", &stringLengthError, &stringSize));\n";
+                    << ", &stringLengthError, &stringSize));\n";
                 out << indent << "if (stringLengthError) {\n";
                 invalidFound(indent + "    ", out, currentOptional);
                 out << indent << "}\n";
@@ -337,8 +362,10 @@ static void processFieldElement(const QString &indent, QTextStream& out, QDomEle
 
                 if (field.hasAttribute("length")) {
                     out << indent << "if (";
-                    if (dynamicOffset) out << "curOffset + ";
-                    if (offset) out << (offset / 8) << " + ";
+                    if (dynamicOffset)
+                        out << "curOffset + ";
+                    if (offset)
+                        out << (offset / 8) << " + ";
                     out << "(" << field.attribute("length") << ") > size) {\n";
                     invalidFound(indent + "    ", out, currentOptional);
                     out << indent << "}\n";
@@ -346,8 +373,10 @@ static void processFieldElement(const QString &indent, QTextStream& out, QDomEle
                 out << indent << f.setterName() << "(" << setterArgs;
                 out << "QByteArray(reinterpret_cast<const char*>(";
                 out << "data";
-                if (dynamicOffset) out << " + curOffset";
-                if (offset) out << " + " << (offset / 8);
+                if (dynamicOffset)
+                    out << " + curOffset";
+                if (offset)
+                    out << " + " << (offset / 8);
                 out << "), ";
                 if (field.hasAttribute("length"))
                     out << field.attribute("length");
@@ -357,16 +386,20 @@ static void processFieldElement(const QString &indent, QTextStream& out, QDomEle
                 if (field.hasAttribute("length")) {
                     if (!dynamicOffset)
                         out << indent << "curOffset = " << (offset / 8);
-                    else out << indent << "curOffset += " << (offset / 8);
+                    else
+                        out << indent << "curOffset += " << (offset / 8);
                     out << " + " << field.attribute("length") << ";\n";
-                    dynamicOffset = true; offset = 0;
+                    dynamicOffset = true;
+                    offset = 0;
                     sizeCheck(indent, out, field.nextSiblingElement(), offset, dynamicOffset, currentOptional);
                 }
             } else if (f.type == "QUuid") {
                 out << indent << f.setterName() << "(" << setterArgs;
                 out << "readUuid(data";
-                if (dynamicOffset) out << " + curOffset";
-                if (offset) out << " + " << (offset / 8);
+                if (dynamicOffset)
+                    out << " + curOffset";
+                if (offset)
+                    out << " + " << (offset / 8);
                 out << "));\n";
             } else if (bits % 8 == 0) {
                 if (f.isStringLength)
@@ -389,12 +422,17 @@ static void processFieldElement(const QString &indent, QTextStream& out, QDomEle
                     qFatal("Unsupported type %s", qPrintable(field.attribute("type")));
 
                 out << "(data";
-                if (dynamicOffset) out << " + curOffset";
-                if (offset) out << " + " << (offset / 8);
+                if (dynamicOffset)
+                    out << " + curOffset";
+                if (offset)
+                    out << " + " << (offset / 8);
                 out << ")";
-                if (field.attribute("type") == "bool") out << " != 0";
-                if (f.isEnum) out << ")";
-                if (!f.isStringLength) out << ")";
+                if (field.attribute("type") == "bool")
+                    out << " != 0";
+                if (f.isEnum)
+                    out << ")";
+                if (!f.isStringLength)
+                    out << ")";
                 out << ";\n";
             } else {
                 if (f.isStringLength)
@@ -412,18 +450,24 @@ static void processFieldElement(const QString &indent, QTextStream& out, QDomEle
                 } else {
                     out << "((readU16(data";
                 }
-                if (dynamicOffset) out << " + curOffset";
-                if (firstByte) out << " + " << firstByte;
+                if (dynamicOffset)
+                    out << " + curOffset";
+                if (firstByte)
+                    out << " + " << firstByte;
                 out << ")";
-                if (bitOffset) out << " >> " << bitOffset;
-                out << ") & 0x" << hex << mask << dec << ")";
-                if (field.attribute("type") == "bool") out << " != 0";
-                if (f.isEnum) out << ")";
-                if (!f.isStringLength) out << ")";
+                if (bitOffset)
+                    out << " >> " << bitOffset;
+                out << ") & 0x" << Qt::hex << mask << Qt::dec << ")";
+                if (field.attribute("type") == "bool")
+                    out << " != 0";
+                if (f.isEnum)
+                    out << ")";
+                if (!f.isStringLength)
+                    out << ")";
                 out << ";\n";
             }
             // evaluate constraints
-            for (QDomElement child  = field.firstChildElement(); !child.isNull(); child = child.nextSiblingElement()) {
+            for (QDomElement child = field.firstChildElement(); !child.isNull(); child = child.nextSiblingElement()) {
                 if (child.tagName() == "constraint") {
                     out << indent << "if (!(" << f.getterName() << "(" << setterArgs << ") " << child.attribute("expr") << ")) {\n";
                     invalidFound(indent + "    ", out, currentOptional);
@@ -437,11 +481,13 @@ static void processFieldElement(const QString &indent, QTextStream& out, QDomEle
             qFatal("Ifs should always be byte-aligned");
         if (!dynamicOffset)
             out << indent << "curOffset = " << (offset / 8) << ";\n";
-        else if (offset) out << indent << "curOffset += " << (offset / 8) << ";\n";
+        else if (offset)
+            out << indent << "curOffset += " << (offset / 8) << ";\n";
 
         out << indent << "if (" << field.attribute("predicate") << ") {\n";
 
-        offset = 0; dynamicOffset = true;
+        offset = 0;
+        dynamicOffset = true;
         sizeCheck(indent + "    ", out, field.firstChildElement(), offset, dynamicOffset, currentOptional);
 
         for (QDomElement child = field.firstChildElement(); !child.isNull(); child = child.nextSiblingElement()) {
@@ -451,7 +497,8 @@ static void processFieldElement(const QString &indent, QTextStream& out, QDomEle
         if (offset % 8 != 0)
             qFatal("Ifs should contain an integer number of bytes");
 
-        if (offset) out << indent << "    curOffset += " << (offset / 8) << ";\n";
+        if (offset)
+            out << indent << "    curOffset += " << (offset / 8) << ";\n";
         out << indent << "}\n";
         offset = 0;
         sizeCheck(indent, out, field.nextSiblingElement(), offset, dynamicOffset, currentOptional);
@@ -460,8 +507,10 @@ static void processFieldElement(const QString &indent, QTextStream& out, QDomEle
             qFatal("Optionals should always be byte-aligned");
         if (!dynamicOffset)
             out << indent << "curOffset = " << (offset / 8) << ";\n";
-        else if (offset) out << indent << "curOffset += " << (offset / 8) << ";\n";
-        offset = 0; dynamicOffset = true;
+        else if (offset)
+            out << indent << "curOffset += " << (offset / 8) << ";\n";
+        offset = 0;
+        dynamicOffset = true;
 
         QString name = ucFirst(field.attribute("name"));
         QString label = field.attribute("name") + "Failed";
@@ -477,7 +526,8 @@ static void processFieldElement(const QString &indent, QTextStream& out, QDomEle
         if (offset % 8 != 0)
             qFatal("Optionals should contain an integer number of bytes");
 
-        if (offset) out << indent << "    curOffset += " << (offset / 8) << ";\n";
+        if (offset)
+            out << indent << "    curOffset += " << (offset / 8) << ";\n";
 
         out << indent << "}\n";
         out << label << ":\n";
@@ -491,9 +541,10 @@ static void processFieldElement(const QString &indent, QTextStream& out, QDomEle
             qFatal("Choose tags should always be byte-aligned");
         if (!dynamicOffset)
             out << indent << "curOffset = " << (offset / 8) << ";\n";
-        else
-            if (offset) out << indent << "curOffset += " << (offset / 8) << ";\n";
-        offset = 0; dynamicOffset = true;
+        else if (offset)
+            out << indent << "curOffset += " << (offset / 8) << ";\n";
+        offset = 0;
+        dynamicOffset = true;
 
         bool isFirst = true;
 
@@ -502,8 +553,12 @@ static void processFieldElement(const QString &indent, QTextStream& out, QDomEle
                 qFatal("only option tags are allowed inside a choose tag");
             }
 
-            if (isFirst) out << indent; else out << " ";
-            if (!isFirst) out << "else ";
+            if (isFirst)
+                out << indent;
+            else
+                out << " ";
+            if (!isFirst)
+                out << "else ";
             isFirst = false;
             if (childField.hasAttribute("predicate"))
                 out << "if (" << childField.attribute("predicate") << ") ";
@@ -518,7 +573,8 @@ static void processFieldElement(const QString &indent, QTextStream& out, QDomEle
             if (offset % 8 != 0)
                 qFatal("options should contain an integer number of bytes");
 
-            if (offset) out << indent << "    curOffset += " << (offset / 8) << ";\n";
+            if (offset)
+                out << indent << "    curOffset += " << (offset / 8) << ";\n";
             out << indent << "}";
             offset = 0;
         }
@@ -530,7 +586,8 @@ static void processFieldElement(const QString &indent, QTextStream& out, QDomEle
 
         if (!dynamicOffset)
             out << indent << "curOffset = " << (offset / 8) << ";\n";
-        else if (offset) out << indent << "curOffset += " << (offset / 8) << ";\n";
+        else if (offset)
+            out << indent << "curOffset += " << (offset / 8) << ";\n";
 
         QString length = field.attribute("length");
         if (fieldsMap.contains(length))
@@ -547,7 +604,8 @@ static void processFieldElement(const QString &indent, QTextStream& out, QDomEle
         }
 
         out << indent << "for (unsigned i = 0, endi = " << length << "; i < endi; ++i) {\n";
-        offset = 0; dynamicOffset = true;
+        offset = 0;
+        dynamicOffset = true;
         sizeCheck(indent + "    ", out, field.firstChildElement(), offset, dynamicOffset, currentOptional);
 
         for (QDomElement child = field.firstChildElement(); !child.isNull(); child = child.nextSiblingElement()) {
@@ -557,20 +615,25 @@ static void processFieldElement(const QString &indent, QTextStream& out, QDomEle
         if (offset % 8 != 0)
             qFatal("Arrays should contain an integer number of bytes");
 
-        if (offset) out << indent << "    curOffset += " << (offset / 8) << ";\n";
+        if (offset)
+            out << indent << "    curOffset += " << (offset / 8) << ";\n";
         out << indent << "}\n";
         offset = 0;
         sizeCheck(indent, out, field.nextSiblingElement(), offset, dynamicOffset, currentOptional);
     }
 }
 
-static void processFieldElementForWrite(const QString &indent, QTextStream& out, QDomElement field, const QMap<QString, Field>& fieldsMap, const QString &getterArgs = QString())
+static void processFieldElementForWrite(const QString &indent,
+                                        QTextStream &out,
+                                        QDomElement field,
+                                        const QMap<QString, Field> &fieldsMap,
+                                        const QString &getterArgs = QString())
 {
     if (field.tagName() == "field") {
         QString name = field.attribute("name");
         unsigned bits = field.attribute("size").toUInt();
         if (!name.startsWith("reserved")) {
-            const Field& f = fieldsMap[name];
+            const Field &f = fieldsMap[name];
             if (field.attribute("type") == "bytestring") {
                 out << indent << "out.writeByteString(";
             } else if (field.attribute("type") == "unicodestring") {
@@ -594,7 +657,7 @@ static void processFieldElementForWrite(const QString &indent, QTextStream& out,
             }
             if (f.isStringLength) {
                 // TODO: figure out length from string
-                const Field& f2 = fieldsMap[f.lengthFor];
+                const Field &f2 = fieldsMap[f.lengthFor];
                 out << f2.getterName() << "(" << getterArgs << ").length()";
             } else {
                 out << f.getterName() << "(" << getterArgs << ")";
@@ -617,8 +680,12 @@ static void processFieldElementForWrite(const QString &indent, QTextStream& out,
     } else if (field.tagName() == "choose") {
         bool isFirst = true;
         for (QDomElement childField = field.firstChildElement(); !childField.isNull(); childField = childField.nextSiblingElement()) {
-            if (isFirst) out << indent; else out << " ";
-            if (!isFirst) out << "else ";
+            if (isFirst)
+                out << indent;
+            else
+                out << " ";
+            if (!isFirst)
+                out << "else ";
             isFirst = false;
             if (childField.hasAttribute("predicate"))
                 out << "if (" << childField.attribute("predicate") << ") ";
@@ -650,12 +717,16 @@ static void processFieldElementForWrite(const QString &indent, QTextStream& out,
     }
 }
 
-static void processFieldElementForDump(const QString &indent, QTextStream& out, QDomElement field, const QMap<QString, Field>& fieldsMap, const QString &getterArgs = QString())
+static void processFieldElementForDump(const QString &indent,
+                                       QTextStream &out,
+                                       QDomElement field,
+                                       const QMap<QString, Field> &fieldsMap,
+                                       const QString &getterArgs = QString())
 {
     if (field.tagName() == "field") {
         QString name = field.attribute("name");
         if (!name.startsWith("reserved")) {
-            const Field& f = fieldsMap[name];
+            const Field &f = fieldsMap[name];
             if (!f.isStringLength) {
                 out << indent << "out << \"";
                 if (getterArgs.length() == 0) {
@@ -681,8 +752,12 @@ static void processFieldElementForDump(const QString &indent, QTextStream& out,
     } else if (field.tagName() == "choose") {
         bool isFirst = true;
         for (QDomElement childField = field.firstChildElement(); !childField.isNull(); childField = childField.nextSiblingElement()) {
-            if (isFirst) out << indent; else out << " ";
-            if (!isFirst) out << "else ";
+            if (isFirst)
+                out << indent;
+            else
+                out << " ";
+            if (!isFirst)
+                out << "else ";
             isFirst = false;
             if (childField.hasAttribute("predicate"))
                 out << "if (" << childField.attribute("predicate") << ") ";
@@ -714,7 +789,7 @@ static void processFieldElementForDump(const QString &indent, QTextStream& out,
     }
 }
 
-void processEnumsForImplementation(QDomNodeList fieldList, const QString &className, QTextStream& out)
+void processEnumsForImplementation(QDomNodeList fieldList, const QString &className, QTextStream &out)
 {
     for (int i = 0; i < fieldList.size(); i++) {
         QDomElement f = fieldList.at(i).toElement();
@@ -722,7 +797,7 @@ void processEnumsForImplementation(QDomNodeList fieldList, const QString &classN
         if (enumNodes.size()) {
             QString name = ucFirst(f.attribute("name"));
             out << "QString " << className << "::" << lcFirst(f.attribute("name")) << "ToString(" << name << " " << f.attribute("name") << ")\n{\n"
-            << "    switch (" << f.attribute("name") << ") {\n";
+                << "    switch (" << f.attribute("name") << ") {\n";
             for (int j = 0; j < enumNodes.size(); j++) {
                 QDomElement en = enumNodes.at(j).toElement();
                 out << "        case " << en.attribute("name") << ": return QString(\"" << en.attribute("name") << "\");\n";
@@ -732,7 +807,7 @@ void processEnumsForImplementation(QDomNodeList fieldList, const QString &classN
     }
 }
 
-void processRecordForImplementation(QDomElement e, QTextStream& out)
+void processRecordForImplementation(QDomElement e, QTextStream &out)
 {
     QString className = e.attribute("name") + "Record";
     bool containsStrings = false;
@@ -746,8 +821,8 @@ void processRecordForImplementation(QDomElement e, QTextStream& out)
 
     // private class
     out << "class " << className << "::Private\n{\n"
-    << "public:\n";
-    foreach(const Field& f, fields) {
+        << "public:\n";
+    foreach (const Field &f, fields) {
         if (f.isArray)
             out << "    std::vector<" << f.type << "> " << f.name << ";\n";
         else if (!f.isStringLength)
@@ -764,8 +839,9 @@ void processRecordForImplementation(QDomElement e, QTextStream& out)
     // constructor
     out << className << "::" << className << "(Swinder::Workbook *book)\n";
     out << "    : Record(book), d(new Private)\n{\n";
-    foreach(const Field& f, fields) {
-        if (f.isArray || f.isStringLength) continue;
+    foreach (const Field &f, fields) {
+        if (f.isArray || f.isStringLength)
+            continue;
         QString val;
         if (!f.defaultValue.isEmpty()) {
             val = f.defaultValue;
@@ -788,13 +864,13 @@ void processRecordForImplementation(QDomElement e, QTextStream& out)
 
     // copy constructor
     out << className << "::" << className << "( const " << className << "& record )\n"
-    << "    : Record(record), d(new Private)\n{\n"
-    << "    *this = record;\n}\n\n";
+        << "    : Record(record), d(new Private)\n{\n"
+        << "    *this = record;\n}\n\n";
 
     // assignment operator
     out << className << "& " << className << "::operator=( const " << className << "& record )\n{\n"
-    << "    *d = *record.d;\n"
-    << "    return *this;\n}\n\n";
+        << "    *d = *record.d;\n"
+        << "    return *this;\n}\n\n";
 
     // enums
     QDomNodeList fieldNodes = e.elementsByTagName("field");
@@ -805,24 +881,30 @@ void processRecordForImplementation(QDomElement e, QTextStream& out)
     processEnumsForImplementation(typeNodes, className, out);
 
     // getters and setters
-    foreach(const Field& f, fields) {
-        if (f.isStringLength) continue;
+    foreach (const Field &f, fields) {
+        if (f.isStringLength)
+            continue;
 
-        if (f.isEnum) out << className << "::";
+        if (f.isEnum)
+            out << className << "::";
         out << f.type << " " << className << "::" << f.getterName() << "(";
-        if (f.isArray) out << " unsigned index ";
+        if (f.isArray)
+            out << " unsigned index ";
         out << ") const\n{\n    return d->" << f.name;
-        if (f.isArray) out << "[index]";
+        if (f.isArray)
+            out << "[index]";
         out << ";\n}\n\n";
 
         out << "void " << className << "::" << f.setterName() << "(";
-        if (f.isArray) out << " unsigned index, ";
+        if (f.isArray)
+            out << " unsigned index, ";
         out << f.type << " " << f.name << " )\n{\n    d->" << f.name;
-        if (f.isArray) out << "[index]";
+        if (f.isArray)
+            out << "[index]";
         out << " = " << f.name << ";\n";
 
         if (f.isArrayLength) {
-            foreach(const Field& af, f.arrayFields) {
+            foreach (const Field &af, f.arrayFields) {
                 out << "    d->" << af.name << ".resize(" << f.name << ");\n";
             }
         }
@@ -834,9 +916,10 @@ void processRecordForImplementation(QDomElement e, QTextStream& out)
     for (int i = 0; i < cfieldNodes.size(); i++) {
         QDomElement f = cfieldNodes.at(i).toElement();
         QString type = f.attribute("ctype");
-        if (type.isEmpty()) type = className + "::" + ucFirst(f.attribute("name"));
+        if (type.isEmpty())
+            type = className + "::" + ucFirst(f.attribute("name"));
         out << type << " " << className << "::" << f.attribute("name") << "() const\n{\n"
-        << "    return " << f.attribute("value") << ";\n}\n\n";
+            << "    return " << f.attribute("value") << ";\n}\n\n";
     }
 
     // array lengths
@@ -848,13 +931,14 @@ void processRecordForImplementation(QDomElement e, QTextStream& out)
             QDomNodeList afields = f.elementsByTagName("field");
             QDomElement af1 = afields.at(0).toElement();
 
-            out << "unsigned " << className << "::" << lcFirst(name)  << "() const\n{\n";
+            out << "unsigned " << className << "::" << lcFirst(name) << "() const\n{\n";
             out << "    return d->" << af1.attribute("name") << ".size();\n}\n\n";
 
             out << "void " << className << "::set" << ucFirst(name) << "( unsigned " << name << " )\n{\n";
             for (int j = 0; j < afields.size(); j++) {
                 QDomElement af = afields.at(j).toElement();
-                if (af.attribute("name").startsWith("reserved")) continue;
+                if (af.attribute("name").startsWith("reserved"))
+                    continue;
                 out << "    d->" << af.attribute("name") << ".resize(" << name << ");\n";
             }
             out << "}\n\n";
@@ -882,7 +966,7 @@ void processRecordForImplementation(QDomElement e, QTextStream& out)
         out << "    unsigned curOffset;\n";
     if (containsStrings) {
         out << "    bool stringLengthError = false;\n"
-        << "    unsigned stringSize;\n";
+            << "    unsigned stringSize;\n";
     }
     unsigned offset = 0;
     bool dynamicOffset = false;
@@ -903,7 +987,7 @@ void processRecordForImplementation(QDomElement e, QTextStream& out)
 
     // dump method
     out << "void " << className << "::dump( std::ostream& out ) const\n{\n"
-    << "    out << \"" << e.attribute("name") << "\" << std::endl;\n";
+        << "    out << \"" << e.attribute("name") << "\" << std::endl;\n";
     for (QDomElement child = e.firstChildElement(); !child.isNull(); child = child.nextSiblingElement())
         processFieldElementForDump("    ", out, child, fieldsMap);
     out << "}\n\n";
@@ -912,8 +996,7 @@ void processRecordForImplementation(QDomElement e, QTextStream& out)
     out << "static Record* create" << className << "(Swinder::Workbook *book)\n{\n    return new " << className << "(book);\n}\n\n";
 }
 
-
-int main(int argc, char** argv)
+int main(int argc, char **argv)
 {
     QCoreApplication app(argc, argv);
 
@@ -932,8 +1015,7 @@ int main(int argc, char** argv)
     if (!doc.setContent(&f, &errorMsg, &errorLine, &errorCol)) {
         f.close();
         errorMsg = "Error parsing file: " + errorMsg + "\n";
-        errorMsg += QLatin1String("In line ")  + QString::number(errorLine)
-                    + QLatin1String(", column ") + QString::number(errorCol);
+        errorMsg += QLatin1String("In line ") + QString::number(errorLine) + QLatin1String(", column ") + QString::number(errorCol);
         qFatal("%s", errorMsg.toLatin1().constData());
     }
     f.close();
@@ -947,18 +1029,18 @@ int main(int argc, char** argv)
     QTextStream cppOut(&cppFile);
 
     hOut << "// This file was automatically generated from records.xml\n"
-    << "#ifndef SWINDER_RECORDS_H\n"
-    << "#define SWINDER_RECORDS_H\n\n"
-    << "#include \"utils.h\"\n\n"
-    << "namespace Swinder {\n\n"
-    << "void registerRecordClasses();\n\n";
+         << "#ifndef SWINDER_RECORDS_H\n"
+         << "#define SWINDER_RECORDS_H\n\n"
+         << "#include \"utils.h\"\n\n"
+         << "namespace Swinder {\n\n"
+         << "void registerRecordClasses();\n\n";
 
     cppOut << "// This file was automatically generated from records.xml\n"
-    << "#include \"records.h\"\n"
-    << "#include <vector>\n"
-    << "#include <iomanip>\n"
-    << "#include \"XlsRecordOutputStream.h\"\n\n"
-    << "namespace Swinder {\n\n";
+           << "#include \"records.h\"\n"
+           << "#include <vector>\n"
+           << "#include <iomanip>\n"
+           << "#include \"XlsRecordOutputStream.h\"\n\n"
+           << "namespace Swinder {\n\n";
 
     QDomNodeList records = doc.elementsByTagName("record");
     for (int i = 0; i < records.size(); i++) {
@@ -967,7 +1049,7 @@ int main(int argc, char** argv)
         processRecordForImplementation(e, cppOut);
     }
 
-    cppOut << "void registerRecordClasses()" << endl << "{" << endl;
+    cppOut << "void registerRecordClasses()" << Qt::endl << "{" << Qt::endl;
     for (int i = 0; i < records.size(); i++) {
         QDomElement e = records.at(i).toElement();
         cppOut << "    RecordRegistry::registerRecordClass(" << e.attribute("name") << "Record::id, create" << e.attribute("name") << "Record);\n";
