@@ -1,22 +1,9 @@
 /* This file is part of the KDE project
-   Copyright (C) 2001 Eva Brucherseifer <eva@kde.org>
-   Copyright (C) 2005 Bram Schoenmakers <bramschoenmakers@kde.nl>
+   SPDX-FileCopyrightText: 2001 Eva Brucherseifer <eva@kde.org>
+   SPDX-FileCopyrightText: 2005 Bram Schoenmakers <bramschoenmakers@kde.nl>
    based on kspread csv export filter by David Faure
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef HTMLEXPORT_TEST_H
@@ -24,6 +11,7 @@
 
 #include <KoFilter.h>
 #include <QByteArray>
+#include <QLoggingCategory>
 #include <QVariantList>
 
 class ExportDialog;
@@ -37,14 +25,17 @@ class Sheet;
 }
 }
 
+Q_DECLARE_LOGGING_CATEGORY(lcHtml)
+
 class HTMLExport : public KoFilter
 {
     Q_OBJECT
 public:
-    HTMLExport(QObject* parent, const QVariantList&);
+    HTMLExport(QObject *parent, const QVariantList &);
     ~HTMLExport() override;
 
-    KoFilter::ConversionStatus convert(const QByteArray& from, const QByteArray& to) override;
+    KoFilter::ConversionStatus convert(const QByteArray &from, const QByteArray &to) override;
+
 private:
     /** Writes the top of the page in HTML to @par str */
     void openPage(Calligra::Sheets::Sheet *sheet, KoDocument *document, QString &str);
@@ -74,6 +65,7 @@ private:
       writes the number of them to @par row and @par column.
      */
     void detectFilledCells(Calligra::Sheets::Sheet *sheet, int &rows, int &columns);
+
 private:
     ExportDialog *m_dialog;
 
@@ -84,4 +76,3 @@ private:
 };
 
 #endif
-
