@@ -1,7 +1,7 @@
 /*
 ** A program to convert the XML rendered by Words into LATEX.
 **
-** Copyright (C) 2000, 2002, 2003 Robert JACOLIN
+** SPDX-FileCopyrightText: 2000, 2002, 2003 Robert JACOLIN
 **
 ** This library is free software; you can redistribute it and/or
 ** modify it under the terms of the GNU Library General Public
@@ -28,7 +28,7 @@
 
 #include <QTextStream>
 
-FileHeader* FileHeader::_instance = 0;
+FileHeader* FileHeader::_instance = nullptr;
 
 /*******************************************/
 /* Constructor                             */
@@ -115,7 +115,7 @@ void FileHeader::generate(QTextStream &out)
     generatePackage(out);
     if (getFormat() == TF_CUSTOM)
         generatePaper(out);
-    out << "%%%%%%%%%%%%%%%%%% END OF PREAMBLE %%%%%%%%%%%%%%%%%%" << endl << endl;
+    out << "%%%%%%%%%%%%%%%%%% END OF PREAMBLE %%%%%%%%%%%%%%%%%%" << Qt::endl << Qt::endl;
 }
 
 /*******************************************/
@@ -123,20 +123,18 @@ void FileHeader::generate(QTextStream &out)
 /*******************************************/
 void FileHeader::generatePaper(QTextStream &out)
 {
-    QString unit;
-
-    out << "% Format of paper" << endl;
+    out << "% Format of paper" << Qt::endl;
     debugLatex << "Generate custom size paper";
     /* paper size */
-    out << "\\setlength{\\paperwidth}{"  << _width  << "pt}" << endl;
-    out << "\\setlength{\\paperheight}{" << _height << "pt}" << endl;
+    out << "\\setlength{\\paperwidth}{"  << _width  << "pt}" << Qt::endl;
+    out << "\\setlength{\\paperheight}{" << _height << "pt}" << Qt::endl;
     /* FileHeader and footer */
-    out << "\\setlength{\\headsep}{" << _headBody << "pt}" << endl;
-    out << "\\setlength{\\footskip}{" << _footBody + _bottomBorder << "pt}" << endl;
+    out << "\\setlength{\\headsep}{" << _headBody << "pt}" << Qt::endl;
+    out << "\\setlength{\\footskip}{" << _footBody + _bottomBorder << "pt}" << Qt::endl;
     /* Margin */
-    out << "\\setlength{\\topmargin}{" << _topBorder << "pt}" << endl;
-    out << "\\setlength{\\textwidth}{" << _width - _rightBorder - _leftBorder << "pt}" << endl;
-    out << endl;
+    out << "\\setlength{\\topmargin}{" << _topBorder << "pt}" << Qt::endl;
+    out << "\\setlength{\\textwidth}{" << _width - _rightBorder - _leftBorder << "pt}" << Qt::endl;
+    out << Qt::endl;
 }
 
 /*******************************************/
@@ -144,11 +142,11 @@ void FileHeader::generatePaper(QTextStream &out)
 /*******************************************/
 void FileHeader::generateLatinPreamble(QTextStream &out)
 {
-    out << "%% Generated by Calligra Sheets. Don't modify this file but the file *.ods." << endl;
-    out << "%% Send an email to rjacolin@ifrance.com for bugs, wishes, .... Thank you." << endl;
-    out << "%% Compile this file with : latex filename.tex" << endl;
-    out << "%% a dvi file will be generated." << endl;
-    out << "%% The file uses the latex style (not the words style). " << endl;
+    out << "%% Generated by Calligra Sheets. Don't modify this file but the file *.ods." << Qt::endl;
+    out << "%% Send an email to rjacolin@ifrance.com for bugs, wishes, .... Thank you." << Qt::endl;
+    out << "%% Compile this file with : latex filename.tex" << Qt::endl;
+    out << "%% a dvi file will be generated." << Qt::endl;
+    out << "%% The file uses the latex style (not the words style). " << Qt::endl;
     out << "\\documentclass[";
     switch (getFormat()) {
     case TF_A3:
@@ -202,8 +200,8 @@ void FileHeader::generateLatinPreamble(QTextStream &out)
     if (Config::instance()->getQuality() == "draft")
         out << ", draft";
     out << "]{";
-    out << Config::instance()->getClass() << "}" << endl;
-    out << "\\usepackage[" << Config::instance()->getEncoding() << "]{inputenc}" << endl << endl;
+    out << Config::instance()->getClass() << "}" << Qt::endl;
+    out << "\\usepackage[" << Config::instance()->getEncoding() << "]{inputenc}" << Qt::endl << Qt::endl;
 }
 
 /*******************************************/
@@ -211,14 +209,14 @@ void FileHeader::generateLatinPreamble(QTextStream &out)
 /*******************************************/
 void FileHeader::generateUnicodePreamble(QTextStream &out)
 {
-    out << "%% Generated by Calligra Sheets. Don't modify this file but the file *.ods." << endl;
-    out << "%% Send an email to rjacolin@ifrance.com for bugs, wishes, .... Thank you." << endl;
-    out << "%% Compile this file with : lambda filename.tex" << endl;
-    out << "%% a dvi file will be generated." << endl;
-    out << "%% Use odvips to convert it and to see it with gv" << endl;
-    out << "%% The file uses the latex style (not the words style). " << endl;
-    out << "\\ocp\\TexUTF=inutf8" << endl;
-    out << "\\InputTranslation currentfile \\TexUTF" << endl;
+    out << "%% Generated by Calligra Sheets. Don't modify this file but the file *.ods." << Qt::endl;
+    out << "%% Send an email to rjacolin@ifrance.com for bugs, wishes, .... Thank you." << Qt::endl;
+    out << "%% Compile this file with : lambda filename.tex" << Qt::endl;
+    out << "%% a dvi file will be generated." << Qt::endl;
+    out << "%% Use odvips to convert it and to see it with gv" << Qt::endl;
+    out << "%% The file uses the latex style (not the words style). " << Qt::endl;
+    out << "\\ocp\\TexUTF=inutf8" << Qt::endl;
+    out << "\\InputTranslation currentfile \\TexUTF" << Qt::endl;
     out << "\\documentclass[";
     switch (getFormat()) {
     case TF_A3:
@@ -272,7 +270,7 @@ void FileHeader::generateUnicodePreamble(QTextStream &out)
     if (Config::instance()->getQuality() == "draft")
         out << ", draft";
     out << "]{";
-    out << Config::instance()->getClass() << "}" << endl;
+    out << Config::instance()->getClass() << "}" << Qt::endl;
 }
 
 
@@ -281,41 +279,41 @@ void FileHeader::generateUnicodePreamble(QTextStream &out)
 /*******************************************/
 void FileHeader::generatePackage(QTextStream &out)
 {
-    out << "% Package(s) to include" << endl;
+    out << "% Package(s) to include" << Qt::endl;
     if (Config::instance()->mustUseUnicode())
-        out << "\\usepackage{omega}" << endl;
+        out << "\\usepackage{omega}" << Qt::endl;
     if (getFormat() == TF_A4)
-        out << "\\usepackage[a4paper]{geometry}" << endl;
+        out << "\\usepackage[a4paper]{geometry}" << Qt::endl;
     if (hasFooter() || hasHeader())
-        out << "\\usepackage{fancyhdr}" << endl;
+        out << "\\usepackage{fancyhdr}" << Qt::endl;
     if (hasColor())
-        out << "\\usepackage{colortbl}" << endl;
+        out << "\\usepackage{colortbl}" << Qt::endl;
     if (hasUnderline())
-        out << "\\usepackage{ulem}" << endl;
+        out << "\\usepackage{ulem}" << Qt::endl;
     if (hasEnumerate())
-        out << "\\usepackage{enumerate}" << endl;
+        out << "\\usepackage{enumerate}" << Qt::endl;
     if (hasGraphics())
-        out << "\\usepackage{graphics}" << endl;
-    out << "\\usepackage{array}" << endl;
-    out << "\\usepackage{multirow}" << endl;
-    out << "\\usepackage{textcomp}" << endl;
-    out << "\\usepackage{rotating}" << endl;
-    out << endl;
+        out << "\\usepackage{graphics}" << Qt::endl;
+    out << "\\usepackage{array}" << Qt::endl;
+    out << "\\usepackage{multirow}" << Qt::endl;
+    out << "\\usepackage{textcomp}" << Qt::endl;
+    out << "\\usepackage{rotating}" << Qt::endl;
+    out << Qt::endl;
     QStringList langs = Config::instance()->getLanguagesList();
     if (langs.count() > 0) {
-        out << "\\usepackage[" << langs.join(", ") << "]{babel}" << endl;
+        out << "\\usepackage[" << langs.join(", ") << "]{babel}" << Qt::endl;
     }
-    out << "\\usepackage{textcomp}" << endl;
-    out << endl;
+    out << "\\usepackage{textcomp}" << Qt::endl;
+    out << Qt::endl;
 
     if (langs.count() > 1)
         out << "\\selectlanguage{" << Config::instance()->getDefaultLanguage()
-        << "}" << endl << endl;
+        << "}" << Qt::endl << Qt::endl;
 }
 
 FileHeader* FileHeader::instance()
 {
-    if (_instance == 0)
+    if (_instance == nullptr)
         _instance = new FileHeader();
     return _instance;
 }
