@@ -1,5 +1,5 @@
 /* This file is part of the wvWare 2 project
-   Copyright (C) 2002-2003 Werner Trobin <trobin@kde.org>
+   SPDX-FileCopyrightText: 2002-2003 Werner Trobin <trobin@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -21,23 +21,21 @@
 
 using namespace wvWare;
 
-
-TableRowData::TableRowData( unsigned int sp, unsigned int so, unsigned int len,
-                            int subDoc, SharedPtr<const Word97::TAP> sharedTap ) :
-    startPiece( sp ), startOffset( so ), length( len ), subDocument( subDoc ), tap( sharedTap )
+TableRowData::TableRowData(unsigned int sp, unsigned int so, unsigned int len, int subDoc, SharedPtr<const Word97::TAP> sharedTap)
+    : startPiece(sp)
+    , startOffset(so)
+    , length(len)
+    , subDocument(subDoc)
+    , tap(sharedTap)
 {
 }
 
-TableRowData::~TableRowData()
+TableRowData::~TableRowData() = default;
+
+PictureData::PictureData(U32 fc, SharedPtr<const Word97::PICF> sharedPicf)
+    : fcPic(fc)
+    , picf(sharedPicf)
 {
 }
 
-
-PictureData::PictureData( U32 fc, SharedPtr<const Word97::PICF> sharedPicf ) :
-    fcPic( fc ), picf( sharedPicf )
-{
-}
-
-PictureData::~PictureData()
-{
-}
+PictureData::~PictureData() = default;
