@@ -1,42 +1,34 @@
 /* This file is part of the KDE project
- * Copyright (C) 2007 Jan Hambrecht <jaham@gmx.net>
+ * SPDX-FileCopyrightText: 2007 Jan Hambrecht <jaham@gmx.net>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "KarbonPathRefineCommand.h"
-#include <KoPathShape.h>
+#include <KLocalizedString>
 #include <KoPathPointData.h>
 #include <KoPathPointInsertCommand.h>
-#include <klocale.h>
-#include <kdebug.h>
+#include <KoPathShape.h>
 
-class KarbonPathRefineCommand::Private {
+class KarbonPathRefineCommand::Private
+{
 public:
-    Private(KoPathShape * p, uint insertPointsCount)
-            : path(p), insertCount(insertPointsCount), initialized(false) {}
-    ~Private() {}
+    Private(KoPathShape *p, uint insertPointsCount)
+        : path(p)
+        , insertCount(insertPointsCount)
+        , initialized(false)
+    {
+    }
+    ~Private() = default;
 
-    KoPathShape * path; ///< the path to refine
-    uint insertCount;   ///< the number of points to insert into segments
-    bool initialized;   ///< tells whether the subcommands are already created
+    KoPathShape *path; ///< the path to refine
+    uint insertCount; ///< the number of points to insert into segments
+    bool initialized; ///< tells whether the subcommands are already created
 };
 
-KarbonPathRefineCommand::KarbonPathRefineCommand(KoPathShape * path, uint insertPointsCount, KUndo2Command *parent)
-        : KUndo2Command(parent), d(new Private(path, insertPointsCount))
+KarbonPathRefineCommand::KarbonPathRefineCommand(KoPathShape *path, uint insertPointsCount, KUndo2Command *parent)
+    : KUndo2Command(parent)
+    , d(new Private(path, insertPointsCount))
 {
     setText(kundo2_i18n("Refine path"));
 }
@@ -49,7 +41,7 @@ KarbonPathRefineCommand::~KarbonPathRefineCommand()
 void KarbonPathRefineCommand::redo()
 {
     // check if we have to create the insert points commands
-    if (! d->initialized) {
+    if (!d->initialized) {
         // create insert point commands, one for each point to insert
         // into each segment
         for (uint iteration = 0; iteration < d->insertCount; ++iteration) {
@@ -71,7 +63,7 @@ void KarbonPathRefineCommand::redo()
                 }
             }
             // create the command and execute it
-            KUndo2Command * cmd = new KoPathPointInsertCommand(pointData, insertPosition, this);
+            KUndo2Command *cmd = new KoPathPointInsertCommand(pointData, insertPosition, this);
             cmd->redo();
         }
         d->initialized = true;
@@ -86,4 +78,3 @@ void KarbonPathRefineCommand::undo()
     KUndo2Command::undo();
     d->path->update();
 }
-
