@@ -1,24 +1,11 @@
 /* This file is part of the KDE project
- * Copyright (C) 2006, 2008 Thomas Zander <zander@kde.org>
- * Copyright (C) 2007-2010 Boudewijn Rempt <boud@valdyas.org>
- * Copyright (C) 2007-2008 C. Boemann <cbo@boemann.dk>
- * Copyright (C) 2006-2007 Jan Hambrecht <jaham@gmx.net>
- * Copyright (C) 2009 Thorsten Zachmann <zachmann@kde.org>
+ * SPDX-FileCopyrightText: 2006, 2008 Thomas Zander <zander@kde.org>
+ * SPDX-FileCopyrightText: 2007-2010 Boudewijn Rempt <boud@valdyas.org>
+ * SPDX-FileCopyrightText: 2007-2008 C. Boemann <cbo@boemann.dk>
+ * SPDX-FileCopyrightText: 2006-2007 Jan Hambrecht <jaham@gmx.net>
+ * SPDX-FileCopyrightText: 2009 Thorsten Zachmann <zachmann@kde.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #ifndef KOCANVASCONTROLLER_H
@@ -27,15 +14,14 @@
 #include "flake_export.h"
 #include <QObject>
 
-#include <QSize>
 #include <QPoint>
 #include <QPointF>
+#include <QSize>
 
 class KActionCollection;
 class QRect;
 class QRectF;
 
-
 class KoShape;
 class KoCanvasBase;
 class KoCanvasControllerProxyObject;
@@ -71,10 +57,10 @@ class FLAKE_EXPORT KoCanvasController
 public:
     /// An enum to alter the positioning and size of the canvas inside the canvas controller
     enum CanvasMode {
-        AlignTop,     ///< canvas is top aligned if smaller than the viewport
-        Centered,     ///< canvas is centered if smaller than the viewport
-        Infinite,     ///< canvas is never smaller than the viewport
-        Spreadsheet   ///< same as Infinite, but supports right-to-left layouts
+        AlignTop, ///< canvas is top aligned if smaller than the viewport
+        Centered, ///< canvas is centered if smaller than the viewport
+        Infinite, ///< canvas is never smaller than the viewport
+        Spreadsheet ///< same as Infinite, but supports right-to-left layouts
     };
 
     // proxy QObject: use this to connect to slots and signals.
@@ -84,7 +70,7 @@ public:
      * Constructor.
      * @param actionCollection the action collection for this canvas
      */
-    explicit KoCanvasController(KActionCollection* actionCollection);
+    explicit KoCanvasController(KActionCollection *actionCollection);
     virtual ~KoCanvasController();
 
 public:
@@ -291,11 +277,11 @@ public:
      */
     virtual void setVastScrolling(qreal factor) = 0;
 
-   /**
+    /**
      * Returns the action collection for the canvas
      * @returns action collection for this canvas, can be 0
      */
-    virtual KActionCollection* actionCollection() const;
+    virtual KActionCollection *actionCollection() const;
 
     QPoint documentOffset() const;
 
@@ -309,15 +295,13 @@ protected:
     void setPreferredCenterFractionY(qreal);
     qreal preferredCenterFractionY() const;
 
-    void setDocumentOffset( QPoint &offset);
-
+    void setDocumentOffset(QPoint &offset);
 
 private:
     class Private;
-    Private * const d;
+    Private *const d;
 };
 
-
 /**
  * Workaround class for the problem that Qt does not allow two QObject base classes.
  * KoCanvasController can be implemented by for instance QWidgets, so it cannot be
@@ -329,24 +313,53 @@ class FLAKE_EXPORT KoCanvasControllerProxyObject : public QObject
     Q_OBJECT
     Q_DISABLE_COPY(KoCanvasControllerProxyObject)
 public:
-    explicit KoCanvasControllerProxyObject(KoCanvasController *canvasController, QObject *parent = 0);
+    explicit KoCanvasControllerProxyObject(KoCanvasController *canvasController, QObject *parent = nullptr);
 
 public:
-
     // Convenience methods to invoke the signals from subclasses
 
-    void emitCanvasRemoved(KoCanvasController *canvasController) { emit canvasRemoved(canvasController); }
-    void emitCanvasSet(KoCanvasController *canvasController) { emit canvasSet(canvasController); }
-    void emitCanvasOffsetXChanged(int offset) { emit canvasOffsetXChanged(offset); }
-    void emitCanvasOffsetYChanged(int offset) { emit canvasOffsetYChanged(offset); }
-    void emitCanvasMousePositionChanged(const QPoint &position) { emit canvasMousePositionChanged(position); }
-    void emitDocumentMousePositionChanged(const QPointF &position) { emit documentMousePositionChanged(position); }
-    void emitSizeChanged(const QSize &size) { emit sizeChanged(size); }
-    void emitMoveDocumentOffset(const QPoint &point) { emit moveDocumentOffset(point); }
-    void emitZoomRelative(const qreal factor, const QPointF &stillPoint) { emit zoomRelative(factor, stillPoint); }
+    void emitCanvasRemoved(KoCanvasController *canvasController)
+    {
+        Q_EMIT canvasRemoved(canvasController);
+    }
+    void emitCanvasSet(KoCanvasController *canvasController)
+    {
+        Q_EMIT canvasSet(canvasController);
+    }
+    void emitCanvasOffsetXChanged(int offset)
+    {
+        Q_EMIT canvasOffsetXChanged(offset);
+    }
+    void emitCanvasOffsetYChanged(int offset)
+    {
+        Q_EMIT canvasOffsetYChanged(offset);
+    }
+    void emitCanvasMousePositionChanged(const QPoint &position)
+    {
+        Q_EMIT canvasMousePositionChanged(position);
+    }
+    void emitDocumentMousePositionChanged(const QPointF &position)
+    {
+        Q_EMIT documentMousePositionChanged(position);
+    }
+    void emitSizeChanged(const QSize &size)
+    {
+        Q_EMIT sizeChanged(size);
+    }
+    void emitMoveDocumentOffset(const QPoint &point)
+    {
+        Q_EMIT moveDocumentOffset(point);
+    }
+    void emitZoomRelative(const qreal factor, const QPointF &stillPoint)
+    {
+        Q_EMIT zoomRelative(factor, stillPoint);
+    }
 
     // Convenience method to retrieve the canvas controller for who needs to use QPointer
-    KoCanvasController *canvasController() const { return m_canvasController; }
+    KoCanvasController *canvasController() const
+    {
+        return m_canvasController;
+    }
 
 Q_SIGNALS:
     /**
@@ -429,43 +442,98 @@ private:
     KoCanvasController *m_canvasController;
 };
 
-class FLAKE_EXPORT  KoDummyCanvasController : public KoCanvasController {
-
+class FLAKE_EXPORT KoDummyCanvasController : public KoCanvasController
+{
 public:
-
-    explicit KoDummyCanvasController(KActionCollection* actionCollection)
+    explicit KoDummyCanvasController(KActionCollection *actionCollection)
         : KoCanvasController(actionCollection)
-    {}
+    {
+    }
 
-    ~KoDummyCanvasController() override
-    {}
-
-
-    void scrollContentsBy(int /*dx*/, int /*dy*/) override {}
-    QSize viewportSize() const override { return QSize(); }
-    void setDrawShadow(bool /*drawShadow*/) override {}
-    void setCanvas(KoCanvasBase *canvas) override {Q_UNUSED(canvas)}
-    KoCanvasBase *canvas() const override {return 0;}
-    int visibleHeight() const override {return 0;}
-    int visibleWidth() const override {return 0;}
-    int canvasOffsetX() const override {return 0;}
-    int canvasOffsetY() const override {return 0;}
-    void ensureVisible(const QRectF &/*rect*/, bool /*smooth */ = false) override {}
-    void ensureVisible(KoShape *shape) override {Q_UNUSED(shape)}
-    void zoomIn(const QPoint &/*center*/) override {}
-    void zoomOut(const QPoint &/*center*/) override {}
-    void zoomBy(const QPoint &/*center*/, qreal /*zoom*/) override {}
-    void zoomTo(const QRect &/*rect*/) override {}
-    void recenterPreferred() override {}
-    void setPreferredCenter(const QPointF &/*viewPoint*/) override {}
-    QPointF preferredCenter() const override {return QPointF();}
-    void pan(const QPoint &/*distance*/) override {}
-    QPoint scrollBarValue() const override {return QPoint();}
-    void setScrollBarValue(const QPoint &/*value*/) override {}
-    void updateDocumentSize(const QSize &/*sz*/, bool /*recalculateCenter*/) override {}
-    void setZoomWithWheel(bool /*zoom*/) override {}
-    void setVastScrolling(qreal /*factor*/) override {}
+    ~KoDummyCanvasController() override = default;
 
+    void scrollContentsBy(int /*dx*/, int /*dy*/) override
+    {
+    }
+    QSize viewportSize() const override
+    {
+        return QSize();
+    }
+    void setDrawShadow(bool /*drawShadow*/) override
+    {
+    }
+    void setCanvas(KoCanvasBase *canvas) override
+    {
+        Q_UNUSED(canvas)
+    }
+    KoCanvasBase *canvas() const override
+    {
+        return nullptr;
+    }
+    int visibleHeight() const override
+    {
+        return 0;
+    }
+    int visibleWidth() const override
+    {
+        return 0;
+    }
+    int canvasOffsetX() const override
+    {
+        return 0;
+    }
+    int canvasOffsetY() const override
+    {
+        return 0;
+    }
+    void ensureVisible(const QRectF & /*rect*/, bool /*smooth */ = false) override
+    {
+    }
+    void ensureVisible(KoShape *shape) override
+    {
+        Q_UNUSED(shape)
+    }
+    void zoomIn(const QPoint & /*center*/) override
+    {
+    }
+    void zoomOut(const QPoint & /*center*/) override
+    {
+    }
+    void zoomBy(const QPoint & /*center*/, qreal /*zoom*/) override
+    {
+    }
+    void zoomTo(const QRect & /*rect*/) override
+    {
+    }
+    void recenterPreferred() override
+    {
+    }
+    void setPreferredCenter(const QPointF & /*viewPoint*/) override
+    {
+    }
+    QPointF preferredCenter() const override
+    {
+        return QPointF();
+    }
+    void pan(const QPoint & /*distance*/) override
+    {
+    }
+    QPoint scrollBarValue() const override
+    {
+        return QPoint();
+    }
+    void setScrollBarValue(const QPoint & /*value*/) override
+    {
+    }
+    void updateDocumentSize(const QSize & /*sz*/, bool /*recalculateCenter*/) override
+    {
+    }
+    void setZoomWithWheel(bool /*zoom*/) override
+    {
+    }
+    void setVastScrolling(qreal /*factor*/) override
+    {
+    }
 };
 
 #endif
