@@ -1,21 +1,8 @@
 /* This file is part of the KDE project
- * Copyright (C) 2007-2008 Thorsten Zachmann <zachmann@kde.org>
- * Copyright (C) 2009 Thomas Zander <zander@kde.org>
+ * SPDX-FileCopyrightText: 2007-2008 Thorsten Zachmann <zachmann@kde.org>
+ * SPDX-FileCopyrightText: 2009 Thomas Zander <zander@kde.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "KoDrag.h"
@@ -30,18 +17,25 @@
 
 #include <FlakeDebug.h>
 
-#include <KoStore.h>
-#include <KoGenStyles.h>
-#include <KoOdfWriteStore.h>
-#include <KoXmlWriter.h>
+#include "KoShapeSavingContext.h"
 #include <KoDocumentBase.h>
 #include <KoEmbeddedDocumentSaver.h>
-#include "KoShapeSavingContext.h"
+#include <KoGenStyles.h>
+#include <KoOdfWriteStore.h>
+#include <KoStore.h>
+#include <KoXmlWriter.h>
 
-class KoDragPrivate {
+class KoDragPrivate
+{
 public:
-    KoDragPrivate() : mimeData(0) { }
-    ~KoDragPrivate() { delete mimeData; }
+    KoDragPrivate()
+        : mimeData(nullptr)
+    {
+    }
+    ~KoDragPrivate()
+    {
+        delete mimeData;
+    }
     QMimeData *mimeData;
 };
 
@@ -58,8 +52,12 @@ KoDrag::~KoDrag()
 bool KoDrag::setOdf(const char *mimeType, KoDragOdfSaveHelper &helper)
 {
     struct Finally {
-        Finally(KoStore *s) : store(s) { }
-        ~Finally() {
+        Finally(KoStore *s)
+            : store(s)
+        {
+        }
+        ~Finally()
+        {
             delete store;
         }
         KoStore *store;
@@ -93,10 +91,9 @@ bool KoDrag::setOdf(const char *mimeType, KoDragOdfSaveHelper &helper)
 
     odfStore.closeContentWriter();
 
-    //add manifest line for content.xml
+    // add manifest line for content.xml
     manifestWriter->addManifestEntry("content.xml", "text/xml");
 
-
     if (!mainStyles.saveOdfStylesDotXml(store, manifestWriter)) {
         return false;
     }
@@ -119,7 +116,7 @@ bool KoDrag::setOdf(const char *mimeType, KoDragOdfSaveHelper &helper)
     }
 
     delete store; // make sure the buffer if fully flushed.
-    finally.store = 0;
+    finally.store = nullptr;
     setData(mimeType, buffer.buffer());
 
     return true;
@@ -127,7 +124,7 @@ bool KoDrag::setOdf(const char *mimeType, KoDragOdfSaveHelper &helper)
 
 void KoDrag::setData(const QString &mimeType, const QByteArray &data)
 {
-    if (d->mimeData == 0) {
+    if (d->mimeData == nullptr) {
         d->mimeData = new QMimeData();
     }
     d->mimeData->setData(mimeType, data);
@@ -137,13 +134,13 @@ void KoDrag::addToClipboard()
 {
     if (d->mimeData) {
         QApplication::clipboard()->setMimeData(d->mimeData);
-        d->mimeData = 0;
+        d->mimeData = nullptr;
     }
 }
 
-QMimeData * KoDrag::mimeData()
+QMimeData *KoDrag::mimeData()
 {
     QMimeData *mimeData = d->mimeData;
-    d->mimeData = 0;
+    d->mimeData = nullptr;
     return mimeData;
 }
