@@ -1,29 +1,16 @@
 /* This file is part of the KDE project
- * Copyright (C) 2006 Jan Hambrecht <jaham@gmx.net>
- * Copyright (C) 2006,2007 Thorsten Zachmann <zachmann@kde.org>
+ * SPDX-FileCopyrightText: 2006 Jan Hambrecht <jaham@gmx.net>
+ * SPDX-FileCopyrightText: 2006, 2007 Thorsten Zachmann <zachmann@kde.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #ifndef KOPATHBREAKATPOINTCOMMAND_H
 #define KOPATHBREAKATPOINTCOMMAND_H
 
-#include <kundo2command.h>
-#include <QList>
 #include "KoPathPointData.h"
+#include <QList>
+#include <kundo2command.h>
 
 class KoPathPoint;
 
@@ -40,7 +27,7 @@ public:
      * @param pointDataList List of point data where the path should be split.
      * @param parent the parent command used for macro commands
      */
-    explicit KoPathBreakAtPointCommand(const QList<KoPathPointData> &pointDataList, KUndo2Command *parent = 0);
+    explicit KoPathBreakAtPointCommand(const QList<KoPathPointData> &pointDataList, KUndo2Command *parent = nullptr);
     ~KoPathBreakAtPointCommand() override;
 
     /// redo the command
@@ -50,7 +37,7 @@ public:
 
 private:
     QList<KoPathPointData> m_pointDataList;
-    QList<KoPathPoint*> m_points;
+    QList<KoPathPoint *> m_points;
     // used for storing where to open the subpath. In case it not used for the open
     // status use .second to the store offset caused by a open of a subpath.
     QVector<KoPathPointIndex> m_closedIndex;
