@@ -1,55 +1,39 @@
 /* This file is part of the KDE project
- * Copyright (C) 2006,2009 Jan Hambrecht <jaham@gmx.net>
- * Copyright (C) 2006,2007 Thorsten Zachmann <zachmann@kde.org>
+ * SPDX-FileCopyrightText: 2006, 2009 Jan Hambrecht <jaham@gmx.net>
+ * SPDX-FileCopyrightText: 2006, 2007 Thorsten Zachmann <zachmann@kde.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "KoPathSegmentTypeCommand.h"
 
+#include <KLocalizedString>
 #include <KoPathSegment.h>
-#include <klocale.h>
 
-KoPathSegmentTypeCommand::KoPathSegmentTypeCommand(const KoPathPointData & pointData, SegmentType segmentType, KUndo2Command *parent)
-: KUndo2Command(parent)
-, m_segmentType(segmentType)
+KoPathSegmentTypeCommand::KoPathSegmentTypeCommand(const KoPathPointData &pointData, SegmentType segmentType, KUndo2Command *parent)
+    : KUndo2Command(parent)
+    , m_segmentType(segmentType)
 {
     QList<KoPathPointData> pointDataList;
     pointDataList.append(pointData);
     initialize(pointDataList);
 }
 
-KoPathSegmentTypeCommand::KoPathSegmentTypeCommand(const QList<KoPathPointData> & pointDataList, SegmentType segmentType,
-        KUndo2Command *parent)
-        : KUndo2Command(parent)
-        , m_segmentType(segmentType)
+KoPathSegmentTypeCommand::KoPathSegmentTypeCommand(const QList<KoPathPointData> &pointDataList, SegmentType segmentType, KUndo2Command *parent)
+    : KUndo2Command(parent)
+    , m_segmentType(segmentType)
 {
     initialize(pointDataList);
 }
 
-KoPathSegmentTypeCommand::~KoPathSegmentTypeCommand()
-{
-}
+KoPathSegmentTypeCommand::~KoPathSegmentTypeCommand() = default;
 
 void KoPathSegmentTypeCommand::redo()
 {
     KUndo2Command::redo();
     QList<KoPathPointData>::const_iterator it(m_pointDataList.constBegin());
     for (; it != m_pointDataList.constEnd(); ++it) {
-        KoPathShape * pathShape = it->pathShape;
+        KoPathShape *pathShape = it->pathShape;
         pathShape->update();
 
         KoPathSegment segment = pathShape->segmentByIndex(it->pointIndex);
@@ -74,7 +58,7 @@ void KoPathSegmentTypeCommand::undo()
 {
     KUndo2Command::undo();
     for (int i = 0; i < m_pointDataList.size(); ++i) {
-        const KoPathPointData & pd = m_pointDataList.at(i);
+        const KoPathPointData &pd = m_pointDataList.at(i);
         pd.pathShape->update();
         KoPathSegment segment = pd.pathShape->segmentByIndex(pd.pointIndex);
         const SegmentTypeData segmentData(m_segmentData.at(i));
@@ -97,7 +81,7 @@ void KoPathSegmentTypeCommand::undo()
     }
 }
 
-void KoPathSegmentTypeCommand::initialize(const QList<KoPathPointData> & pointDataList)
+void KoPathSegmentTypeCommand::initialize(const QList<KoPathPointData> &pointDataList)
 {
     QList<KoPathPointData>::const_iterator it(pointDataList.begin());
     for (; it != pointDataList.end(); ++it) {
@@ -109,14 +93,14 @@ void KoPathSegmentTypeCommand::initialize(const QList<KoPathPointData> & pointDa
                     continue;
             } else {
                 // do not change segment if already a line
-                if (! segment.first()->activeControlPoint2() && ! segment.second()->activeControlPoint1())
+                if (!segment.first()->activeControlPoint2() && !segment.second()->activeControlPoint1())
                     continue;
             }
 
             m_pointDataList.append(*it);
             SegmentTypeData segmentData;
 
-            KoPathShape * pathShape = segment.first()->parent();
+            KoPathShape *pathShape = segment.first()->parent();
 
             // we are changing a curve to a line -> save control point positions
             if (m_segmentType == Line) {
