@@ -1,44 +1,32 @@
 /* This file is part of the KDE project
- * Copyright (C) 2006 Thomas Zander <zander@kde.org>
- * Copyright (C) 2006 Jan Hambrecht <jaham@gmx.net>
+ * SPDX-FileCopyrightText: 2006 Thomas Zander <zander@kde.org>
+ * SPDX-FileCopyrightText: 2006 Jan Hambrecht <jaham@gmx.net>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "KoShapeMoveCommand.h"
 
 #include <KoShape.h>
+#include <KoShapeAnchor.h>
 #include <KoShapeContainer.h>
 #include <KoShapeContainerModel.h>
-#include <KoShapeAnchor.h>
 
-#include <klocalizedstring.h>
+#include <KLocalizedString>
 
 class Q_DECL_HIDDEN KoShapeMoveCommand::Private
 {
 public:
-    QList<KoShape*> shapes;
+    QList<KoShape *> shapes;
     QVector<QPointF> previousPositions, newPositions, previousOffsets, newOffsets;
 };
 
-KoShapeMoveCommand::KoShapeMoveCommand(const QList<KoShape*> &shapes,
-                                       const QVector<QPointF> &previousPositions, const QVector<QPointF> &newPositions,
+KoShapeMoveCommand::KoShapeMoveCommand(const QList<KoShape *> &shapes,
+                                       const QVector<QPointF> &previousPositions,
+                                       const QVector<QPointF> &newPositions,
                                        KUndo2Command *parent)
-    : KUndo2Command(parent),
-    d(new Private())
+    : KUndo2Command(parent)
+    , d(new Private())
 {
     d->shapes = shapes;
     d->previousPositions = previousPositions;
@@ -49,12 +37,14 @@ KoShapeMoveCommand::KoShapeMoveCommand(const QList<KoShape*> &shapes,
     setText(kundo2_i18n("Move shapes"));
 }
 
-KoShapeMoveCommand::KoShapeMoveCommand(const QList<KoShape*> &shapes,
-                                       const QVector<QPointF> &previousPositions, const QVector<QPointF> &newPositions,
-                                       const QVector<QPointF> &previousOffsets, const QVector<QPointF> &newOffsets,
+KoShapeMoveCommand::KoShapeMoveCommand(const QList<KoShape *> &shapes,
+                                       const QVector<QPointF> &previousPositions,
+                                       const QVector<QPointF> &newPositions,
+                                       const QVector<QPointF> &previousOffsets,
+                                       const QVector<QPointF> &newOffsets,
                                        KUndo2Command *parent)
-        : KUndo2Command(parent),
-        d(new Private())
+    : KUndo2Command(parent)
+    , d(new Private())
 {
     d->shapes = shapes;
     d->previousPositions = previousPositions;
