@@ -1,24 +1,11 @@
 /* This file is part of the KDE project
- * Copyright (C) 2010 Matus Talcik <matus.talcik@gmail.com>
+ * SPDX-FileCopyrightText: 2010 Matus Talcik <matus.talcik@gmail.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 /****************************************************************************
 **
-** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
+** SPDX-FileCopyrightText: 2010 Nokia Corporation and /or its subsidiary(-ies).
 ** All rights reserved.
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
@@ -78,10 +65,10 @@ class KUNDO2_EXPORT KUndo2View : public QListView
     Q_PROPERTY(QIcon cleanIcon READ cleanIcon WRITE setCleanIcon)
 
 public:
-    explicit KUndo2View(QWidget *parent = 0);
-    explicit KUndo2View(KUndo2QStack *stack, QWidget *parent = 0);
+    explicit KUndo2View(QWidget *parent = nullptr);
+    explicit KUndo2View(KUndo2QStack *stack, QWidget *parent = nullptr);
 #ifndef QT_NO_UNDOGROUP
-    explicit KUndo2View(KUndo2Group *group, QWidget *parent = 0);
+    explicit KUndo2View(KUndo2Group *group, QWidget *parent = nullptr);
 #endif
     ~KUndo2View() override;
 
@@ -103,7 +90,7 @@ public Q_SLOTS:
 #endif
 
 private:
-    KUndo2ViewPrivate* const d;
+    KUndo2ViewPrivate *const d;
     Q_DISABLE_COPY(KUndo2View)
 };
 
