@@ -1,25 +1,10 @@
 /* This file is part of the KDE project
  *
- * Copyright (c) 2010 Arjen Hiemstra <ahiemstra@heimr.nl>
+ * SPDX-FileCopyrightText: 2010 Arjen Hiemstra <ahiemstra@heimr.nl>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
-
-
 #include "KoFindMatch.h"
 
 #include <QVariant>
@@ -27,13 +12,11 @@
 class Q_DECL_HIDDEN KoFindMatch::Private : public QSharedData
 {
 public:
-    Private() { }
-    ~Private() { }
+    Private() = default;
+    ~Private() = default;
     Private(const Private &other)
-            : QSharedData(other),
-            container(other.container),
-            location(other.location)
-    { }
+
+        = default;
 
     QVariant container;
     QVariant location;
@@ -52,19 +35,12 @@ KoFindMatch::KoFindMatch(const QVariant &container, const QVariant &location)
 }
 
 KoFindMatch::KoFindMatch(const KoFindMatch &other)
-    : d(other.d)
-{
-}
 
-KoFindMatch::~KoFindMatch()
-{
-}
+    = default;
 
-KoFindMatch &KoFindMatch::operator=(const KoFindMatch &other)
-{
-    d = other.d;
-    return *this;
-}
+KoFindMatch::~KoFindMatch() = default;
+
+KoFindMatch &KoFindMatch::operator=(const KoFindMatch &other) = default;
 
 bool KoFindMatch::operator==(const KoFindMatch &other) const
 {
@@ -95,4 +71,3 @@ void KoFindMatch::setLocation(const QVariant &location)
 {
     d->location = location;
 }
-
