@@ -1,27 +1,14 @@
 /* This file is part of the KDE project
- * Copyright (C) 2011 Smit Patel <smitpatel24@gmail.com>
+ * SPDX-FileCopyrightText: 2011 Smit Patel <smitpatel24@gmail.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 #ifndef KOODFBIBLIOGRAPHYCONFIGURATION_H
 #define KOODFBIBLIOGRAPHYCONFIGURATION_H
 
-#include <QString>
 #include <QMetaType>
 #include <QObject>
+#include <QString>
 
 #include "KoXmlReader.h"
 #include "koodf_export.h"
@@ -43,9 +30,8 @@ class KOODF_EXPORT KoOdfBibliographyConfiguration : public QObject
 {
     Q_OBJECT
 public:
-
     KoOdfBibliographyConfiguration();
-    ~KoOdfBibliographyConfiguration();
+    ~KoOdfBibliographyConfiguration() override;
     KoOdfBibliographyConfiguration(const KoOdfBibliographyConfiguration &other);
     KoOdfBibliographyConfiguration &operator=(const KoOdfBibliographyConfiguration &other);
 
@@ -60,7 +46,7 @@ public:
     /**
      * save the bibliography-configuration element
      */
-    void saveOdf(KoXmlWriter * writer) const;
+    void saveOdf(KoXmlWriter *writer) const;
 
     /**
      * Sort by position
@@ -71,7 +57,7 @@ public:
     void setSortByPosition(bool enable);
 
     /**
-     * Numberred entries
+     * Numbered entries
      * If text:numbered-entries attribute is true then bibliography entries or citations will be numbered.
      */
     bool numberedEntries() const;
@@ -106,12 +92,10 @@ public:
     void setSortKeys(const QVector<SortKeyPair> &sortKeys);
 
 private:
-
     class Private;
-    Private * const d;
-
+    Private *const d;
 };
 
-Q_DECLARE_METATYPE(KoOdfBibliographyConfiguration*)
+Q_DECLARE_METATYPE(KoOdfBibliographyConfiguration *)
 
 #endif // KOODFBIBLIOGRAPHYCONFIGURATION_H
