@@ -1,20 +1,7 @@
 /* This file is part of the KDE project
-   Copyright (C) 2010 KO GmbH <ben.martin@kogmbh.com>
+   SPDX-FileCopyrightText: 2010 KO GmbH <ben.martin@kogmbh.com>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef __rdf_KoRdfSemanticItem_h__
@@ -58,7 +45,7 @@ public:
     KoRdfSemanticItem(QObject *parent, const KoDocumentRdf *rdf, Soprano::QueryResultIterator &it);
     virtual ~KoRdfSemanticItem();
 
-    static QList<hKoRdfSemanticItem> fromList(const QList< hKoRdfBasicSemanticItem > &lst);
+    static QList<hKoRdfSemanticItem> fromList(const QList<hKoRdfBasicSemanticItem> &lst);
 
 protected:
     /**
@@ -88,7 +75,7 @@ public:
      * SemanticItems because the returned widgetItem can also create a
      * menu and perform other actions for the SemanticItem.
      */
-    virtual KoRdfSemanticTreeWidgetItem *createQTreeWidgetItem(QTreeWidgetItem *parent = 0);
+    virtual KoRdfSemanticTreeWidgetItem *createQTreeWidgetItem(QTreeWidgetItem *parent = nullptr);
 
     /**
      * Insert the SemanticItem into the document at the current cursor
