@@ -1,39 +1,26 @@
 /* This file is part of the KDE project
  *
- * Copyright (c) 2011 Boudewijn Rempt <boud@kogmbh.com>
- * Copyright (c) 2012 C. Boemann <cbo@kogmbh.com>
+ * SPDX-FileCopyrightText: 2011 Boudewijn Rempt <boud@kogmbh.com>
+ * SPDX-FileCopyrightText: 2012 C. Boemann <cbo@kogmbh.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 #include "TestKoDocumentRdf.h"
 
-#include <QTest>
-#include <QUuid>
 #include <QString>
+#include <QTest>
+#include <QTextCharFormat>
 #include <QTextDocument>
 #include <QTextTable>
-#include <QTextCharFormat>
+#include <QUuid>
 
-#include <KoRdfSemanticItem.h>
-#include <KoDocumentRdf.h>
-#include <KoTextEditor.h>
 #include <KoBookmark.h>
-#include <KoTextInlineRdf.h>
-#include <KoTextDocument.h>
+#include <KoDocumentRdf.h>
 #include <KoInlineTextObjectManager.h>
+#include <KoRdfSemanticItem.h>
+#include <KoTextDocument.h>
+#include <KoTextEditor.h>
+#include <KoTextInlineRdf.h>
 
 const QString lorem(
     "Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor"
@@ -41,8 +28,7 @@ const QString lorem(
     "exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.\n"
     "Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla"
     "pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia"
-    "deserunt mollit anim id est laborum.\n"
-    );
+    "deserunt mollit anim id est laborum.\n");
 
 void TestKoDocumentRdf::testCreate()
 {
