@@ -1,20 +1,7 @@
 /* This file is part of the KDE project
- * Copyright (C) 2006 Thomas Zander <zander@kde.org>
+ * SPDX-FileCopyrightText: 2006 Thomas Zander <zander@kde.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #ifndef KOINLINEOBJECTFACTORY_H
@@ -31,8 +18,8 @@ class KoProperties;
 
 /// A template used in the KoInlineObjectFactoryBase
 struct KOTEXT_EXPORT KoInlineObjectTemplate {
-    QString id;         ///< The id of the inlineObject
-    QString name;       ///< The name to be shown for this template
+    QString id; ///< The id of the inlineObject
+    QString name; ///< The name to be shown for this template
     /**
      * The properties which, when passed to the KoInlineObjectFactoryBase::createInlineObject() method
      * result in the object this template represents.
@@ -54,8 +41,8 @@ class KOTEXT_EXPORT KoInlineObjectFactoryBase
 public:
     /// The type of inlineObject this factory creates.
     enum ObjectType {
-        TextVariable,   ///< The factory creates KoVariable inheriting objects.
-        Other = 0x100  ///< The factory creates objects that should not be shown in any menu
+        TextVariable, ///< The factory creates KoVariable inheriting objects.
+        Other = 0x100 ///< The factory creates objects that should not be shown in any menu
     };
 
     /**
@@ -69,7 +56,7 @@ public:
     /**
      * Create a new instance of an inline object.
      */
-    virtual KoInlineObject *createInlineObject(const KoProperties *properties = 0) const = 0;
+    virtual KoInlineObject *createInlineObject(const KoProperties *properties = nullptr) const = 0;
 
     /**
      * return the id for the variable this factory creates.
@@ -104,7 +91,7 @@ protected:
     void addTemplate(const KoInlineObjectTemplate &params);
 
 private:
-    InlineObjectFactoryPrivate * const d;
+    InlineObjectFactoryPrivate *const d;
 };
 
 #endif
