@@ -26,7 +26,10 @@ class KOTEXT_EXPORT KoList : public QObject
 {
     Q_OBJECT
 public:
-    enum Type { TextList, NumberedParagraph };
+    enum Type {
+        TextList,
+        NumberedParagraph
+    };
 
     /// Constructor
     KoList(const QTextDocument *document, KoListStyle *style, Type type = TextList);
