@@ -1,42 +1,29 @@
 /*
- *  Copyright (c) 2012 C. Boemann <cbo@boemann.dk>
+ *  SPDX-FileCopyrightText: 2012 C. Boemann <cbo@boemann.dk>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
 #include "ChangeStylesCommand.h"
 
 #include "KoList.h"
 
-#include <KoStyleManager.h>
 #include <KoCharacterStyle.h>
 #include <KoParagraphStyle.h>
+#include <KoStyleManager.h>
 #include <KoTextDocument.h>
 #include <KoTextEditor.h>
 
-#include <QTextDocument>
-#include <QTextCursor>
 #include <QTextBlock>
+#include <QTextCursor>
+#include <QTextDocument>
 
-ChangeStylesCommand::ChangeStylesCommand(QTextDocument *qDoc
-        , const QList<KoCharacterStyle *> &origCharacterStyles
-        , const QList<KoParagraphStyle *> &origParagraphStyles
-        , const QSet<int> &changedStyles
-        , KUndo2Command *parent)
-    : KUndo2Command(kundo2_noi18n("stylechangecommand"),parent)
+ChangeStylesCommand::ChangeStylesCommand(QTextDocument *qDoc,
+                                         const QList<KoCharacterStyle *> &origCharacterStyles,
+                                         const QList<KoParagraphStyle *> &origParagraphStyles,
+                                         const QSet<int> &changedStyles,
+                                         KUndo2Command *parent)
+    : KUndo2Command(kundo2_noi18n("stylechangecommand"), parent)
     , m_origCharacterStyles(origCharacterStyles)
     , m_origParagraphStyles(origParagraphStyles)
     , m_changedStyles(changedStyles)
@@ -64,7 +51,7 @@ ChangeStylesCommand::ChangeStylesCommand(QTextDocument *qDoc
         }
 
         bool blockChanged = false;
-        int id =  block.blockFormat().intProperty(KoParagraphStyle::StyleId);
+        int id = block.blockFormat().intProperty(KoParagraphStyle::StyleId);
         if (id > 0 && changedStyles.contains(id)) {
             KoParagraphStyle *style = sm->paragraphStyle(id);
             Q_ASSERT(style);
@@ -119,9 +106,7 @@ ChangeStylesCommand::ChangeStylesCommand(QTextDocument *qDoc
     delete memento; // we always have one that is unused
 }
 
-ChangeStylesCommand::~ChangeStylesCommand()
-{
-}
+ChangeStylesCommand::~ChangeStylesCommand() = default;
 
 void ChangeStylesCommand::redo()
 {
@@ -132,8 +117,7 @@ void ChangeStylesCommand::redo()
         KoStyleManager *sm = KoTextDocument(m_document).styleManager();
 
         QTextCursor cursor(m_document);
-        foreach (Memento *memento, m_mementos) {
-
+        for (Memento *memento : std::as_const(m_mementos)) {
             cursor.setPosition(memento->blockPosition);
             QTextBlock block = cursor.block();
 
@@ -165,7 +149,7 @@ void ChangeStylesCommand::redo()
 
             QList<QTextCharFormat>::ConstIterator fmtIt = memento->fragmentDirectFormats.constBegin();
             QList<int>::ConstIterator idIt = memento->fragmentStyleId.constBegin();
-            foreach(QTextCursor fragCursor, memento->fragmentCursors) {
+            for (QTextCursor fragCursor : std::as_const(memento->fragmentCursors)) {
                 QTextCharFormat cf(block.charFormat()); // start with block formatting
 
                 if (*idIt > 0) {
@@ -175,7 +159,7 @@ void ChangeStylesCommand::redo()
                     }
                 }
 
-                cf.merge(*fmtIt); //apply direct formatting
+                cf.merge(*fmtIt); // apply direct formatting
 
                 fragCursor.setCharFormat(cf);
 
@@ -193,14 +177,13 @@ void ChangeStylesCommand::undo()
     KUndo2Command::undo();
 }
 
-
 void ChangeStylesCommand::clearCommonProperties(QTextFormat *firstFormat, const QTextFormat &secondFormat)
 {
     Q_ASSERT(firstFormat);
-    foreach(int key, secondFormat.properties().keys()) {
+    const auto properties = secondFormat.properties().keys();
+    for (int key : properties) {
         if (firstFormat->property(key) == secondFormat.property(key)) {
             firstFormat->clearProperty(key);
         }
     }
 }
-
