@@ -1,51 +1,38 @@
 /* This file is part of the KDE project
- * Copyright (C) 2006-2010 Thomas Zander <zander@kde.org>
- * Copyright (C) 2008 Thorsten Zachmann <zachmann@kde.org>
- * Copyright (C) 2008 Roopesh Chander <roop@forwardbias.in>
- * Copyright (C) 2008 Girish Ramakrishnan <girish@forwardbias.in>
- * Copyright (C) 2009 KO GmbH <cbo@kogmbh.com>
- * Copyright (C) 2011 Pierre Ducroquet <pinaraf@pinaraf.info>
+ * SPDX-FileCopyrightText: 2006-2010 Thomas Zander <zander@kde.org>
+ * SPDX-FileCopyrightText: 2008 Thorsten Zachmann <zachmann@kde.org>
+ * SPDX-FileCopyrightText: 2008 Roopesh Chander <roop@forwardbias.in>
+ * SPDX-FileCopyrightText: 2008 Girish Ramakrishnan <girish@forwardbias.in>
+ * SPDX-FileCopyrightText: 2009 KO GmbH <cbo@kogmbh.com>
+ * SPDX-FileCopyrightText: 2011 Pierre Ducroquet <pinaraf@pinaraf.info>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 #include "KoTableCellStyle.h"
 #include "KoTableCellStyle_p.h"
 
 #include <KoXmlReaderForward.h>
 
-#include <KoGenStyle.h>
-#include <KoShapeLoadingContext.h>
-#include <KoOdfGraphicStyles.h>
 #include "KoParagraphStyle.h"
+#include <KoGenStyle.h>
+#include <KoOdfGraphicStyles.h>
+#include <KoShapeLoadingContext.h>
 
 #include <KoTextDebug.h>
 
-#include <QTextTableFormat>
 #include <QTextTableCell>
+#include <QTextTableFormat>
 
-#include <KoUnit.h>
-#include <KoStyleStack.h>
 #include <KoOdfLoadingContext.h>
+#include <KoStyleStack.h>
+#include <KoUnit.h>
 #include <KoXmlNS.h>
 
 #include "TextDebug.h"
 
 #include <cfloat>
 
-KoTableCellStyle::RotationAlignment rotationAlignmentFromString(const QString& align)
+KoTableCellStyle::RotationAlignment rotationAlignmentFromString(const QString &align)
 {
     if (align == "bottom")
         return KoTableCellStyle::RAlignBottom;
@@ -53,7 +40,7 @@ KoTableCellStyle::RotationAlignment rotationAlignmentFromString(const QString& a
         return KoTableCellStyle::RAlignCenter;
     if (align == "top")
         return KoTableCellStyle::RAlignTop;
-    
+
     return KoTableCellStyle::RAlignNone;
 }
 
@@ -69,15 +56,13 @@ QString rotationAlignmentToString(KoTableCellStyle::RotationAlignment align)
 }
 
 KoTableCellStylePrivate::KoTableCellStylePrivate()
-    : paragraphStyle(0)
-    , parentStyle(0)
+    : paragraphStyle(nullptr)
+    , parentStyle(nullptr)
     , next(0)
 {
 }
 
-KoTableCellStylePrivate::~KoTableCellStylePrivate()
-{
-}
+KoTableCellStylePrivate::~KoTableCellStylePrivate() = default;
 
 void KoTableCellStylePrivate::setProperty(int key, const QVariant &value)
 {
@@ -102,7 +87,7 @@ KoTableCellStyle::KoTableCellStyle(const QTextTableCellFormat &format, QObject *
 }
 
 KoTableCellStyle::KoTableCellStyle(const KoTableCellStyle &other)
-    :QObject(other.parent())
+    : QObject(other.parent())
     , d_ptr(new KoTableCellStylePrivate)
 {
     Q_D(KoTableCellStyle);
@@ -111,7 +96,7 @@ KoTableCellStyle::KoTableCellStyle(const KoTableCellStyle &other)
     d->paragraphStyle = other.paragraphStyle()->clone(this);
 }
 
-KoTableCellStyle& KoTableCellStyle::operator=(const KoTableCellStyle &other)
+KoTableCellStyle &KoTableCellStyle::operator=(const KoTableCellStyle &other)
 {
     Q_D(KoTableCellStyle);
 
@@ -144,11 +129,11 @@ QTextCharFormat KoTableCellStyle::cleanCharFormat(const QTextCharFormat &charFor
         QMap<int, QVariant>::const_iterator it = props.begin();
         while (it != props.end()) {
             // lets save all Qt's table cell properties
-            if (it.key()>=QTextFormat::TableCellRowSpan && it.key()<QTextFormat::ImageName)
+            if (it.key() >= QTextFormat::TableCellRowSpan && it.key() < QTextFormat::ImageName)
                 format.setProperty(it.key(), it.value());
 
             // lets save all our table cell properties
-            if (it.key()>=StyleId && it.key()<LastCellStyleProperty)
+            if (it.key() >= StyleId && it.key() < LastCellStyleProperty)
                 format.setProperty(it.key(), it.value());
 
             ++it;
@@ -166,11 +151,10 @@ QRectF KoTableCellStyle::contentRect(const QRectF &boundingRect) const
     const KoBorder::BorderData &bottomEdge = getEdge(KoBorder::BottomBorder);
 
     return boundingRect.adjusted(
-                leftEdge.outerPen.widthF() + leftEdge.spacing + leftEdge.innerPen.widthF() + propertyDouble(QTextFormat::TableCellLeftPadding),
-                topEdge.outerPen.widthF() + topEdge .spacing + topEdge .innerPen.widthF() + propertyDouble(QTextFormat::TableCellTopPadding),
-                - rightEdge.outerPen.widthF() - rightEdge.spacing - rightEdge.innerPen.widthF() - propertyDouble(QTextFormat::TableCellRightPadding),
-                - bottomEdge.outerPen.widthF() - bottomEdge.spacing - bottomEdge.innerPen.widthF() - propertyDouble(QTextFormat::TableCellBottomPadding)
-   );
+        leftEdge.outerPen.widthF() + leftEdge.spacing + leftEdge.innerPen.widthF() + propertyDouble(QTextFormat::TableCellLeftPadding),
+        topEdge.outerPen.widthF() + topEdge.spacing + topEdge.innerPen.widthF() + propertyDouble(QTextFormat::TableCellTopPadding),
+        -rightEdge.outerPen.widthF() - rightEdge.spacing - rightEdge.innerPen.widthF() - propertyDouble(QTextFormat::TableCellRightPadding),
+        -bottomEdge.outerPen.widthF() - bottomEdge.spacing - bottomEdge.innerPen.widthF() - propertyDouble(QTextFormat::TableCellBottomPadding));
 }
 
 QRectF KoTableCellStyle::boundingRect(const QRectF &contentRect) const
@@ -181,11 +165,10 @@ QRectF KoTableCellStyle::boundingRect(const QRectF &contentRect) const
     const KoBorder::BorderData &bottomEdge = getEdge(KoBorder::BottomBorder);
 
     return contentRect.adjusted(
-                - leftEdge.outerPen.widthF() - leftEdge.spacing - leftEdge.innerPen.widthF() - propertyDouble(QTextFormat::TableCellLeftPadding),
-                - topEdge.outerPen.widthF() - topEdge.spacing - topEdge.innerPen.widthF() - propertyDouble(QTextFormat::TableCellTopPadding),
-                rightEdge.outerPen.widthF() + rightEdge.spacing + rightEdge.innerPen.widthF() + propertyDouble(QTextFormat::TableCellRightPadding),
-                bottomEdge.outerPen.widthF() + bottomEdge.spacing + bottomEdge.innerPen.widthF() + propertyDouble(QTextFormat::TableCellBottomPadding)
-   );
+        -leftEdge.outerPen.widthF() - leftEdge.spacing - leftEdge.innerPen.widthF() - propertyDouble(QTextFormat::TableCellLeftPadding),
+        -topEdge.outerPen.widthF() - topEdge.spacing - topEdge.innerPen.widthF() - propertyDouble(QTextFormat::TableCellTopPadding),
+        rightEdge.outerPen.widthF() + rightEdge.spacing + rightEdge.innerPen.widthF() + propertyDouble(QTextFormat::TableCellRightPadding),
+        bottomEdge.outerPen.widthF() + bottomEdge.spacing + bottomEdge.innerPen.widthF() + propertyDouble(QTextFormat::TableCellBottomPadding));
 }
 
 void KoTableCellStyle::setParentStyle(KoTableCellStyle *parent)
@@ -360,7 +343,7 @@ void KoTableCellStyle::applyStyle(QTextTableCellFormat &format) const
             parentBorder.setBorderData(KoBorder::BltrBorder, childBorder.borderData(KoBorder::BltrBorder));
         if (childBorder.hasBorder(KoBorder::TlbrBorder))
             parentBorder.setBorderData(KoBorder::TlbrBorder, childBorder.borderData(KoBorder::TlbrBorder));
-        format.setProperty(Borders, QVariant::fromValue<KoBorder>(parentBorder));
+        format.setProperty(Borders, QVariant::fromValue(parentBorder));
     }
 }
 
@@ -410,7 +393,7 @@ bool KoTableCellStyle::wrap() const
 
 void KoTableCellStyle::setAlignment(Qt::Alignment alignment)
 {
-    setProperty(VerticalAlignment, (int) alignment);
+    setProperty(VerticalAlignment, (int)alignment);
 }
 
 Qt::Alignment KoTableCellStyle::alignment() const
@@ -438,7 +421,7 @@ void KoTableCellStyle::setName(const QString &name)
     if (name == d->name)
         return;
     d->name = name;
-    emit nameChanged(name);
+    Q_EMIT nameChanged(name);
 }
 
 int KoTableCellStyle::styleId() const
@@ -449,7 +432,9 @@ int KoTableCellStyle::styleId() const
 void KoTableCellStyle::setStyleId(int id)
 {
     Q_D(KoTableCellStyle);
-    setProperty(StyleId, id); if (d->next == 0) d->next = id;
+    setProperty(StyleId, id);
+    if (d->next == 0)
+        d->next = id;
 }
 
 QString KoTableCellStyle::masterPageName() const
@@ -469,7 +454,7 @@ void KoTableCellStyle::setCellProtection(KoTableCellStyle::CellProtectionFlag pr
 
 KoTableCellStyle::CellProtectionFlag KoTableCellStyle::cellProtection() const
 {
-    return (CellProtectionFlag) propertyInt(CellProtection);
+    return (CellProtectionFlag)propertyInt(CellProtection);
 }
 
 void KoTableCellStyle::setTextDirection(KoText::Direction value)
@@ -479,7 +464,7 @@ void KoTableCellStyle::setTextDirection(KoText::Direction value)
 
 KoText::Direction KoTableCellStyle::textDirection() const
 {
-    return (KoText::Direction) propertyInt(TextWritingMode);
+    return (KoText::Direction)propertyInt(TextWritingMode);
 }
 
 bool KoTableCellStyle::printContent() const
@@ -557,7 +542,7 @@ KoBorder KoTableCellStyle::borders() const
     return KoBorder();
 }
 
-void KoTableCellStyle::setBorders(const KoBorder& borders)
+void KoTableCellStyle::setBorders(const KoBorder &borders)
 {
     setProperty(Borders, QVariant::fromValue<KoBorder>(borders));
 }
@@ -569,7 +554,7 @@ KoShadowStyle KoTableCellStyle::shadow() const
     return KoShadowStyle();
 }
 
-void KoTableCellStyle::setShadow(const KoShadowStyle& shadow)
+void KoTableCellStyle::setShadow(const KoShadowStyle &shadow)
 {
     setProperty(Shadow, QVariant::fromValue<KoShadowStyle>(shadow));
 }
@@ -587,7 +572,7 @@ void KoTableCellStyle::setRotationAlignment(KoTableCellStyle::RotationAlignment
 KoTableCellStyle::CellTextDirection KoTableCellStyle::direction() const
 {
     if (hasProperty(Direction))
-        return (KoTableCellStyle::CellTextDirection) propertyInt(Direction);
+        return (KoTableCellStyle::CellTextDirection)propertyInt(Direction);
     return KoTableCellStyle::Default;
 }
 
@@ -602,7 +587,7 @@ void KoTableCellStyle::loadOdf(const KoXmlElement *element, KoShapeLoadingContex
         d->name = element->attributeNS(KoXmlNS::style, "name", QString());
 
     QString masterPage = element->attributeNS(KoXmlNS::style, "master-page-name", QString());
-    if (! masterPage.isEmpty()) {
+    if (!masterPage.isEmpty()) {
         setMasterPageName(masterPage);
     }
 
@@ -615,7 +600,7 @@ void KoTableCellStyle::loadOdf(const KoXmlElement *element, KoShapeLoadingContex
 
     context.styleStack().save();
     QString family = element->attributeNS(KoXmlNS::style, "family", "table-cell");
-    context.addStyles(element, family.toLocal8Bit().constData());   // Load all parents - only because we don't support inheritance.
+    context.addStyles(element, family.toLocal8Bit().constData()); // Load all parents - only because we don't support inheritance.
 
     context.styleStack().setTypeProperties("table-cell");
     loadOdfProperties(scontext, context.styleStack());
@@ -672,54 +657,53 @@ void KoTableCellStyle::loadOdfProperties(KoShapeLoadingContext &context, KoStyle
     if (styleStack.hasProperty(KoXmlNS::style, "shrink-to-fit")) {
         setShrinkToFit(styleStack.property(KoXmlNS::style, "shrink-to-fit") == "true");
     }
-    
+
     if (styleStack.hasProperty(KoXmlNS::style, "print-content")) {
         setPrintContent(styleStack.property(KoXmlNS::style, "print-content") == "true");
     }
-    
+
     if (styleStack.hasProperty(KoXmlNS::style, "repeat-content")) {
         setRepeatContent(styleStack.property(KoXmlNS::style, "repeat-content") == "true");
     }
-    
+
     if (styleStack.hasProperty(KoXmlNS::style, "repeat-content")) {
         setRepeatContent(styleStack.property(KoXmlNS::style, "repeat-content") == "true");
     }
-    
+
     if (styleStack.hasProperty(KoXmlNS::style, "decimal-places")) {
         bool ok;
         int value = styleStack.property(KoXmlNS::style, "decimal-places").toInt(&ok);
         if (ok)
             setDecimalPlaces(value);
     }
-    
+
     if (styleStack.hasProperty(KoXmlNS::style, "rotation-angle")) {
         setRotationAngle(KoUnit::parseAngle(styleStack.property(KoXmlNS::style, "rotation-angle")));
     }
-    
-    if (styleStack.hasProperty(KoXmlNS::style, "glyph-orientation-vertical"))
-    {
+
+    if (styleStack.hasProperty(KoXmlNS::style, "glyph-orientation-vertical")) {
         setVerticalGlyphOrientation(styleStack.property(KoXmlNS::style, "glyph-orientation-vertical") == "auto");
     }
-    
+
     if (styleStack.hasProperty(KoXmlNS::style, "direction")) {
         if (styleStack.property(KoXmlNS::style, "direction") == "ltr")
             setDirection(KoTableCellStyle::LeftToRight);
         else
             setDirection(KoTableCellStyle::TopToBottom);
     }
-    
+
     if (styleStack.hasProperty(KoXmlNS::style, "rotation-align")) {
         setRotationAlignment(rotationAlignmentFromString(styleStack.property(KoXmlNS::style, "rotation-align")));
     }
-    
+
     if (styleStack.hasProperty(KoXmlNS::style, "text-align-source")) {
         setAlignFromType(styleStack.property(KoXmlNS::style, "text-align-source") == "value-type");
     }
-    
+
     if (styleStack.hasProperty(KoXmlNS::fo, "wrap-option")) {
         setWrap(styleStack.property(KoXmlNS::fo, "wrap-option") == "wrap");
     }
-    
+
     if (styleStack.hasProperty(KoXmlNS::style, "cell-protect")) {
         QString protection = styleStack.property(KoXmlNS::style, "cell-protect");
         if (protection == "none")
@@ -737,11 +721,11 @@ void KoTableCellStyle::loadOdfProperties(KoShapeLoadingContext &context, KoStyle
     const QString verticalAlign(styleStack.property(KoXmlNS::style, "vertical-align"));
     if (!verticalAlign.isEmpty()) {
         if (verticalAlign == "automatic")
-            setAlignment((Qt::AlignmentFlag) 0);
+            setAlignment((Qt::AlignmentFlag)0);
         else
             setAlignment(KoText::valignmentFromString(verticalAlign));
     }
-    
+
     if (styleStack.hasProperty(KoXmlNS::style, "writing-mode"))
         setTextDirection(KoText::directionFromString(styleStack.property(KoXmlNS::style, "writing-mode")));
 }
@@ -749,7 +733,7 @@ void KoTableCellStyle::loadOdfProperties(KoShapeLoadingContext &context, KoStyle
 void KoTableCellStyle::copyProperties(const KoTableCellStyle *style)
 {
     Q_D(KoTableCellStyle);
-    const KoTableCellStylePrivate *styleD = static_cast<const KoTableCellStylePrivate*>(style->d_func());
+    const KoTableCellStylePrivate *styleD = static_cast<const KoTableCellStylePrivate *>(style->d_func());
 
     d->stylesPrivate = styleD->stylesPrivate;
     setName(style->name()); // make sure we emit property change
@@ -764,18 +748,17 @@ KoTableCellStyle *KoTableCellStyle::clone(QObject *parent)
     return newStyle;
 }
 
-
 bool KoTableCellStyle::operator==(const KoTableCellStyle &other) const
 {
     Q_D(const KoTableCellStyle);
-    const KoTableCellStylePrivate *otherD = static_cast<const KoTableCellStylePrivate*>(other.d_func());
+    const KoTableCellStylePrivate *otherD = static_cast<const KoTableCellStylePrivate *>(other.d_func());
     return otherD->stylesPrivate == d->stylesPrivate;
 }
 
 void KoTableCellStyle::removeDuplicates(const KoTableCellStyle &other)
 {
     Q_D(KoTableCellStyle);
-    const KoTableCellStylePrivate *otherD = static_cast<const KoTableCellStylePrivate*>(other.d_func());
+    const KoTableCellStylePrivate *otherD = static_cast<const KoTableCellStylePrivate *>(other.d_func());
     d->stylesPrivate.removeDuplicates(otherD->stylesPrivate);
 }
 
@@ -784,17 +767,13 @@ void KoTableCellStyle::saveOdf(KoGenStyle &style, KoShapeSavingContext &context)
     Q_D(KoTableCellStyle);
     QList<int> keys = d->stylesPrivate.keys();
     bool donePadding = false;
-    if (hasProperty(QTextFormat::TableCellLeftPadding) && 
-            hasProperty(QTextFormat::TableCellRightPadding) && 
-            hasProperty(QTextFormat::TableCellTopPadding) && 
-            hasProperty(QTextFormat::TableCellBottomPadding) && 
-            leftPadding() == rightPadding() &&
-            topPadding() == bottomPadding() &&
-            topPadding() == leftPadding()) {
+    if (hasProperty(QTextFormat::TableCellLeftPadding) && hasProperty(QTextFormat::TableCellRightPadding) && hasProperty(QTextFormat::TableCellTopPadding)
+        && hasProperty(QTextFormat::TableCellBottomPadding) && leftPadding() == rightPadding() && topPadding() == bottomPadding()
+        && topPadding() == leftPadding()) {
         donePadding = true;
         style.addPropertyPt("fo:padding", leftPadding(), KoGenStyle::TableCellType);
     }
-    foreach(int key, keys) {
+    foreach (int key, keys) {
         if (key == CellBackgroundBrush) {
             QBrush backBrush = background();
             if (backBrush.style() != Qt::NoBrush)
@@ -868,11 +847,9 @@ void KoTableCellStyle::saveOdf(KoGenStyle &style, KoShapeSavingContext &context)
     if (d->paragraphStyle) {
         d->paragraphStyle->saveOdf(style, context);
     }
-
 }
 
-void KoTableCellStyle::setEdge(KoBorder::BorderSide side, KoBorder::BorderStyle style,
-                               qreal width, const QColor &color)
+void KoTableCellStyle::setEdge(KoBorder::BorderSide side, KoBorder::BorderStyle style, qreal width, const QColor &color)
 {
     KoBorder::BorderData edge;
     qreal innerWidth = 0;
@@ -884,7 +861,7 @@ void KoTableCellStyle::setEdge(KoBorder::BorderSide side, KoBorder::BorderStyle
         width = 0.0;
         break;
     case KoBorder::BorderDouble:
-        innerWidth = space = width/3; //some nice default look
+        innerWidth = space = width / 3; // some nice default look
         width -= (space + innerWidth);
         edge.outerPen.setStyle(Qt::SolidLine);
         break;
@@ -902,16 +879,16 @@ void KoTableCellStyle::setEdge(KoBorder::BorderSide side, KoBorder::BorderStyle
         break;
     }
     case KoBorder::BorderTriple:
-        innerWidth = middleWidth = space = width/6;
+        innerWidth = middleWidth = space = width / 6;
         width -= (space + innerWidth);
         edge.outerPen.setStyle(Qt::SolidLine);
         break;
     case KoBorder::BorderDashDot:
-        dashes << 3 << 3<< 7 << 3;
+        dashes << 3 << 3 << 7 << 3;
         edge.outerPen.setDashPattern(dashes);
         break;
     case KoBorder::BorderDashDotDot:
-        dashes << 2 << 2<< 6 << 2 << 2 << 2;
+        dashes << 2 << 2 << 6 << 2 << 2 << 2;
         edge.outerPen.setDashPattern(dashes);
         break;
     case KoBorder::BorderWave:
@@ -921,7 +898,7 @@ void KoTableCellStyle::setEdge(KoBorder::BorderSide side, KoBorder::BorderStyle
         edge.outerPen.setStyle(Qt::SolidLine);
         break;
     case KoBorder::BorderDoubleWave:
-        innerWidth = space = width/3; //some nice default look
+        innerWidth = space = width / 3; // some nice default look
         width -= (space + innerWidth);
         edge.outerPen.setStyle(Qt::SolidLine);
         break;
@@ -948,7 +925,7 @@ void KoTableCellStyle::setEdge(KoBorder::BorderSide side, const KoBorder::Border
 {
     KoBorder borders = this->borders();
     KoBorder::BorderData edgeCopy(edge);
-    edgeCopy.style = style;                 // Just for safety.
+    edgeCopy.style = style; // Just for safety.
     borders.setBorderData(side, edgeCopy);
     setBorders(borders);
 }
