@@ -1,26 +1,13 @@
 /* This file is part of the KDE project
- * Copyright (C) 2006 Thomas Zander <zander@kde.org>
- * Copyright (C) 2007 Sebastian Sauer <mail@dipe.org>
- * Copyright (C) 2008 Thorsten Zachmann <zachmann@kde.org>
- * Copyright (C) 2008 Girish Ramakrishnan <girish@forwardbias.in>
- * Copyright (C) 2009-2011 KO GmbH <cbo@kogmbh.com>
- * Copyright (C) 2011-2012 Pierre Stirnweiss <pstirnweiss@googlemail.com>
- * Copyright (C) 2012 Gopalakrishna Bhat A <gopalakbhat@gmail.com>
+ * SPDX-FileCopyrightText: 2006 Thomas Zander <zander@kde.org>
+ * SPDX-FileCopyrightText: 2007 Sebastian Sauer <mail@dipe.org>
+ * SPDX-FileCopyrightText: 2008 Thorsten Zachmann <zachmann@kde.org>
+ * SPDX-FileCopyrightText: 2008 Girish Ramakrishnan <girish@forwardbias.in>
+ * SPDX-FileCopyrightText: 2009-2011 KO GmbH <cbo@kogmbh.com>
+ * SPDX-FileCopyrightText: 2011-2012 Pierre Stirnweiss <pstirnweiss@googlemail.com>
+ * SPDX-FileCopyrightText: 2012 Gopalakrishna Bhat A <gopalakbhat@gmail.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #ifndef KOSTYLETHUMBNAILER_H
@@ -70,9 +57,9 @@ public:
      * The created thumbnail is cached.
      */
     QImage thumbnail(KoParagraphStyle *style,
-                     const QSize &size = QSize(), bool recreateThumbnail = false,
-                     KoStyleThumbnailerFlags flags =
-                          KoStyleThumbnailerFlags(CenterAlignThumbnail | UseStyleNameText | ScaleThumbnailFont));
+                     const QSize &size = QSize(),
+                     bool recreateThumbnail = false,
+                     KoStyleThumbnailerFlags flags = KoStyleThumbnailerFlags(CenterAlignThumbnail | UseStyleNameText | ScaleThumbnailFont));
 
     /**
      * @returns a thumbnail representing the @param characterStyle applied on the given @param paragraphStyle, constrained into the @param size.
@@ -82,10 +69,11 @@ public:
      * If @param recreateThumbnail is true, do not return the cached thumbnail if it exist, but recreate a new one.
      * The created thumbnail is cached.
      */
-    QImage thumbnail(KoCharacterStyle *characterStyle, KoParagraphStyle *paragraphStyle = 0,
-                     const QSize &size = QSize(), bool recreateThumbnail = false,
-                     KoStyleThumbnailerFlags flags =
-                          KoStyleThumbnailerFlags(CenterAlignThumbnail | UseStyleNameText | ScaleThumbnailFont));
+    QImage thumbnail(KoCharacterStyle *characterStyle,
+                     KoParagraphStyle *paragraphStyle = nullptr,
+                     const QSize &size = QSize(),
+                     bool recreateThumbnail = false,
+                     KoStyleThumbnailerFlags flags = KoStyleThumbnailerFlags(CenterAlignThumbnail | UseStyleNameText | ScaleThumbnailFont));
 
     /**
      * Sets the size of the thumbnails returned by the @fn thumbnail with no size arguments.
@@ -114,7 +102,7 @@ private:
     void removeFromCache(const QString &expr);
 
     class Private;
-    Private* const d;
+    Private *const d;
 };
 
 #endif
