@@ -1,20 +1,7 @@
 /* This file is part of the KDE project
- * Copyright (C) 2011 C. Boemann <cbo@kogmbh.com>
+ * SPDX-FileCopyrightText: 2011 C. Boemann <cbo@kogmbh.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #ifndef KOTEXTLAYOUTROOTAREAPROVIDER_H
@@ -38,6 +25,7 @@ class QRectF;
 struct RootAreaConstraint {
     QString masterPageName;
     int visiblePageNumber;
+    bool newPageForced;
 };
 
 /**
@@ -59,7 +47,8 @@ public:
      * @param requestedPosition the position of the new area in the text flow
      * @param isNewArea will contain a boolean to tell whether this is a new area or a recycled one
      */
-    virtual KoTextLayoutRootArea *provide(KoTextDocumentLayout *documentLayout, const RootAreaConstraint &constraints, int requestedPosition, bool *isNewArea) = 0;
+    virtual KoTextLayoutRootArea *
+    provide(KoTextDocumentLayout *documentLayout, const RootAreaConstraint &constraints, int requestedPosition, bool *isNewArea) = 0;
 
     /// Release all root areas that are after the "afterThis" root area
     /// If afterThis == 0 all should be released
