@@ -1,60 +1,46 @@
 /* This file is part of the KDE project
- * Copyright (C) 2007,2009,2010 Thomas Zander <zander@kde.org>
- * Copyright (C) 2010 C. Boemann <cbo@kogmbh.com>
+ * SPDX-FileCopyrightText: 2007, 2009, 2010 Thomas Zander <zander@kde.org>
+ * SPDX-FileCopyrightText: 2010 C. Boemann <cbo@kogmbh.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "KoTextShapeContainerModel.h"
 
 #include "KoAnchorInlineObject.h"
-#include "KoTextShapeData.h"
 #include "KoShapeContainer.h"
+#include "KoTextShapeData.h"
 
 #include <QTextBlock>
+#include <QTextDocument>
 #include <QTextLayout>
 #include <QTextLine>
-#include <QTextDocument>
 
 #include <TextLayoutDebug.h>
 
-struct Relation
-{
-    Relation(KoShape *shape = 0)
-        : child(shape),
-        anchor(0),
-        nested(false),
-        inheritsTransform(false)
+struct Relation {
+    Relation(KoShape *shape = nullptr)
+        : child(shape)
+        , anchor(nullptr)
+        , nested(false)
+        , inheritsTransform(false)
     {
     }
     KoShape *child;
     KoShapeAnchor *anchor;
     uint nested : 1;
-    uint inheritsTransform :1;
+    uint inheritsTransform : 1;
 };
 
 class Q_DECL_HIDDEN KoTextShapeContainerModel::Private
 {
 public:
-    QHash<const KoShape*, Relation> children;
+    QHash<const KoShape *, Relation> children;
     QList<KoShapeAnchor *> shapeRemovedAnchors;
 };
 
 KoTextShapeContainerModel::KoTextShapeContainerModel()
-        : d(new Private())
+    : d(new Private())
 {
 }
 
@@ -70,7 +56,7 @@ void KoTextShapeContainerModel::add(KoShape *child)
     Relation relation(child);
     d->children.insert(child, relation);
 
-    KoShapeAnchor *toBeAddedAnchor = 0;
+    KoShapeAnchor *toBeAddedAnchor = nullptr;
     foreach (KoShapeAnchor *anchor, d->shapeRemovedAnchors) {
         if (child == anchor->shape()) {
             toBeAddedAnchor = anchor;
@@ -118,15 +104,14 @@ bool KoTextShapeContainerModel::inheritsTransform(const KoShape *shape) const
     return d->children[shape].inheritsTransform;
 }
 
-
 int KoTextShapeContainerModel::count() const
 {
     return d->children.count();
 }
 
-QList<KoShape*> KoTextShapeContainerModel::shapes() const
+QList<KoShape *> KoTextShapeContainerModel::shapes() const
 {
-    QList<KoShape*> answer;
+    QList<KoShape *> answer;
     answer.reserve(d->children.count());
     foreach (const Relation &relation, d->children) {
         answer << relation.child;
@@ -142,17 +127,13 @@ void KoTextShapeContainerModel::containerChanged(KoShapeContainer *container, Ko
 
 void KoTextShapeContainerModel::childChanged(KoShape *child, KoShape::ChangeType type)
 {
-    if (((type == KoShape::RotationChanged ||
-          type == KoShape::ScaleChanged ||
-          type == KoShape::ShearChanged ||
-          type == KoShape::ClipPathChanged ||
-          type == KoShape::PositionChanged ||
-          type == KoShape::SizeChanged) && child->textRunAroundSide() != KoShape::RunThrough) ||
-          type == KoShape::TextRunAroundChanged) {
-
+    if (((type == KoShape::RotationChanged || type == KoShape::ScaleChanged || type == KoShape::ShearChanged || type == KoShape::ClipPathChanged
+          || type == KoShape::PositionChanged || type == KoShape::SizeChanged)
+         && child->textRunAroundSide() != KoShape::RunThrough)
+        || type == KoShape::TextRunAroundChanged) {
         relayoutInlineObject(child);
     }
-    KoShapeContainerModel::childChanged( child, type );
+    KoShapeContainerModel::childChanged(child, type);
 }
 
 void KoTextShapeContainerModel::addAnchor(KoShapeAnchor *anchor)
@@ -166,7 +147,7 @@ void KoTextShapeContainerModel::addAnchor(KoShapeAnchor *anchor)
 void KoTextShapeContainerModel::removeAnchor(KoShapeAnchor *anchor)
 {
     if (d->children.contains(anchor->shape())) {
-        d->children[anchor->shape()].anchor = 0;
+        d->children[anchor->shape()].anchor = nullptr;
         d->shapeRemovedAnchors.removeAll(anchor);
     }
 }
@@ -176,13 +157,13 @@ void KoTextShapeContainerModel::proposeMove(KoShape *child, QPointF &move)
     if (!d->children.contains(child))
         return;
     Relation relation = d->children.value(child);
-    if (relation.anchor == 0)
+    if (relation.anchor == nullptr)
         return;
 
-    QPointF newPosition = child->position() + move/* + relation.anchor->offset()*/;
-//warnTextLayout <<"proposeMove:" /*<< move <<" |"*/ << newPosition <<" |" << parentShapeRect;
+    QPointF newPosition = child->position() + move /* + relation.anchor->offset()*/;
+    // warnTextLayout <<"proposeMove:" /*<< move <<" |"*/ << newPosition <<" |" << parentShapeRect;
 
-    QTextLayout *layout = 0;
+    QTextLayout *layout = nullptr;
     int anchorPosInParag = -1;
 
     if (relation.anchor->anchorType() == KoShapeAnchor::AnchorAsCharacter) {
@@ -194,20 +175,19 @@ void KoTextShapeContainerModel::proposeMove(KoShape *child, QPointF &move)
         if (layout) {
             QTextLine tl = layout->lineForTextPosition(anchorPosInParag);
             Q_ASSERT(tl.isValid());
-            relation.anchor->setOffset(QPointF(newPosition.x() - tl.cursorToX(anchorPosInParag)
-                + tl.x(), 0));
+            relation.anchor->setOffset(QPointF(newPosition.x() - tl.cursorToX(anchorPosInParag) + tl.x(), 0));
             relayoutInlineObject(child);
         }
 
         // the rest of the code uses the shape baseline, at this time the bottom. So adjust
         newPosition.setY(newPosition.y() + child->size().height());
-        if (layout == 0) {
+        if (layout == nullptr) {
             QTextBlock block = document->findBlock(posInDocument);
             layout = block.layout();
             anchorPosInParag = posInDocument - block.position();
         }
         if (layout->lineCount() > 0) {
-            KoTextShapeData *data = qobject_cast<KoTextShapeData*>(child->parent()->userData());
+            KoTextShapeData *data = qobject_cast<KoTextShapeData *>(child->parent()->userData());
             Q_ASSERT(data);
             QTextLine tl = layout->lineForTextPosition(anchorPosInParag);
             Q_ASSERT(tl.isValid());
@@ -216,7 +196,7 @@ void KoTextShapeContainerModel::proposeMove(KoShape *child, QPointF &move)
             relayoutInlineObject(child);
         }
     } else {
-        //TODO pavolk: handle position type change: absolute to realtive, etc ..
+        // TODO pavolk: handle position type change: absolute to relative, etc ..
         child->setPosition(newPosition);
         relation.anchor->setOffset(relation.anchor->offset() + move);
         relayoutInlineObject(child);
@@ -233,11 +213,10 @@ bool KoTextShapeContainerModel::isChildLocked(const KoShape *child) const
 
 void KoTextShapeContainerModel::relayoutInlineObject(KoShape *child)
 {
-    if (child == 0) {
+    if (child == nullptr) {
         return;
     }
-    KoTextShapeData *data  = qobject_cast<KoTextShapeData*>(child->parent()->userData());
+    KoTextShapeData *data = qobject_cast<KoTextShapeData *>(child->parent()->userData());
     Q_ASSERT(data);
     data->setDirty();
 }
-
