@@ -1,39 +1,25 @@
 /* This file is part of the KDE project
- * Copyright 2018 Dag Andersen <danders@get2net.dk>
- * 
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- * 
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Library General Public License for more details.
- * 
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB. If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-FileCopyrightText: 2018 Dag Andersen <danders@get2net.dk>
+ *
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "PlotAreaCommand.h"
 
 // KF5
-#include <klocalizedstring.h>
+#include <KLocalizedString>
 
 // KChart
 #include "KChartCartesianAxis.h"
 
 // KoChart
-#include "ChartShape.h"
-#include "PlotArea.h"
 #include "Axis.h"
 #include "ChartDebug.h"
+#include "ChartShape.h"
+#include "PlotArea.h"
 
 using namespace KoChart;
 
-
 PlotAreaCommand::PlotAreaCommand(PlotArea *plotArea)
     : m_plotArea(plotArea)
     , m_chart(plotArea->parent())
@@ -41,9 +27,7 @@ PlotAreaCommand::PlotAreaCommand(PlotArea *plotArea)
     m_newOrientation = m_oldOrientation = plotArea->isVertical() ? Qt::Vertical : Qt::Horizontal;
 }
 
-PlotAreaCommand::~PlotAreaCommand()
-{
-}
+PlotAreaCommand::~PlotAreaCommand() = default;
 
 void PlotAreaCommand::redo()
 {
@@ -72,5 +56,5 @@ void PlotAreaCommand::setOrientation(Qt::Orientation orientation)
         setText(kundo2_i18n("Set Horizontal Bars"));
     } else {
         setText(kundo2_i18n("Set Vertical Bars"));
-    }    
+    }
 }
