@@ -1,48 +1,38 @@
 /* This file is part of the KDE project
  *
- * Copyright 2018 Dag Andersen <danders@get2net.dk>
+ * SPDX-FileCopyrightText: 2018 Dag Andersen <danders@get2net.dk>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "BubbleDataEditor.h"
 
-#include <QSortFilterProxyModel>
 #include <QAbstractTableModel>
 #include <QAction>
+#include <QSortFilterProxyModel>
 
 #include <KoIcon.h>
 
-#include "ChartShape.h"
-#include "ChartProxyModel.h"
-#include "ChartTableView.h"
-#include "ChartTableModel.h"
-#include "DataSet.h"
 #include "ChartDebug.h"
+#include "ChartProxyModel.h"
+#include "ChartShape.h"
+#include "ChartTableModel.h"
+#include "ChartTableView.h"
+#include "DataSet.h"
 
+namespace KoChart
+{
 
-
-namespace KoChart {
-
-namespace Bubble {
+namespace Bubble
+{
 
 class DataProxy : public QSortFilterProxyModel
 {
 public:
-    DataProxy(QObject *parent = 0) : QSortFilterProxyModel(parent) {}
+    DataProxy(QObject *parent = nullptr)
+        : QSortFilterProxyModel(parent)
+    {
+    }
 
     QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const override
     {
@@ -55,13 +45,13 @@ public:
         }
         return QSortFilterProxyModel::headerData(section, orientation, role);
     }
-    bool filterAcceptsColumn(int source_column, const QModelIndex &/*source_parent*/) const override
+    bool filterAcceptsColumn(int source_column, const QModelIndex & /*source_parent*/) const override
     {
         return source_column != 0; // skip categories
     }
     bool insertColumns(int column, int count, const QModelIndex &parent) override
     {
-        debugChartUiBubble<<column;
+        debugChartUiBubble << column;
         Q_UNUSED(count);
         Q_UNUSED(parent);
 
@@ -70,7 +60,7 @@ public:
         if (scolumn < 0) {
             scolumn = model->columnCount();
         }
-        debugChartUiBubble<<column<<':'<<scolumn;
+        debugChartUiBubble << column << ':' << scolumn;
         if (!model->insertColumns(scolumn, 1)) {
             return false;
         }
@@ -87,7 +77,7 @@ public:
     }
     bool insertRows(int row, int count, const QModelIndex &parent) override
     {
-        debugChartUiBubble<<row;
+        debugChartUiBubble << row;
         Q_UNUSED(count);
         Q_UNUSED(parent);
 
@@ -127,7 +117,6 @@ BubbleDataEditor::BubbleDataEditor(ChartShape *chart, QWidget *parent)
     m_insertRowBelowAction = new QAction(m_ui.insertRowBelow->icon(), i18n("Insert Row Below"), m_ui.tableView);
     m_deleteAction = new QAction(m_ui.deleteSelection->icon(), i18n("Delete"), m_ui.tableView);
 
-
     m_ui.tableView->addAction(m_insertColumnBeforeAction);
     m_ui.tableView->addAction(m_insertColumnAfterAction);
     m_ui.tableView->addAction(m_insertRowAboveAction);
@@ -139,31 +128,31 @@ BubbleDataEditor::BubbleDataEditor(ChartShape *chart, QWidget *parent)
     m_ui.deleteSelection->setEnabled(false);
     m_deleteAction->setEnabled(false);
 
-//     m_dataSetModel = new DataSetTableModel(m_ui.dataSetView);
+    //     m_dataSetModel = new DataSetTableModel(m_ui.dataSetView);
     m_dataSetModel.tableSource = m_chart->tableSource();
-    connect(m_ui.addDataSetBefore, SIGNAL(clicked()), this, SLOT(slotAddDataSetBefore()));
-    connect(m_ui.addDataSetAfter, SIGNAL(clicked()), this, SLOT(slotAddDataSetAfter()));
-    connect(m_ui.removeDataSet, SIGNAL(clicked()), this, SLOT(slotRemoveDataSet()));
+    connect(m_ui.addDataSetBefore, &QAbstractButton::clicked, this, &BubbleDataEditor::slotAddDataSetBefore);
+    connect(m_ui.addDataSetAfter, &QAbstractButton::clicked, this, &BubbleDataEditor::slotAddDataSetAfter);
+    connect(m_ui.removeDataSet, &QAbstractButton::clicked, this, &BubbleDataEditor::slotRemoveDataSet);
 
     m_dataSetModel.setModel(m_chart->proxyModel());
-//     connect(&m_dataSetModel, &DataSetTableModel::dataChanged, this, &BubbleDataEditor::slotDataChanged);
+    //     connect(&m_dataSetModel, &DataSetTableModel::dataChanged, this, &BubbleDataEditor::slotDataChanged);
 
     m_dataModel = new DataProxy(m_ui.tableView);
     m_dataModel->setSourceModel(m_chart->internalModel());
 
-    connect(m_ui.insertColumnBefore, SIGNAL(clicked()), this, SLOT(slotInsertColumnBefore()));
-    connect(m_ui.insertColumnAfter, SIGNAL(clicked()), this, SLOT(slotInsertColumnAfter()));
-    connect(m_ui.insertRowAbove, SIGNAL(clicked()), this, SLOT(slotInsertRowAbove()));
-    connect(m_ui.insertRowBelow, SIGNAL(clicked()), this, SLOT(slotInsertRowBelow()));
-    connect(m_ui.deleteSelection,SIGNAL(clicked()), this, SLOT(slotDeleteSelection()));
+    connect(m_ui.insertColumnBefore, &QAbstractButton::clicked, this, &BubbleDataEditor::slotInsertColumnBefore);
+    connect(m_ui.insertColumnAfter, &QAbstractButton::clicked, this, &BubbleDataEditor::slotInsertColumnAfter);
+    connect(m_ui.insertRowAbove, &QAbstractButton::clicked, this, &BubbleDataEditor::slotInsertRowAbove);
+    connect(m_ui.insertRowBelow, &QAbstractButton::clicked, this, &BubbleDataEditor::slotInsertRowBelow);
+    connect(m_ui.deleteSelection, &QAbstractButton::clicked, this, &BubbleDataEditor::slotDeleteSelection);
 
-    connect(m_insertColumnBeforeAction, SIGNAL(triggered()), this, SLOT(slotInsertColumnBefore()));
-    connect(m_insertColumnAfterAction, SIGNAL(triggered()), this, SLOT(slotInsertColumnAfter()));
-    connect(m_insertRowAboveAction, SIGNAL(triggered()), this, SLOT(slotInsertRowAbove()));
-    connect(m_insertRowBelowAction, SIGNAL(triggered()), this, SLOT(slotInsertRowBelow()));
-    connect(m_deleteAction, SIGNAL(triggered()), this, SLOT(slotDeleteSelection()));
+    connect(m_insertColumnBeforeAction, &QAction::triggered, this, &BubbleDataEditor::slotInsertColumnBefore);
+    connect(m_insertColumnAfterAction, &QAction::triggered, this, &BubbleDataEditor::slotInsertColumnAfter);
+    connect(m_insertRowAboveAction, &QAction::triggered, this, &BubbleDataEditor::slotInsertRowAbove);
+    connect(m_insertRowBelowAction, &QAction::triggered, this, &BubbleDataEditor::slotInsertRowBelow);
+    connect(m_deleteAction, &QAction::triggered, this, &BubbleDataEditor::slotDeleteSelection);
 
-    connect(m_ui.tableView, SIGNAL(currentIndexChanged(QModelIndex)), this, SLOT(enableActions()));
+    connect(m_ui.tableView, &ChartTableView::currentIndexChanged, this, &BubbleDataEditor::enableActions);
 
     m_ui.tableView->setModel(m_dataModel);
     m_ui.dataSetView->setModel(&m_dataSetModel);
@@ -177,31 +166,28 @@ BubbleDataEditor::BubbleDataEditor(ChartShape *chart, QWidget *parent)
 
     m_ui.dataSetView->verticalHeader()->hide();
 
-    connect(m_ui.manualControl, SIGNAL(toggled(bool)), m_chart->proxyModel(), SLOT(setManualControl(bool)));
+    connect(m_ui.manualControl, &QAbstractButton::toggled, m_chart->proxyModel(), &ChartProxyModel::setManualControl);
 
-    connect(m_ui.tableView->selectionModel(), SIGNAL(selectionChanged(const QItemSelection&,const QItemSelection&)), this, SLOT(enableActions()));
-    connect(m_ui.dataSetView->selectionModel(), SIGNAL(selectionChanged(const QItemSelection&,const QItemSelection&)), this, SLOT(enableActions()));
-    connect(m_ui.manualControl, SIGNAL(clicked()), this, SLOT(enableActions()));
+    connect(m_ui.tableView->selectionModel(), &QItemSelectionModel::selectionChanged, this, &BubbleDataEditor::enableActions);
+    connect(m_ui.dataSetView->selectionModel(), &QItemSelectionModel::selectionChanged, this, &BubbleDataEditor::enableActions);
+    connect(m_ui.manualControl, &QAbstractButton::clicked, this, &BubbleDataEditor::enableActions);
 
     chart->proxyModel()->setManualControl(m_ui.manualControl->isChecked());
     enableActions();
 
-    connect(m_dataModel, SIGNAL(columnsInserted(const QModelIndex &, int, int)), this, SLOT(dataColumnsInserted(QModelIndex,int,int)));
-    connect(m_dataModel, SIGNAL(columnsRemoved(const QModelIndex &, int, int)), this, SLOT(dataColumnsRemoved(QModelIndex,int,int)));
-    connect(m_dataModel->sourceModel(), SIGNAL(rowsInserted(const QModelIndex &, int, int)), this, SLOT(dataRowCountChanged()));
-    connect(m_dataModel->sourceModel(), SIGNAL(rowsRemoved(const QModelIndex &, int, int)), this, SLOT(dataRowCountChanged()));
+    connect(m_dataModel, &QAbstractItemModel::columnsInserted, this, &BubbleDataEditor::dataColumnsInserted);
+    connect(m_dataModel, &QAbstractItemModel::columnsRemoved, this, &BubbleDataEditor::dataColumnsRemoved);
+    connect(m_dataModel->sourceModel(), &QAbstractItemModel::rowsInserted, this, &BubbleDataEditor::dataRowCountChanged);
+    connect(m_dataModel->sourceModel(), &QAbstractItemModel::rowsRemoved, this, &BubbleDataEditor::dataRowCountChanged);
 
     resize(sizeHint().expandedTo(QSize(600, 300)));
-
 }
 
-BubbleDataEditor::~BubbleDataEditor()
-{
-}
+BubbleDataEditor::~BubbleDataEditor() = default;
 
 void BubbleDataEditor::slotInsertColumnBefore()
 {
-    debugChartUiBubble<<m_ui.tableView->currentIndex();
+    debugChartUiBubble << m_ui.tableView->currentIndex();
     int pos = m_ui.tableView->currentIndex().column();
     if (pos < 0) {
         pos = 0;
@@ -211,7 +197,7 @@ void BubbleDataEditor::slotInsertColumnBefore()
 
 void BubbleDataEditor::slotInsertColumnAfter()
 {
-    debugChartUiBubble<<m_ui.tableView->currentIndex();
+    debugChartUiBubble << m_ui.tableView->currentIndex();
     int pos = m_ui.tableView->currentIndex().column() + 1;
     if (pos == 0) {
         pos = m_dataModel->columnCount();
@@ -221,7 +207,7 @@ void BubbleDataEditor::slotInsertColumnAfter()
 
 void BubbleDataEditor::slotInsertRowAbove()
 {
-    debugChartUiBubble<<m_ui.tableView->currentIndex();
+    debugChartUiBubble << m_ui.tableView->currentIndex();
     int pos = m_ui.tableView->currentIndex().row();
     if (pos < 0) {
         pos = 0;
@@ -231,7 +217,7 @@ void BubbleDataEditor::slotInsertRowAbove()
 
 void BubbleDataEditor::slotInsertRowBelow()
 {
-    debugChartUiBubble<<m_ui.tableView->currentIndex();
+    debugChartUiBubble << m_ui.tableView->currentIndex();
     int pos = m_ui.tableView->currentIndex().row() + 1;
     if (pos == 0) {
         pos = m_dataModel->rowCount();
@@ -257,7 +243,7 @@ void BubbleDataEditor::slotDeleteSelection()
 
 void BubbleDataEditor::slotAddDataSetBefore()
 {
-    debugChartUiBubble<<m_ui.tableView->currentIndex();
+    debugChartUiBubble << m_ui.tableView->currentIndex();
     int pos = m_ui.dataSetView->currentIndex().row();
     if (pos < 0) {
         pos = 0;
@@ -267,7 +253,7 @@ void BubbleDataEditor::slotAddDataSetBefore()
 
 void BubbleDataEditor::slotAddDataSetAfter()
 {
-    debugChartUiBubble<<m_ui.dataSetView->currentIndex();
+    debugChartUiBubble << m_ui.dataSetView->currentIndex();
     int pos = m_ui.dataSetView->currentIndex().row() + 1;
     if (pos == 0) {
         pos = m_dataSetModel.rowCount();
@@ -310,23 +296,23 @@ void BubbleDataEditor::enableActions()
 //             break;
 //         case 1: {
 //             QString s = ds->customDataRegion().toString().split('.').value(0) + '.' + value.toString();
-//             emit xDataChanged(ds, CellRegion(m_chart->tableSource(), s));
+//             Q_EMIT xDataChanged(ds, CellRegion(m_chart->tableSource(), s));
 //             break;
 //         }
 //         case 2: {
 //             QString s = ds->customDataRegion().toString().split('.').value(0) + '.' + value.toString();
-//             emit yDataChanged(ds, CellRegion(m_chart->tableSource(), s));
+//             Q_EMIT yDataChanged(ds, CellRegion(m_chart->tableSource(), s));
 //             break;
 //         }
 //         case 3: {
 //             QString s = ds->customDataRegion().toString().split('.').value(0) + '.' + value.toString();
-//             emit bubbleDataChanged(ds, CellRegion(m_chart->tableSource(), s));
+//             Q_EMIT bubbleDataChanged(ds, CellRegion(m_chart->tableSource(), s));
 //             break;
 //         }
 //     }
 // }
 
-void BubbleDataEditor::dataColumnsInserted(const QModelIndex&, int first, int last)
+void BubbleDataEditor::dataColumnsInserted(const QModelIndex &, int first, int last)
 {
     Q_ASSERT(first == last);
     if (!m_ui.manualControl->isChecked() || first == m_dataModel->columnCount() - 1) {
@@ -338,7 +324,7 @@ void BubbleDataEditor::dataColumnsInserted(const QModelIndex&, int first, int la
         for (QRect r : region.rects()) {
             if (r.left() >= first) {
                 ds->setXDataRegion(CellRegion(region.table(), r.adjusted(1, 0, 1, 0)));
-                debugChartUiBubble<<"move X:"<<first<<':'<<r<<region.toString()<<':'<<ds->xDataRegion().toString();
+                debugChartUiBubble << "move X:" << first << ':' << r << region.toString() << ':' << ds->xDataRegion().toString();
                 break;
             }
         }
@@ -346,14 +332,14 @@ void BubbleDataEditor::dataColumnsInserted(const QModelIndex&, int first, int la
         for (QRect r : region.rects()) {
             if (r.left() >= first) {
                 ds->setYDataRegion(CellRegion(region.table(), r.adjusted(1, 0, 1, 0)));
-                debugChartUiBubble<<"move Y:"<<first<<':'<<r<<region.toString()<<':'<<ds->xDataRegion().toString();
+                debugChartUiBubble << "move Y:" << first << ':' << r << region.toString() << ':' << ds->xDataRegion().toString();
                 break;
             }
         }
         region = ds->customDataRegion();
         for (QRect r : region.rects()) {
             if (r.left() >= first) {
-                debugChartUiBubble<<"move Cust:"<<first<<':'<<r;
+                debugChartUiBubble << "move Cust:" << first << ':' << r;
                 ds->setCustomDataRegion(CellRegion(region.table(), r.adjusted(1, 0, 1, 0)));
                 break;
             }
@@ -361,7 +347,7 @@ void BubbleDataEditor::dataColumnsInserted(const QModelIndex&, int first, int la
         region = ds->categoryDataRegion();
         for (QRect r : region.rects()) {
             if (r.left() >= first) {
-                debugChartUiBubble<<"move Cat:"<<first<<':'<<r;
+                debugChartUiBubble << "move Cat:" << first << ':' << r;
                 ds->setCategoryDataRegion(CellRegion(region.table(), r.adjusted(1, 0, 1, 0)));
                 break;
             }
@@ -369,7 +355,7 @@ void BubbleDataEditor::dataColumnsInserted(const QModelIndex&, int first, int la
         region = ds->labelDataRegion();
         for (QRect r : region.rects()) {
             if (r.left() >= first) {
-                debugChartUiBubble<<"move Lab:"<<first<<':'<<r;
+                debugChartUiBubble << "move Lab:" << first << ':' << r;
                 ds->setLabelDataRegion(CellRegion(region.table(), r.adjusted(1, 0, 1, 0)));
                 break;
             }
@@ -377,7 +363,7 @@ void BubbleDataEditor::dataColumnsInserted(const QModelIndex&, int first, int la
     }
 }
 
-void BubbleDataEditor::dataColumnsRemoved(const QModelIndex&, int first, int last)
+void BubbleDataEditor::dataColumnsRemoved(const QModelIndex &, int first, int last)
 {
     if (!m_ui.manualControl->isChecked()) {
         return;
@@ -389,7 +375,7 @@ void BubbleDataEditor::dataColumnsRemoved(const QModelIndex&, int first, int las
         for (QRect r : region.rects()) {
             if (r.left() >= first) {
                 ds->setXDataRegion(CellRegion(region.table(), r.adjusted(-count, 0, -count, 0)));
-                debugChartUiBubble<<"move X:"<<first<<':'<<r<<region.toString()<<':'<<ds->xDataRegion().toString();
+                debugChartUiBubble << "move X:" << first << ':' << r << region.toString() << ':' << ds->xDataRegion().toString();
                 break;
             }
         }
@@ -397,14 +383,14 @@ void BubbleDataEditor::dataColumnsRemoved(const QModelIndex&, int first, int las
         for (QRect r : region.rects()) {
             if (r.left() >= first) {
                 ds->setYDataRegion(CellRegion(region.table(), r.adjusted(-count, 0, -count, 0)));
-                debugChartUiBubble<<"move Y:"<<first<<':'<<r<<region.toString()<<':'<<ds->xDataRegion().toString();
+                debugChartUiBubble << "move Y:" << first << ':' << r << region.toString() << ':' << ds->xDataRegion().toString();
                 break;
             }
         }
         region = ds->customDataRegion();
         for (QRect r : region.rects()) {
             if (r.left() >= first) {
-                debugChartUiBubble<<"move Cust:"<<first<<':'<<r;
+                debugChartUiBubble << "move Cust:" << first << ':' << r;
                 ds->setCustomDataRegion(CellRegion(region.table(), r.adjusted(-count, 0, -count, 0)));
                 break;
             }
@@ -412,7 +398,7 @@ void BubbleDataEditor::dataColumnsRemoved(const QModelIndex&, int first, int las
         region = ds->categoryDataRegion();
         for (QRect r : region.rects()) {
             if (r.left() >= first) {
-                debugChartUiBubble<<"move Cat:"<<first<<':'<<r;
+                debugChartUiBubble << "move Cat:" << first << ':' << r;
                 ds->setCategoryDataRegion(CellRegion(region.table(), r.adjusted(-count, 0, -count, 0)));
                 break;
             }
@@ -420,7 +406,7 @@ void BubbleDataEditor::dataColumnsRemoved(const QModelIndex&, int first, int las
         region = ds->labelDataRegion();
         for (QRect r : region.rects()) {
             if (r.left() >= first) {
-                debugChartUiBubble<<"move Lab:"<<first<<':'<<r;
+                debugChartUiBubble << "move Lab:" << first << ':' << r;
                 ds->setLabelDataRegion(CellRegion(region.table(), r.adjusted(-count, 0, -count, 0)));
                 break;
             }
@@ -431,10 +417,10 @@ void BubbleDataEditor::dataColumnsRemoved(const QModelIndex&, int first, int las
 void BubbleDataEditor::dataRowCountChanged()
 {
     if (!m_chart->proxyModel()->manualControl()) {
-        debugChartUiBubble<<"Not manual control";
+        debugChartUiBubble << "Not manual control";
         return;
     }
-    const QList<DataSet*> lst = m_chart->proxyModel()->dataSets();
+    const QList<DataSet *> lst = m_chart->proxyModel()->dataSets();
     for (int i = 0; i < lst.count(); ++i) {
         DataSet *ds = lst.at(i);
         CellRegion region = ds->xDataRegion();
@@ -461,7 +447,7 @@ void BubbleDataEditor::dataRowCountChanged()
             r.setHeight(m_dataModel->rowCount());
             ds->setCategoryDataRegion(CellRegion(region.table(), r));
         }
-        debugChartUiBubble<<ds;
+        debugChartUiBubble << ds;
     }
 }
 
