@@ -1,20 +1,7 @@
 /* This file is part of the KDE project
- * Copyright (C) 2010 Carlos Licea <carlos@kdab.com>
+ * SPDX-FileCopyrightText: 2010 Carlos Licea <carlos@kdab.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "InitialsCommentShape.h"
@@ -23,8 +10,8 @@
 #include <QPainter>
 
 InitialsCommentShape::InitialsCommentShape()
-: KoShape()
-, m_active(true)
+    : KoShape()
+    , m_active(true)
 {
 }
 
@@ -32,26 +19,25 @@ InitialsCommentShape::~InitialsCommentShape()
 {
 }
 
-void InitialsCommentShape::saveOdf(KoShapeSavingContext& /*context*/) const
+void InitialsCommentShape::saveOdf(KoShapeSavingContext & /*context*/) const
 {
 }
 
-bool InitialsCommentShape::loadOdf(const KoXmlElement& /*element*/, KoShapeLoadingContext& /*context*/)
+bool InitialsCommentShape::loadOdf(const KoXmlElement & /*element*/, KoShapeLoadingContext & /*context*/)
 {
     return false;
 }
 
-void InitialsCommentShape::paint(QPainter& painter, const KoViewConverter& converter, KoShapePaintingContext &)
+void InitialsCommentShape::paint(QPainter &painter, const KoViewConverter &converter, KoShapePaintingContext &)
 {
     applyConversion(painter, converter);
 
     QLinearGradient gradient(initialsBoxPoint, QPointF(0, initialsBoxSize.height()));
     qreal lighterPos = 0.0;
     qreal darkerPos = 0.0;
-    if(!m_active){
+    if (!m_active) {
         darkerPos = 1.0;
-    }
-    else {
+    } else {
         lighterPos = 1.0;
     }
     gradient.setColorAt(lighterPos, QColor(Qt::yellow));
@@ -74,7 +60,6 @@ void InitialsCommentShape::setInitials(const QString &initials)
 QString InitialsCommentShape::initials()
 {
     return m_initials;
-
 }
 
 bool InitialsCommentShape::isActive() const
@@ -92,4 +77,3 @@ void InitialsCommentShape::toogleActive()
     setActive(!m_active);
     update();
 }
-
