@@ -1,20 +1,7 @@
 /* This file is part of the KDE project
-   Copyright (C) 2010 KO GmbH <ben.martin@kogmbh.com>
+   SPDX-FileCopyrightText: 2010 KO GmbH <ben.martin@kogmbh.com>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef __rdf_KoRdfLocation_h__
@@ -58,7 +45,7 @@ public:
     virtual void importFromData(const QByteArray &ba, const KoDocumentRdf *rdf = 0, KoCanvasBase *host = 0);
     virtual QWidget *createEditor(QWidget *parent);
     virtual void updateFromEditorData();
-    virtual KoRdfSemanticTreeWidgetItem *createQTreeWidgetItem(QTreeWidgetItem *parent = 0);
+    virtual KoRdfSemanticTreeWidgetItem *createQTreeWidgetItem(QTreeWidgetItem *parent = nullptr);
     virtual Soprano::Node linkingSubject() const;
     virtual void setupStylesheetReplacementMapping(QMap<QString, QString> &m);
     virtual void exportToMime(QMimeData *md) const;
@@ -83,7 +70,6 @@ public:
     void setDlong(double dlong);
 
 private:
-
     Soprano::Node m_linkSubject;
     QString m_name;
     double m_dlat;
