@@ -1,30 +1,17 @@
 /* This file is part of the KDE project
- * Copyright (C) 2008 Pierre Stirnweiss <pstirnweiss@googlemail.com>
- * Copyright (C) 2009-2010 Thomas Zander <zander@kde.org>
- * Copyright (C) 2012 Gopalakrishna Bhat A <gopalakbhat@gmail.com>
+ * SPDX-FileCopyrightText: 2008 Pierre Stirnweiss <pstirnweiss@googlemail.com>
+ * SPDX-FileCopyrightText: 2009-2010 Thomas Zander <zander@kde.org>
+ * SPDX-FileCopyrightText: 2012 Gopalakrishna Bhat A <gopalakbhat@gmail.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "FormattingPreview.h"
 
-#include <KoPostscriptPaintDevice.h>
-#include <KoZoomHandler.h>
-#include <KoStyleThumbnailer.h>
 #include <KoCharacterStyle.h>
+#include <KoPostscriptPaintDevice.h>
+#include <KoStyleThumbnailer.h>
+#include <KoZoomHandler.h>
 
 #include <QBrush>
 #include <QColor>
@@ -43,16 +30,16 @@
 
 #include <math.h>
 
-#include <klocale.h>
-#include <kdebug.h>
+#include <KLocalizedString>
+#include <QDebug>
 
-FormattingPreview::FormattingPreview(QWidget* parent)
-        : QFrame(parent),
-        m_sampleText(i18n("Font")),
-        m_characterStyle(0),
-        m_paragraphStyle(0),
-        m_thumbnailer(new KoStyleThumbnailer()),
-        m_previewLayoutRequired(true)
+FormattingPreview::FormattingPreview(QWidget *parent)
+    : QFrame(parent)
+    , m_sampleText(i18n("Font"))
+    , m_characterStyle(nullptr)
+    , m_paragraphStyle(nullptr)
+    , m_thumbnailer(new KoStyleThumbnailer())
+    , m_previewLayoutRequired(true)
 {
     setFrameStyle(QFrame::Box | QFrame::Plain);
     setMinimumSize(500, 150);
@@ -81,8 +68,8 @@ void FormattingPreview::setText(const QString &sampleText)
     update();
 }
 
-//Character properties
-void FormattingPreview::setCharacterStyle(const KoCharacterStyle* style)
+// Character properties
+void FormattingPreview::setCharacterStyle(const KoCharacterStyle *style)
 {
     if (m_characterStyle) {
         delete m_characterStyle;
@@ -108,7 +95,7 @@ void FormattingPreview::setParagraphStyle(const KoParagraphStyle *style)
     update();
 }
 
-//Painting related methods
+// Painting related methods
 
 void FormattingPreview::paintEvent(QPaintEvent *event)
 {
@@ -118,14 +105,13 @@ void FormattingPreview::paintEvent(QPaintEvent *event)
     p->save();
 
     QRect rectang = contentsRect();
-
     p->fillRect(rectang, QBrush(QColor(Qt::white)));
-    p->drawImage(rectang, m_thumbnailer->thumbnail(m_characterStyle,m_paragraphStyle,rectang.size(),m_previewLayoutRequired, KoStyleThumbnailer::NoFlags));
+
+    rectang.adjust(6, 6, -6, -6);
+    p->drawImage(rectang, m_thumbnailer->thumbnail(m_characterStyle, m_paragraphStyle, rectang.size(), m_previewLayoutRequired, KoStyleThumbnailer::NoFlags));
 
     m_previewLayoutRequired = false;
 
     p->restore();
     delete p;
 }
-
-#include <FormattingPreview.moc>
