@@ -1,12 +1,11 @@
 #include "SimpleAnnotationWidget.h"
 
-
 #include "../ReviewTool.h"
 #include <QAction>
 #include <QDebug>
-SimpleAnnotationWidget::SimpleAnnotationWidget(ReviewTool *tool, QWidget *parent) :
-    QWidget(parent),
-    m_tool(tool)
+SimpleAnnotationWidget::SimpleAnnotationWidget(ReviewTool *tool, QWidget *parent)
+    : QWidget(parent)
+    , m_tool(tool)
 {
     widget.setupUi(this);
     widget.insertAnnotation->setDefaultAction(m_tool->action("insert_annotation"));
