@@ -1,10 +1,7 @@
 /* This file is part of the KDE project
-   Copyright (C) 2006 Stefan Nikolaus <stefan.nikolaus@kdemail.net>
+   SPDX-FileCopyrightText: 2006 Stefan Nikolaus <stefan.nikolaus@kdemail.net>
 
-   This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
-   (at your option) any later version.
+   SPDX-License-Identifier: GPL-2.0-or-later
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -18,9 +15,6 @@
 */
 #include "BenchmarkRTree.h"
 
-// #include "rtree.h"
-#include "RTree.h"
-
 #include <QTest>
 
 using namespace std;
@@ -104,7 +98,8 @@ void RTreeBenchmark::testLookupPerformance()
     QBENCHMARK {
         for (int y = 1; y <= max_y; y += step_y) {
             for (int x = 1; x <= max_x; x += step_x) {
-                if (!m_tree.contains(QPoint(x, y)).isEmpty()) counter++;
+                if (!m_tree.contains(QPoint(x, y)).isEmpty())
+                    counter++;
             }
         }
     }
