@@ -1,35 +1,20 @@
-/* This file is part of the KDE project
-   Copyright 2007 Stefan Nikolaus <stefan.nikolaus@kdemail.net>
-   Copyright 2006 Ariya Hidayat <ariya@kde.org>
-
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; only
-   version 2 of the License.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
-*/
+// This file is part of the KDE project
+// SPDX-FileCopyrightText: 2007 Stefan Nikolaus <stefan.nikolaus@kdemail.net>
+// SPDX-FileCopyrightText: 2006 Ariya Hidayat <ariya@kde.org>
+// SPDX-License-Identifier: LGPL-2.0-only
 
 #ifndef CALLIGRA_SHEETS_TEST_STATISTICAL_FUNCTIONS
 #define CALLIGRA_SHEETS_TEST_STATISTICAL_FUNCTIONS
 
 #include <QObject>
 
-#include <Value.h>
+#include <engine/Value.h>
 
 namespace Calligra
 {
 namespace Sheets
 {
-class Map;
+class MapBase;
 
 class TestStatisticalFunctions : public QObject
 {
@@ -38,22 +23,22 @@ class TestStatisticalFunctions : public QObject
 private Q_SLOTS:
     void initTestCase();
 
-//     void testARRANG(); // alias PERMUT
+    //     void testARRANG(); // alias PERMUT
     void testAVEDEV();
     void testAVERAGE();
     void testAVERAGEA();
     void testBETADIST();
     void testBETAINV();
-//     void testBINO(); // Calligra Sheets version of BINOMDIST with 3 Parameters
+    //     void testBINO(); // Calligra Sheets version of BINOMDIST with 3 Parameters
     void testBINOMDIST();
     void testCHIDIST();
-//     void testCOMBIN();  // in -> TestMathFunctions
-//     void testCOMBINA(); // in -> TestMathFunctions
+    //     void testCOMBIN();  // in -> TestMathFunctions
+    //     void testCOMBINA(); // in -> TestMathFunctions
     void testCONFIDENCE();
     void testCORREL();
     void testCOVAR();
     void testDEVSQ();
-//     void testDEVSQA(); // no ODF-test available
+    //     void testDEVSQA(); // no ODF-test available
     void testEXPONDIST();
     void testFDIST();
     void testFINV();
@@ -63,28 +48,26 @@ private Q_SLOTS:
     void testFTEST();
     void testGAMMADIST();
     void testGAMMAINV();
-//     void testGAMMALN(); in -> TestMathFunctions
+    //     void testGAMMALN(); in -> TestMathFunctions
     void testGAUSS();
     void testGROWTH(); // to be implemented
     void testGEOMEAN();
     void testHARMEAN();
     void testHYPGEOMDIST();
     void testINTERCEPT();
-//     void testINVBINO();
+    //     void testINVBINO();
     void testKURT();
-//     void testKURTP(); // ???
+    //     void testKURTP(); // ???
     void testLARGE();
 
-
     void testLEGACYCHIDIST();
     void testLEGACYCHIINV();
     void testLEGACYFDIST();
     void testLEGACYFINV();
-//     void testLEGACYNORMSDIST(); // same as NORMDIST required for OpenFormula compliance
+    //     void testLEGACYNORMSDIST(); // same as NORMDIST required for OpenFormula compliance
 
-
-//     void testLINEST(); // ???
-//     void testLOGEST(); // ???
+    //     void testLINEST(); // ???
+    //     void testLOGEST(); // ???
     void testLOGINV();
     void testLOGNORMDIST();
     void testMAX();
@@ -96,8 +79,8 @@ private Q_SLOTS:
     void testNEGBINOMDIST();
     void testNORMDIST();
     void testNORMINV();
-//     void testNORMSDIST();
-//     void testNORMSINV();
+    //     void testNORMSDIST();
+    //     void testNORMSINV();
 
     void testPEARSON();
     void testPERCENTILE();
@@ -105,7 +88,7 @@ private Q_SLOTS:
     void testPERMUTATIONA();
     void testPHI();
     void testPOISSON();
-//     void testPROB();     // ???
+    //     void testPROB();     // ???
     void testQUARTILE();
     void testRANK();
     void testRSQ();
@@ -119,10 +102,10 @@ private Q_SLOTS:
     void testSTDEVP();
     void testSTDEVPA();
     void testSTEYX();
-//     void testSUMXMY2(); // deprecated
+    //     void testSUMXMY2(); // deprecated
     void testSUMPRODUCT();
-//     void testSUMX2PY2();
-//     void testSUMX2MY2();
+    //     void testSUMX2PY2();
+    //     void testSUMX2MY2();
     void testTDIST();
     void testTINV();
     void testTREND();
@@ -139,11 +122,11 @@ private Q_SLOTS:
     void cleanupTestCase();
 
 private:
-    bool  TestArray(const QString& formula, const QString& Array, int accuracy, bool checkSize);
-    Value evaluate(const QString&);
-    Value TestDouble(const QString& formula, const Value& v2, int accuracy);
+    bool TestArray(const QString &formula, const QString &Array, int accuracy, bool checkSize);
+    Value evaluate(const QString &);
+    Value TestDouble(const QString &formula, const Value &v2, int accuracy);
 
-    Map* m_map;
+    MapBase *m_map;
 };
 
 } // namespace Sheets
