@@ -1,35 +1,22 @@
-/* This file is part of the KDE project
-   Copyright 2007 Brad Hards <bradh@frogmouth.net>
-
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; only
-   version 2 of the License.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
-*/
+// This file is part of the KDE project
+// SPDX-FileCopyrightText: 2007 Brad Hards <bradh@frogmouth.net>
+// SPDX-License-Identifier: LGPL-2.0-only
 
 #ifndef CALLIGRA_SHEETS_TEST_TEXT_FUNCTIONS
 #define CALLIGRA_SHEETS_TEST_TEXT_FUNCTIONS
 
 #include <QObject>
 
-#include <Value.h>
+#include <engine/Value.h>
 
 namespace Calligra
 {
 namespace Sheets
 {
 
-class TestTextFunctions: public QObject
+class MapBase;
+
+class TestTextFunctions : public QObject
 {
     Q_OBJECT
 
@@ -63,8 +50,13 @@ private Q_SLOTS:
     void testROT13();
     void testBAHTTEXT();
     void testTEXT();
+
+    void cleanupTestCase();
+
 private:
-    Value evaluate(const QString&, Value& ex);
+    Value evaluate(const QString &, Value &ex);
+
+    MapBase *m_map;
 };
 
 } // namespace Sheets
