@@ -1,26 +1,13 @@
 /* This file is part of the KDE project
- * Copyright (C) 2010 Gopalakrishna Bhat A <gopalakbhat@gmail.com>
+ * SPDX-FileCopyrightText: 2010 Gopalakrishna Bhat A <gopalakbhat@gmail.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #ifndef KPRPRESENTATIONTOOLADAPTOR_H
 #define KPRPRESENTATIONTOOLADAPTOR_H
 
-#ifndef QT_NO_DBUS
+#ifdef WITH_QTDBUS
 #include "KPrPresentationTool.h"
 
 #include <QDBusAbstractAdaptor>
@@ -75,6 +62,6 @@ private:
     KPrPresentationTool *m_tool;
     KPrViewModePresentation &m_viewModePresentation;
 };
-#endif // QT_NO_DBUS
+#endif // WITH_QTDBUS
 
 #endif /* KPRPRESENTATIONTOOLADAPTOR_H */
