@@ -1,22 +1,9 @@
 /* This file is part of the KDE project
-*
-* Copyright (C) 2011 Paul Mendez <paulestebanms@gmail.com>
-*
-* This library is free software; you can redistribute it and/or
-* modify it under the terms of the GNU Library General Public
-* License as published by the Free Software Foundation; either
-* version 2 of the License, or (at your option) any later version.
-*
-* This library is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-* Library General Public License for more details.
-*
-* You should have received a copy of the GNU Library General Public License
-* along with this library; see the file COPYING.LIB.  If not, write to
-* the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-* Boston, MA 02110-1301, USA.
-*/
+ *
+ * SPDX-FileCopyrightText: 2011 Paul Mendez <paulestebanms@gmail.com>
+ *
+ * SPDX-License-Identifier: LGPL-2.0-or-later
+ */
 
 #ifndef KPRSLIDESMANAGERVIEW_H
 #define KPRSLIDESMANAGERVIEW_H
@@ -33,19 +20,19 @@ class KPrSlidesManagerView : public QListView
 {
     Q_OBJECT
 public:
-    explicit KPrSlidesManagerView(QWidget *parent = 0);
+    explicit KPrSlidesManagerView(QWidget *parent = nullptr);
 
     ~KPrSlidesManagerView() override;
 
-    void paintEvent (QPaintEvent *event) override;
+    void paintEvent(QPaintEvent *event) override;
 
-    //It emits a slideDblClick signal and then calls the parent
-    //implementation
+    // It emits a slideDblClick signal and then calls the parent
+    // implementation
     void mouseDoubleClickEvent(QMouseEvent *event) override;
 
     void contextMenuEvent(QContextMenuEvent *event) override;
 
-    void startDrag (Qt::DropActions supportedActions) override;
+    void startDrag(Qt::DropActions supportedActions) override;
 
     void dropEvent(QDropEvent *ev) override;
 
@@ -55,11 +42,11 @@ public:
 
     void dragLeaveEvent(QDragLeaveEvent *e) override;
 
-    //Reimplemented to provide suitable signals for selection and deselection of items
+    // Reimplemented to provide suitable signals for selection and deselection of items
     void selectionChanged(const QItemSelection &selected, const QItemSelection &deselected) override;
 
-    //Manage click events outside of items, to provide
-    //a suitable active item for the context menu.
+    // Manage click events outside of items, to provide
+    // a suitable active item for the context menu.
     bool eventFilter(QObject *watched, QEvent *event) override;
 
     void focusOutEvent(QFocusEvent *event) override;
@@ -94,8 +81,8 @@ Q_SIGNALS:
     /** Is emitted if the user has double click an item */
     void slideDblClick();
 
-    //lets update the active page when changing the current index
-    //without a item selected event.
+    // lets update the active page when changing the current index
+    // without a item selected event.
     /** Is emitted if the selection has been changed within a procedure code */
     void indexChanged(QModelIndex index);
 
@@ -142,7 +129,6 @@ private:
     QRect m_itemSize;
     bool m_draggingFlag;
     int margin;
-
 };
 
 #endif // KPRSLIDESMANAGERVIEW_H
