@@ -1,32 +1,18 @@
 /* This file is part of the KDE project
- * Copyright (C) 2008 Fredy Yanardi <fyanardi@gmail.com>
- * Copyright (C) 2009 Thorsten Zachmann <zachmann@kde.org>
+ * SPDX-FileCopyrightText: 2008 Fredy Yanardi <fyanardi@gmail.com>
+ * SPDX-FileCopyrightText: 2009 Thorsten Zachmann <zachmann@kde.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "KPrViewModeNotes.h"
 
 #include <QEvent>
-#include <QPainter>
 #include <QGraphicsWidget>
-
-#include <kdebug.h>
+#include <QPainter>
 
 #include <KoDocumentResourceManager.h>
+#include <KoInteractionTool.h>
 #include <KoRuler.h>
 #include <KoSelection.h>
 #include <KoShapeLayer.h>
@@ -34,7 +20,6 @@
 #include <KoText.h>
 #include <KoToolManager.h>
 #include <KoToolProxy.h>
-#include <KoInteractionTool.h>
 
 #include <KoPACanvasBase.h>
 #include <KoPADocument.h>
@@ -43,16 +28,15 @@
 
 #include "KPrNotes.h"
 #include "KPrPage.h"
+#include "StageDebug.h"
 
 KPrViewModeNotes::KPrViewModeNotes(KoPAViewBase *view, KoPACanvasBase *canvas)
-    : KoPAViewMode( view, canvas )
+    : KoPAViewMode(view, canvas)
 {
     setName(i18n("Notes"));
 }
 
-KPrViewModeNotes::~KPrViewModeNotes()
-{
-}
+KPrViewModeNotes::~KPrViewModeNotes() = default;
 
 void KPrViewModeNotes::paint(KoPACanvasBase *canvas, QPainter &painter, const QRectF &paintRect)
 {
@@ -113,28 +97,28 @@ void KPrViewModeNotes::keyPressEvent(QKeyEvent *event)
         event->accept();
 
         switch (event->key()) {
-            case Qt::Key_Home:
-                pageNavigation = KoPageApp::PageFirst;
-                break;
-            case Qt::Key_PageUp:
-                pageNavigation = KoPageApp::PagePrevious;
-                break;
-            case Qt::Key_PageDown:
-                pageNavigation = KoPageApp::PageNext;
-                break;
-            case Qt::Key_End:
-                pageNavigation = KoPageApp::PageLast;
-                break;
-            default:
-                event->ignore();
-                return;
+        case Qt::Key_Home:
+            pageNavigation = KoPageApp::PageFirst;
+            break;
+        case Qt::Key_PageUp:
+            pageNavigation = KoPageApp::PagePrevious;
+            break;
+        case Qt::Key_PageDown:
+            pageNavigation = KoPageApp::PageNext;
+            break;
+        case Qt::Key_End:
+            pageNavigation = KoPageApp::PageLast;
+            break;
+        default:
+            event->ignore();
+            return;
         }
 
         KoPAPageBase *activePage = m_view->activePage();
         KoPAPageBase *newPage = m_view->kopaDocument()->pageByNavigation(activePage, pageNavigation);
 
         if (newPage != activePage) {
-            updateActivePage( newPage );
+            updateActivePage(newPage);
         }
     }
 }
@@ -151,16 +135,16 @@ void KPrViewModeNotes::wheelEvent(QWheelEvent *event, const QPointF &point)
 
 void KPrViewModeNotes::activate(KoPAViewMode *previousViewMode)
 {
-    Q_UNUSED( previousViewMode );
+    Q_UNUSED(previousViewMode);
     m_canvas->resourceManager()->setResource(KoCanvasResourceManager::ShowTextShapeOutlines, QVariant(true));
-    m_view->setActionEnabled( KoPAView::AllActions, false );
-    updateActivePage( m_view->activePage() );
+    m_view->setActionEnabled(KoPAView::AllActions, false);
+    updateActivePage(m_view->activePage());
 }
 
 void KPrViewModeNotes::deactivate()
 {
     m_canvas->resourceManager()->setResource(KoCanvasResourceManager::ShowTextShapeOutlines, QVariant(false));
-    m_view->setActionEnabled( KoPAView::AllActions, true );
+    m_view->setActionEnabled(KoPAView::AllActions, true);
     m_view->doUpdateActivePage(m_view->activePage());
 }
 
@@ -171,25 +155,25 @@ void KPrViewModeNotes::updateActivePage(KoPAPageBase *page)
     }
 
     KPrPage *prPage = static_cast<KPrPage *>(page);
-    if (prPage == 0) {
+    if (prPage == nullptr) {
         return;
     }
     KPrNotes *notes = prPage->pageNotes();
     notes->updatePageThumbnail();
-    KoShapeLayer* layer = dynamic_cast<KoShapeLayer*>(notes->shapes().last());
+    KoShapeLayer *layer = static_cast<KoShapeLayer *>(notes->shapes().last());
 
     m_canvas->shapeManager()->setShapes(layer->shapes());
-    m_canvas->masterShapeManager()->setShapes(QList<KoShape*>());
+    m_canvas->masterShapeManager()->setShapes(QList<KoShape *>());
 
-    static_cast<KoPAView*>(m_view)->updateCanvasSize(true);
+    static_cast<KoPAView *>(m_view)->updateCanvasSize(true);
 
     m_view->updatePageNavigationActions();
 
     KoSelection *selection = m_canvas->shapeManager()->selection();
     selection->select(notes->textShape());
-    selection->setActiveLayer( layer );
+    selection->setActiveLayer(layer);
     QString tool = KoToolManager::instance()->preferredToolForSelection(selection->selectedShapes());
-    // we need to make sue to switch to the default tool so that the text tool does notice the selection chane
+    // we need to make sue to switch to the default tool so that the text tool does notice the selection change
     KoToolManager::instance()->switchToolRequested(KoInteractionTool_ID);
     // we need to set the focus to the text tool again so that we can start typing
     // otherwise you need to click on the shape again
@@ -197,45 +181,44 @@ void KPrViewModeNotes::updateActivePage(KoPAPageBase *page)
     KoToolManager::instance()->switchToolRequested(tool);
 }
 
-void KPrViewModeNotes::addShape( KoShape *shape )
+void KPrViewModeNotes::addShape(KoShape *shape)
 {
     KoShape *parent = shape;
-    KPrNotes *notes = 0;
+    KPrNotes *notes = nullptr;
     // similar to KoPADocument::pageByShape()
-    while ( !notes && ( parent = parent->parent() ) ) {
-        notes = dynamic_cast<KPrNotes *>( parent );
+    while (!notes && (parent = parent->parent())) {
+        notes = dynamic_cast<KPrNotes *>(parent);
     }
 
-    if ( notes ) {
+    if (notes) {
         Q_ASSERT(dynamic_cast<KPrPage *>(m_view->activePage()));
         KPrPage *activePage = static_cast<KPrPage *>(m_view->activePage());
-        if ( notes == activePage->pageNotes() ) {
-            m_view->kopaCanvas()->shapeManager()->addShape( shape );
+        if (notes == activePage->pageNotes()) {
+            m_view->kopaCanvas()->shapeManager()->addShape(shape);
         }
     }
 }
 
-void KPrViewModeNotes::removeShape( KoShape *shape )
+void KPrViewModeNotes::removeShape(KoShape *shape)
 {
     KoShape *parent = shape;
-    KPrNotes *notes = 0;
-    while ( !notes && ( parent = parent->parent() ) ) {
-        notes = dynamic_cast<KPrNotes *>( parent );
+    KPrNotes *notes = nullptr;
+    while (!notes && (parent = parent->parent())) {
+        notes = dynamic_cast<KPrNotes *>(parent);
     }
 
-    if ( notes ) {
-        KPrPage *activePage = static_cast<KPrPage *>( m_view->activePage() );
-        if ( notes == activePage->pageNotes() ) {
-            m_view->kopaCanvas()->shapeManager()->remove( shape );
+    if (notes) {
+        KPrPage *activePage = static_cast<KPrPage *>(m_view->activePage());
+        if (notes == activePage->pageNotes()) {
+            m_view->kopaCanvas()->shapeManager()->remove(shape);
         }
     }
 }
 
 const KoPageLayout &KPrViewModeNotes::activePageLayout() const
 {
-    KPrPage *activePage = static_cast<KPrPage *>( m_view->activePage() );
+    KPrPage *activePage = static_cast<KPrPage *>(m_view->activePage());
     KPrNotes *notes = activePage->pageNotes();
 
     return notes->pageLayout();
 }
-
