@@ -1,6 +1,6 @@
 /* This file is part of the KDE project
- * Copyright (C) 2010 Thorsten Zachmann <zachmann@kde.org>
- * Copyright (C) 2010 Benjamin Port <port.benjamin@gmail.com>
+ * SPDX-FileCopyrightText: 2010 Thorsten Zachmann <zachmann@kde.org>
+ * SPDX-FileCopyrightText: 2010 Benjamin Port <port.benjamin@gmail.com>
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
  * License as published by the Free Software Foundation; either
@@ -17,39 +17,33 @@
  * Boston, MA 02110-1301, USA.
  */
 
-
 #include "KPrAnimationSubStep.h"
 #include "KPrShapeAnimation.h"
 #include <KoPASavingContext.h>
 #include <KoXmlWriter.h>
 
+KPrAnimationSubStep::KPrAnimationSubStep() = default;
 
-KPrAnimationSubStep::KPrAnimationSubStep()
-{
-}
-
-KPrAnimationSubStep::~KPrAnimationSubStep()
-{
-}
+KPrAnimationSubStep::~KPrAnimationSubStep() = default;
 
 void KPrAnimationSubStep::init(KPrAnimationCache *animationCache, int step)
 {
-    for(int i=0;i < this->animationCount();i++) {
-        QAbstractAnimation * animation = this->animationAt(i);
-        if (KPrShapeAnimation *a = dynamic_cast<KPrShapeAnimation*>(animation)) {
+    for (int i = 0; i < this->animationCount(); i++) {
+        QAbstractAnimation *animation = this->animationAt(i);
+        if (KPrShapeAnimation *a = dynamic_cast<KPrShapeAnimation *>(animation)) {
             a->init(animationCache, step);
         }
     }
 }
 
-bool KPrAnimationSubStep::saveOdf(KoPASavingContext & paContext, bool startStep) const
+bool KPrAnimationSubStep::saveOdf(KoPASavingContext &paContext, bool startStep) const
 {
     KoXmlWriter &writer = paContext.xmlWriter();
     writer.startElement("anim:par");
-    for (int i=0; i < this->animationCount(); i++) {
+    for (int i = 0; i < this->animationCount(); i++) {
         bool startSubStep = !i;
         QAbstractAnimation *animation = this->animationAt(i);
-        if (KPrShapeAnimation *a = dynamic_cast<KPrShapeAnimation*>(animation)) {
+        if (KPrShapeAnimation *a = dynamic_cast<KPrShapeAnimation *>(animation)) {
             a->saveOdf(paContext, startStep, startSubStep);
         }
     }
@@ -59,9 +53,9 @@ bool KPrAnimationSubStep::saveOdf(KoPASavingContext & paContext, bool startStep)
 
 void KPrAnimationSubStep::deactivate()
 {
-    for (int i=0; i < this->animationCount(); i++) {
+    for (int i = 0; i < this->animationCount(); i++) {
         QAbstractAnimation *animation = this->animationAt(i);
-        if (KPrShapeAnimation *a = dynamic_cast<KPrShapeAnimation*>(animation)) {
+        if (KPrShapeAnimation *a = dynamic_cast<KPrShapeAnimation *>(animation)) {
             a->deactivate();
         }
     }
