@@ -1,6 +1,6 @@
 /* This file is part of the KDE project
- * Copyright (C) 2010 Thorsten Zachmann <zachmann@kde.org>
- * Copyright (C) 2010 Benjamin Port <port.benjamin@gmail.com>
+ * SPDX-FileCopyrightText: 2010 Thorsten Zachmann <zachmann@kde.org>
+ * SPDX-FileCopyrightText: 2010 Benjamin Port <port.benjamin@gmail.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -21,9 +21,9 @@
 #ifndef KPRANIMATIONSUBSTEP_H
 #define KPRANIMATIONSUBSTEP_H
 
-#include <QParallelAnimationGroup>
 #include "KPrAnimationData.h"
 #include "stage_export.h"
+#include <QParallelAnimationGroup>
 
 class KoPASavingContext;
 
@@ -33,10 +33,9 @@ public:
     KPrAnimationSubStep();
     ~KPrAnimationSubStep() override;
 
-    // Do not mark this 'override', sub-classing will fail
-    virtual void init(KPrAnimationCache *animationCache, int step); //NOLINT
+    void init(KPrAnimationCache *animationCache, int step) override;
 
-    virtual bool saveOdf(KoPASavingContext & paContext, bool startStep) const;
+    virtual bool saveOdf(KoPASavingContext &paContext, bool startStep) const;
     virtual void deactivate();
 };
 
