@@ -1,28 +1,15 @@
 /* This file is part of the KDE project
- * Copyright (C) 2007-2008 Thorsten Zachmann <zachmann@kde.org>
- * Copyright (C) 2011 Paul Mendez <paulestebanms@gmail.com>
+ * SPDX-FileCopyrightText: 2007-2008 Thorsten Zachmann <zachmann@kde.org>
+ * SPDX-FileCopyrightText: 2011 Paul Mendez <paulestebanms@gmail.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #ifndef KPRDELETESLIDESCOMMAND_H
 #define KPRDELETESLIDESCOMMAND_H
 
-#include <kundo2command.h>
 #include <QMap>
+#include <kundo2command.h>
 
 class KPrDocument;
 class KoPAPageBase;
@@ -42,7 +29,7 @@ public:
      * @param page the page to delete
      * @param parent the parent command used for macro commands
      */
-    KPrDeleteSlidesCommand(KPrDocument *document, KoPAPageBase *page, KUndo2Command *parent = 0 );
+    KPrDeleteSlidesCommand(KPrDocument *document, KoPAPageBase *page, KUndo2Command *parent = nullptr);
 
     /**
      * Command to delete multiple pages.
@@ -50,7 +37,7 @@ public:
      * @param pages a list of pages to delete
      * @param parent the parent command used for macro commands
      */
-    KPrDeleteSlidesCommand(KPrDocument *document, const QList<KoPAPageBase*> &pages, KUndo2Command *parent = 0);
+    KPrDeleteSlidesCommand(KPrDocument *document, const QList<KoPAPageBase *> &pages, KUndo2Command *parent = nullptr);
 
     ~KPrDeleteSlidesCommand() override;
 
@@ -61,8 +48,8 @@ public:
 
 private:
     KPrDocument *m_document; //< the document to delete the pages from
-    QMap<int, KoPAPageBase*> m_pages; //< a map of pages to delete, with document index as key
-    QMap<QString, QList<KoPAPageBase*> > m_customSlideShows;
+    QMap<int, KoPAPageBase *> m_pages; //< a map of pages to delete, with document index as key
+    QMap<QString, QList<KoPAPageBase *>> m_customSlideShows;
     bool m_deletePages; //< shows if pages should be deleted when deleting the command
 };
 
