@@ -1,22 +1,9 @@
 /* This file is part of the KDE project
 
-   Copyright (C) 2008 C. Boemann <cbo@boemann.dk>
-   Copyright (C) 2012 Paul Mendez <paulestebanms@gmail.com>
+   SPDX-FileCopyrightText: 2008 C. Boemann <cbo@boemann.dk>
+   SPDX-FileCopyrightText: 2012 Paul Mendez <paulestebanms@gmail.com>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KPRANIMATIONTOOL_H
@@ -52,44 +39,44 @@ public:
     void repaintDecorations() override;
 
 public Q_SLOTS:
-    void activate(ToolActivation toolActivation, const QSet<KoShape*> &shapes) override;
+    void activate(KoToolBase::ToolActivation toolActivation, const QSet<KoShape *> &shapes) override;
     void deactivate() override;
 
 private Q_SLOTS:
 
     /**
-      * @brief Reload motion path shapes (For all shapes with motion paths on current page)
-      */
+     * @brief Reload motion path shapes (For all shapes with motion paths on current page)
+     */
     void reloadMotionPaths();
 
     /**
-      * @brief Verify if a motion path shape has changed (to update the canvas)
-      */
+     * @brief Verify if a motion path shape has changed (to update the canvas)
+     */
     void verifyMotionPathChanged(KoShape *shape);
 
 protected:
     QRectF handlesSize();
 
-    QList<QPointer<QWidget> > createOptionWidgets() override;
+    QList<QPointer<QWidget>> createOptionWidgets() override;
 
     /**
-      * @brief Load motion path shapes (For all shapes with motion paths on current page)
-      */
+     * @brief Load motion path shapes (For all shapes with motion paths on current page)
+     */
     void initMotionPathShapes();
 
     /**
-      * @brief Add motion path shape to the motion path shapes manager
-      */
+     * @brief Add motion path shape to the motion path shapes manager
+     */
     virtual void addPathShape(KoPathShape *pathShape);
 
     /**
-      * @brief Helper method to get the current page size
-      */
+     * @brief Helper method to get the current page size
+     */
     QSizeF getPageSize();
 
     /**
-      * @brief remove motion paths of motion path manager and helper maps
-      */
+     * @brief remove motion paths of motion path manager and helper maps
+     */
     void cleanMotionPathManager();
 
 private:
