@@ -1,41 +1,26 @@
 /* This file is part of the KDE project
- * Copyright (C) 2006, 2008, 2010 Thomas Zander <zander@kde.org>
- * Copyright (C) 2008 Pierre Ducroquet <pinaraf@pinaraf.info>
- * Copyright (C) 2008 Sebastian Sauer <mail@dipe.org>
+ * SPDX-FileCopyrightText: 2006, 2008, 2010 Thomas Zander <zander@kde.org>
+ * SPDX-FileCopyrightText: 2008 Pierre Ducroquet <pinaraf@pinaraf.info>
+ * SPDX-FileCopyrightText: 2008 Sebastian Sauer <mail@dipe.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "KWPageStyle.h"
 #include "KWPageStyle_p.h"
 
-#include <KoXmlWriter.h>
-#include <KoXmlNS.h>
-#include <KoUnit.h>
 #include <KoColorBackground.h>
-#include <KoPatternBackground.h>
 #include <KoImageCollection.h>
 #include <KoOdfLoadingContext.h>
+#include <KoPatternBackground.h>
+#include <KoUnit.h>
+#include <KoXmlNS.h>
+#include <KoXmlWriter.h>
 
 #include <QBuffer>
 #include <QColor>
 
-KWPageStylePrivate::~KWPageStylePrivate()
-{
-}
+KWPageStylePrivate::~KWPageStylePrivate() = default;
 
 void KWPageStylePrivate::clear()
 {
@@ -58,37 +43,27 @@ void KWPageStylePrivate::clear()
 ///////////
 
 KWPageStyle::KWPageStyle(const QString &name, const QString &displayname)
-    : d (new KWPageStylePrivate())
+    : d(new KWPageStylePrivate())
 {
     d->name = name;
-    if (!displayname.isEmpty() && displayname != name)
+    if (!displayname.isEmpty())
         d->displayName = displayname;
 }
 
 KWPageStyle::KWPageStyle(const KWPageStyle &ps)
-    : d(ps.d)
-{
-}
 
-KWPageStyle::KWPageStyle()
-{
-}
+    = default;
+
+KWPageStyle::KWPageStyle() = default;
 
 bool KWPageStyle::isValid() const
 {
     return d && !d->name.isEmpty();
 }
 
+KWPageStyle &KWPageStyle::operator=(const KWPageStyle &ps) = default;
 
-KWPageStyle &KWPageStyle::operator=(const KWPageStyle &ps)
-{
-    d = ps.d;
-    return *this;
-}
-
-KWPageStyle::~KWPageStyle()
-{
-}
+KWPageStyle::~KWPageStyle() = default;
 
 KWPageStyle::PageUsageType KWPageStyle::pageUsage() const
 {
@@ -231,24 +206,23 @@ KoGenStyle KWPageStyle::saveOdf() const
     pageLayout.setAutoStyleInStylesDotXml(true);
 
     switch (d->pageUsage) {
-        case LeftPages:
-            pageLayout.addAttribute("style:page-usage", "left");
-            break;
-        case MirroredPages:
-            pageLayout.addAttribute("style:page-usage", "mirrored");
-            break;
-        case RightPages:
-            pageLayout.addAttribute("style:page-usage", "right");
-            break;
-        default:
-            pageLayout.addAttribute("style:page-usage", "all");
-            break;
+    case LeftPages:
+        pageLayout.addAttribute("style:page-usage", "left");
+        break;
+    case MirroredPages:
+        pageLayout.addAttribute("style:page-usage", "mirrored");
+        break;
+    case RightPages:
+        pageLayout.addAttribute("style:page-usage", "right");
+        break;
+    default:
+        pageLayout.addAttribute("style:page-usage", "all");
+        break;
     }
 
     // Save background color if it is set
-    if (d->fullPageBackground)
-    {
-        KoColorBackground *colorBackground = dynamic_cast<KoColorBackground*>(d->fullPageBackground.data());
+    if (d->fullPageBackground) {
+        KoColorBackground *colorBackground = dynamic_cast<KoColorBackground *>(d->fullPageBackground.data());
         if (colorBackground)
             pageLayout.addProperty("fo:background-color", colorBackground->color().name());
     }
@@ -257,15 +231,13 @@ KoGenStyle KWPageStyle::saveOdf() const
     d->columns.saveOdf(pageLayout);
 
     //<style:footnote-sep style:adjustment="left" style:width="0.5pt" style:rel-width="20%" style:line-style="solid"/>
-    //writer.startElement("style:footnote-sep");
+    // writer.startElement("style:footnote-sep");
     // TODO
-    //writer.addAttribute("style:adjustment",)
-    //writer.addAttribute("style:width",)
-    //writer.addAttribute("style:rel-width",)
-    //writer.addAttribute("style:line-style",)
-    //writer.endElement();
-
-
+    // writer.addAttribute("style:adjustment",)
+    // writer.addAttribute("style:width",)
+    // writer.addAttribute("style:rel-width",)
+    // writer.addAttribute("style:line-style",)
+    // writer.endElement();
 
     if (headerPolicy() != Words::HFTypeNone) {
         QBuffer buffer;
@@ -331,9 +303,9 @@ void KWPageStyle::loadOdf(KoOdfLoadingContext &context, const KoXmlElement &mast
     d->columns.loadOdf(props);
 
     KoXmlElement header = KoXml::namedItemNS(style, KoXmlNS::style, "header-style");
-    if (! header.isNull()) {
+    if (!header.isNull()) {
         KoXmlElement hfprops = KoXml::namedItemNS(header, KoXmlNS::style, "header-footer-properties");
-        if (! hfprops.isNull()) {
+        if (!hfprops.isNull()) {
             d->headerDistance = KoUnit::parseValue(hfprops.attributeNS(KoXmlNS::fo, "margin-bottom"));
             d->headerMinimumHeight = KoUnit::parseValue(hfprops.attributeNS(KoXmlNS::fo, "min-height"));
             const QString dynamicSpacing(hfprops.attributeNS(KoXmlNS::style, "dynamic-spacing"));
@@ -343,9 +315,9 @@ void KWPageStyle::loadOdf(KoOdfLoadingContext &context, const KoXmlElement &mast
     }
 
     KoXmlElement footer = KoXml::namedItemNS(style, KoXmlNS::style, "footer-style");
-    if (! footer.isNull()) {
+    if (!footer.isNull()) {
         KoXmlElement hfprops = KoXml::namedItemNS(footer, KoXmlNS::style, "header-footer-properties");
-        if (! hfprops.isNull()) {
+        if (!hfprops.isNull()) {
             d->footerDistance = KoUnit::parseValue(hfprops.attributeNS(KoXmlNS::fo, "margin-top"));
             d->footerMinimumHeight = KoUnit::parseValue(hfprops.attributeNS(KoXmlNS::fo, "min-height"));
             const QString dynamicSpacing(hfprops.attributeNS(KoXmlNS::style, "dynamic-spacing"));
@@ -359,12 +331,12 @@ void KWPageStyle::loadOdf(KoOdfLoadingContext &context, const KoXmlElement &mast
     if (!propBackgroundImage.isNull()) {
         const QString href = propBackgroundImage.attributeNS(KoXmlNS::xlink, "href", QString());
         if (!href.isEmpty()) {
-            QSharedPointer<KoPatternBackground> background =  QSharedPointer<KoPatternBackground>(new KoPatternBackground(documentResources->imageCollection()));
+            QSharedPointer<KoPatternBackground> background = QSharedPointer<KoPatternBackground>(new KoPatternBackground(documentResources->imageCollection()));
             d->fullPageBackground = background;
 
             KoImageCollection *imageCollection = documentResources->imageCollection();
-            if (imageCollection != 0) {
-                KoImageData *imageData = imageCollection->createImageData(href,context.store());
+            if (imageCollection != nullptr) {
+                KoImageData *imageData = imageCollection->createImageData(href, context.store());
                 background->setPattern(imageData);
             }
         }
@@ -373,12 +345,10 @@ void KWPageStyle::loadOdf(KoOdfLoadingContext &context, const KoXmlElement &mast
 
     // Load background color
     QString backgroundColor = props.attributeNS(KoXmlNS::fo, "background-color", QString());
-    if (!backgroundColor.isNull() && d->fullPageBackground == 0) {
-
+    if (!backgroundColor.isNull() && d->fullPageBackground == nullptr) {
         if (backgroundColor == "transparent") {
             d->fullPageBackground.clear();
-        }
-        else {
+        } else {
             d->fullPageBackground = QSharedPointer<KoShapeBackground>(new KoColorBackground(QColor(backgroundColor)));
         }
     }
@@ -425,7 +395,7 @@ const KWPageStylePrivate *KWPageStyle::priv() const
 
 uint KWPageStyle::hash() const
 {
-    return ((uint) d) + 1;
+    return ((uint)d) + 1;
 }
 
 bool KWPageStyle::isPageSpread() const
